<?php
/**
 * The file that defines the core plugin class.
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://www.solwininfotech.com/
 * @since      1.0.0
 *
 * @package    Ualp_Twilio_SMS
 * @subpackage Ualp_Twilio_SMS/includes
 */

// Include Autoload file for Twilio.
require_once plugin_dir_path( __FILE__ ) . '/twilio-lib/src/Twilio/autoload.php';
use Twilio\Rest\Client;
/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Ualp_Twilio_SMS
 * @subpackage Ualp_Twilio_SMS/includes
 * @author     Solwin Infotech <info@solwininfotech.com>
 */
class Ualp_Twilio_SMS {

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since  1.0.0
	 * @access protected
	 * @var    string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;
	/**
	 * The current version of the plugin.
	 *
	 * @since  1.0.0
	 * @access protected
	 * @var    string    $version    The current version of the plugin.
	 */
	protected $version;
	/**
	 * Class Cunstructor.
	 *
	 * @since  1.0.0
	 */
	public function __construct() {

	}

	/**
	 * Send Bulk Messages.
	 *
	 * @param string $to To.
	 * @param string $message Message.
	 */
	public static function send_message_bulk( $to, $message ) {
		$sender_id = get_option( 'ualp_twilio_from' );
		if ( ! $to ) {
			$to = get_option( 'ualp_twilio_to' );
		}
		$twilio_sid   = get_option( 'ualp_twilio_api_sid' );
		$twilio_token = get_option( 'ualp_twilio_api_auth_token' );
		try {
			$client   = new Client( $twilio_sid, $twilio_token );
			$response = $client->messages->create(
				$to,
				array(
					'from' => $sender_id,
					'body' => $message,
				)
			);
			self::display_success();
		} catch ( Exception $e ) {
			self::display_error( $e->getMessage() );
		}
	}

	/**
	 * Send Messages.
	 *
	 * @param string $message Message.
	 */
	public static function send_message( $message ) {
		$sender_id    = get_option( 'ualp_twilio_from' );
		$to           = get_option( 'ualp_twilio_to' );
		$twilio_sid   = get_option( 'ualp_twilio_api_sid' );
		$twilio_token = get_option( 'ualp_twilio_api_auth_token' );
		try {
			$client   = new Client( $twilio_sid, $twilio_token );
			$response = $client->messages->create(
				$to,
				array(
					'from' => $sender_id,
					'body' => $message,
				)
			);
			self::display_success();
		} catch ( Exception $e ) {
			self::display_error( $e->getMessage() );
		}
	}
	/**
	 * Designs for displaying Notices.
	 *
	 * @since    1.0.0
	 * @param string $message - String - The message we are displaying.
	 * @param bool   $status   - Boolean - its either true or false.
	 */
	public static function admin_notice( $message, $status = true ) {
		$class = ( $status ) ? 'notice notice-success' : 'notice notice-error';
		printf( '<div class="%1$s"><p>%2$s</p></div>', esc_attr( $class ), esc_html( $message ) );
	}
	/**
	 * Displays Error Notices.
	 *
	 * @param string $message Message.
	 */
	public static function display_error( $message = 'Aww!, there was an error.' ) {
		add_action(
			'admin_notices',
			function() use ( $message ) {
				self::admin_notice( $message, false );
			}
		);
	}
	/**
	 * Displays Success Notices
	 *
	 * @param string $message Message.
	 */
	public static function display_success( $message = 'Successful!' ) {
		add_action(
			'admin_notices',
			function() use ( $message ) {
				self::admin_notice( $message, true );
			}
		);
	}


}
$ualp_twilio_sms = new Ualp_Twilio_SMS();
