<?php
/**
 * Export Logs.
 *
 * @package User Activity Log PRO
 */

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'ualp_export_user_log' ) ) {
	/**
	 * Export logs in csv format.
	 *
	 * @param string $userrole User Role.
	 * @param string $username User Name.
	 * @param string $type Type.
	 * @param string $ip IP Address.
	 * @param string $country Country.
	 * @param string $user_agent User Agent.
	 * @param string $time Time.
	 * @param string $start_date Start Date.
	 * @param string $end_date End Date.
	 * @param string $hook Hook.
	 * @param string $favorite Favorite.
	 * @param string $search Search.
	 * @param string $t_session Session.
	 * @param string $site_id Site ID.
	 * @param string $logformat Log Format.
	 * @param string $showallpost Show All Posts.
	 * @param string $showposttype Show Post Type.
	 */
	function ualp_export_user_log( $userrole, $username, $type, $ip, $country, $user_agent, $time, $start_date, $end_date, $hook, $favorite, $search, $t_session, $site_id, $logformat, $showallpost, $showposttype ) {
		global $wpdb, $query, $externaldb;
		$header = array();
		$where  = ' where 1 = 1';
		if ( isset( $userrole ) && '' != $userrole ) {
			$where .= " AND user_role LIKE '%%$userrole%%'";
		}
		if ( isset( $username ) && '' != $username ) {
			$where .= " AND user_name like '$username'";
		}
		if ( isset( $type ) && '' != $type ) {
			$where .= " AND object_type like '$type'";
		}
		if ( isset( $ip ) && '' != $ip ) {
			$where .= " AND ip_address like '$ip'";
		}
		if ( isset( $country ) && '' != $country ) {
			$where .= " AND country like '$country'";
		}
		if ( isset( $user_agent ) && '' != $user_agent ) {
			$where .= " AND user_agent like '$user_agent'";
		}

		if ( isset( $favorite ) && '' != $favorite ) {
			$where .= " AND favorite like '$favorite'";
		}
		if ( isset( $t_session ) && '' != $t_session ) {
			$where .= " AND t_session like '$t_session'";
		}
		if ( isset( $site_id ) && '' != $site_id ) {
			$where .= " AND site_id like '$site_id'";
		}
		if ( isset( $hook ) && 'transition_post_status' == $hook ) {
			if ( isset( $showposttype ) && '' != $showposttype ) {
				$where .= " AND object_type = '" . $showposttype . "'";
			}
			if ( isset( $showallpost ) && '' != $showallpost ) {
				$where .= " AND post_id = '" . $showallpost . "'";
			}
			if ( isset( $hook ) && '' != $hook && isset( $showposttype ) && '' == $showposttype && isset( $showallpost ) && '' == $showallpost ) {
				$where .= " AND hook like '$hook'";
			}
		} elseif ( isset( $hook ) && '' != $hook ) {
			$where .= " AND hook like '$hook'";
		}

		if ( isset( $time ) && '' != $time ) {
			$current_time = current_time( 'timestamp' );

			$start_time = mktime( 0, 0, 0, gmdate( 'm', $current_time ), gmdate( 'd', $current_time ), gmdate( 'Y', $current_time ) );
			$end_time   = mktime( 23, 59, 59, gmdate( 'm', $current_time ), gmdate( 'd', $current_time ), gmdate( 'Y', $current_time ) );

			if ( 'today' == $time ) {
				$start_time = $current_time;
				$start_time = strtotime( 'today' );
				$end_time   = strtotime( '+1 day', $current_time );
			} elseif ( 'yesterday' === $time ) {
				$start_time = strtotime( 'yesterday', $start_time );
				$end_time   = $current_time;
			} elseif ( 'week' === $time ) {
				$start_time = strtotime( '-1 week', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );
			} elseif ( 'this-month' === $time ) {
				$start_time = gmdate( 'Y-m-01' );
				$start_time = strtotime( $start_time );

				$end_time = gmdate( 'Y-m-31' );
				$end_time = strtotime( $end_time );
			} elseif ( 'month' === $time ) {
				$start_time = strtotime( '-1 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );
			} elseif ( '2-month' === $time ) {
				$start_time = strtotime( '-2 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );
			} elseif ( '3-month' === $time ) {
				$start_time = strtotime( '-3 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );
			} elseif ( '6-month' === $time ) {
				$start_time = strtotime( '-6 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );
			} elseif ( 'this-year' === $time ) {
				$start_time = gmdate( 'Y-01-01' );
				$start_time = strtotime( $start_time );

				$end_time = gmdate( 'Y-12-31' );
				$end_time = strtotime( $end_time );
			} elseif ( 'last-year' === $time ) {
				$start_time = gmdate( 'Y-01-01' );
				$start_time = strtotime( $start_time );
				$start_time = strtotime( '-1 year', $start_time );

				$end_time = gmdate( 'Y-12-31' );
				$end_time = strtotime( $end_time );
				$end_time = strtotime( '-1 year', $end_time );
			} elseif ( 'custom' === $time ) {
				if ( isset( $start_date ) && '' != $start_date ) {
					$custom_start_date = $start_date;
					$start_time        = strtotime( $custom_start_date . ' 23:59:59' );
					if ( gmdate( 'Y-m-d H:i:s', $start_time ) > gmdate( 'Y-m-d' ) ) {
						$start_time = strtotime( $custom_start_date . ' 23:59:59' );
					} else {
						$start_time = strtotime( '-1 day', $start_time );
					}
				}
				if ( isset( $end_date ) && '' != $end_date ) {
					$end_time = strtotime( $end_date . ' 23:59:59' );
					$end_time = strtotime( '+1 day', $end_time );
				}
			}

			if ( '' != $start_time ) {
				$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
			}
			if ( '' != $end_time ) {
				$end_time = gmdate( 'Y-m-d H:i:s', $end_time );
			}
			if ( '' != $start_time ) {
				if ( 'custom' === $time ) {
					$where .= " AND modified_date >= '$start_time' ";
				} else {
					$where .= " AND modified_date > '$start_time' ";
				}
			}
			if ( '' != $end_time ) {
				$where .= " AND modified_date < '$end_time'";
			}
		}
		if ( isset( $search ) && '' != $search ) {
			$where .= " AND user_name like '$search' or user_role like '$search' or object_type like '$search' or action like '$search'";
		}

		$get_log_query    = 'SELECT * FROM ' . UALP_TABLENAME . " $where ORDER BY modified_date desc";
		$result_log_query = $externaldb->get_results( $get_log_query );
		$data_content     = array();
		$c                = 0;
		$date_format      = get_option( 'date_format' );
		$time_format      = get_option( 'time_format' );
		$logged_head      = '';

		if ( ! empty( $result_log_query ) ) {
			foreach ( $result_log_query as $result_log ) {
				$c++;
				$result_log = (array) $result_log;
				if ( ! ualp_allow_ip() ) {
					if ( isset( $result_log['ip_address'] ) ) {
						unset( $result_log['ip_address'] );
					}
				}
				if ( ! ualp_allow_country() ) {
					unset( $result_log['country'] );
				}
				if ( ! ualp_allow_user_agent() ) {
					if ( isset( $result_log['user_agent'] ) ) {
						unset( $result_log['user_agent'] );
					}
				}
				if ( isset( $result_log['uactid'] ) ) {
					$result_log['uactid'] = $c;
				}
				if ( isset( $result_log['favorite'] ) ) {
					if ( 1 == $result_log['favorite'] ) {
						$result_log['favorite'] = 'Yes';
					} elseif ( 0 == $result_log['favorite'] ) {
						$result_log['favorite'] = 'No';
					}
				}
				if ( isset( $result_log['modified_date'] ) ) {
					$get_date                    = strtotime( $result_log['modified_date'] );
					$date                        = gmdate( $date_format, $get_date );
					$time                        = gmdate( $time_format, $get_date );
					$result_log['modified_date'] = $date . ' ' . $time;
				}
				if ( isset( $result_log['description'] ) ) {
					if ( '' == $result_log['description'] ) {
						$action                    = '';
						$post_title                = '';
						$action                    = $result_log['action'];
						$post_title                = $result_log['post_title'];
						$result_log['description'] = $action . ' : ' . $post_title;
					} else {
						$result_log['description'] = html_entity_decode( $result_log['description'] );
					}
				}
				if ( isset( $result_log['site_id'] ) ) {
					unset( $result_log['site_id'] );
				}
				unset( $result_log['post_id'] );
				unset( $result_log['user_id'] );
				unset( $result_log['post_title'] );
				unset( $result_log['action'] );
				unset( $result_log['t_session'] );
				if ( 'yes' != $logged_head ) {
					foreach ( $result_log as $result_log_key => $result_log_val ) {
						if ( ! in_array( $result_log_key, $header ) ) {
							$header[] = $result_log_key;
						}
					}
					$result_log[ $result_log_key ] = html_entity_decode( $result_log_val );
				}
				$logged_head    = 'yes';
				$data_content[] = $result_log;
			}
		}
		if ( 'csv' == $logformat ) {
			$header       = array_values( $header );
			$count_header = count( $header );
			for ( $h = 0;$h < $count_header;$h++ ) {
				if ( 'uactid' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Sr No.', 'user_activity_log_pro' );
				}
				if ( 'user_name' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Author Name', 'user_activity_log_pro' );
				}
				if ( 'user_role' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Author Role', 'user_activity_log_pro' );
				}
				if ( 'user_email' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Author E-mail', 'user_activity_log_pro' );
				}
				if ( ualp_allow_ip() ) {
					if ( 'ip_address' == $header[ $h ] ) {
						$header[ $h ] = esc_html__( 'IP Address', 'user_activity_log_pro' );
					}
				}
				if ( ualp_allow_country() ) {
					if ( 'country' == $header[ $h ] ) {
						$header[ $h ] = esc_html__( 'Country', 'user_activity_log_pro' );
					}
				}
				if ( ualp_allow_user_agent() ) {
					if ( 'user_agent' == $header[ $h ] ) {
						$header[ $h ] = esc_html__( 'User Agent', 'user_activity_log_pro' );
					}
				}
				if ( 'modified_date' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Date', 'user_activity_log_pro' );
				}
				if ( 'object_type' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Activity Type', 'user_activity_log_pro' );
				}
				if ( 'hook' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Activity Hook', 'user_activity_log_pro' );
				}
				if ( 'description' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Description', 'user_activity_log_pro' );
				}
				if ( 'favorite' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Favorite?', 'user_activity_log_pro' );
				}
			}
			$export_delimiter = ',';
			$random_id        = wp_rand();
			$csv_file_name    = 'export_user_logs_' . gmdate( 'Y-m-d_H-i-s', time() ) . '.csv';
			ualp_csv_output( $csv_file_name, $data_content, $header, $export_delimiter );
		}
		if ( 'json' == $logformat ) {
			$json_file_name = 'export_user_logs_' . gmdate( 'Y-m-d_H-i-s', time() ) . '.json';
			ualp_json_output( $json_file_name, $data_content );
		}
		do_action( 'ualp_export_activity_log' );
	}
}

if ( ! function_exists( 'ualp_csv_output' ) ) {
	/**
	 * CSV Output.
	 *
	 * @param string $filename Data.
	 * @param array  $data Fields.
	 * @param array  $fields Data.
	 * @param string $delimiter Delimiter.
	 */
	function ualp_csv_output( $filename = null, $data = array(), $fields = array(), $delimiter = null ) {
		if ( null === $delimiter ) {
			$delimiter = ',';
		}
		$random_id = wp_rand();
		$filename  = 'export_user_logs_' . gmdate( 'Y-m-d_H-i-s', time() ) . '.csv';
		if ( $filename ) {
			$data = ualp_unparse( $data, $fields, null, null, $delimiter );
			header( 'Content-type: application/csv' );
			header( 'Content-Disposition: attachment; filename="' . $filename . '"' );
			echo $data;
		}
		return $data;
	}
}

if ( ! function_exists( 'ualp_unparse' ) ) {
	/**
	 * Un Parse the data.
	 *
	 * @param array  $data Data.
	 * @param array  $fields Fields.
	 * @param bool   $append Data.
	 * @param bool   $is_php Data.
	 * @param string $delimiter Delimiter.
	 */
	function ualp_unparse( $data = array(), $fields = array(), $append = false, $is_php = false, $delimiter = null ) {
		$linefeed = "\r\n";
		$string   = ( $is_php ) ? "<?php header('Status: 403'); die(' '); ?>" . $linefeed : '';
		$entry    = array();
		// create heading.
		if ( ! empty( $fields ) ) {
			foreach ( $fields as $key => $value ) {
				$entry[] = ualp_enclose_value( $value );
			}
			$string .= implode( $delimiter, $entry ) . $linefeed;
			$entry   = array();
		}
		// create data.
		foreach ( $data as $key => $row ) {
			foreach ( $row as $field => $value ) {
				$entry[] = ualp_enclose_value( $value );
			}
			$string .= implode( $delimiter, $entry ) . $linefeed;
			$entry   = array();
		}
		return $string;
	}
}

if ( ! function_exists( 'ualp_enclose_value' ) ) {
	/**
	 * Enclose Value.
	 *
	 * @param string $value Value.
	 */
	function ualp_enclose_value( $value = null ) {
		$this_delimiter = ',';
		$this_enclosure = '"';
		if ( null !== $value && '' != $value ) {
			$delimiter = preg_quote( $this_delimiter, '/' );
			$enclosure = preg_quote( $this_enclosure, '/' );
			if ( isset( $value[0] ) == '=' ) {
				$value = '' . $value;
			}
			if ( preg_match( '/' . $delimiter . '|' . $enclosure . "|\n|\r/i", $value ) || ( isset( $value[0] ) == ' ' || substr( $value, -1 ) == ' ' ) ) {
				$value = str_replace( $this_enclosure, $this_enclosure . $this_enclosure, $value );
				$value = $this_enclosure . $value . $this_enclosure;
			}
		}
		return $value;
	}
}
add_action( 'admin_init', 'ualp_export_log' );
if ( ! function_exists( 'ualp_export_log' ) ) {
	/**
	 * Export Log.
	 */
	function ualp_export_log() {
		if ( is_admin() && is_user_logged_in() ) {
			if ( isset( $_GET['export'] ) && 'user_logs' == $_GET['export'] && isset( $_GET['export-nonce'] ) && '' != $_GET['export-nonce'] ) {
				$userrole     = '';
				$username     = '';
				$type         = '';
				$ip           = '';
				$time         = '';
				$search       = '';
				$start_date   = '';
				$end_date     = '';
				$user_agent   = '';
				$t_session    = '';
				$site_id      = '';
				$logformat    = '';
				$showallpost  = '';
				$showposttype = '';
				if ( isset( $_GET['userrole'] ) ) {
					$userrole = sanitize_text_field( wp_unslash( $_GET['userrole'] ) );
				}
				if ( isset( $_GET['username'] ) ) {
					$username = sanitize_text_field( wp_unslash( $_GET['username'] ) );
				}
				if ( isset( $_GET['type'] ) ) {
					$type = sanitize_text_field( wp_unslash( $_GET['type'] ) );
				}
				if ( isset( $_GET['ip'] ) ) {
					$ip = sanitize_text_field( wp_unslash( $_GET['ip'] ) );
				}
				if ( isset( $_GET['country'] ) ) {
					$country = sanitize_text_field( wp_unslash( $_GET['country'] ) );
				}
				if ( isset( $_GET['user_agent'] ) ) {
					$user_agent = sanitize_text_field( wp_unslash( $_GET['user_agent'] ) );
				}
				if ( isset( $_GET['time'] ) ) {
					$time = sanitize_text_field( wp_unslash( $_GET['time'] ) );
				}
				if ( isset( $_GET['hook'] ) ) {
					$hook = sanitize_text_field( wp_unslash( $_GET['hook'] ) );
				}
				if ( isset( $_GET['favorite'] ) ) {
					$favorite = sanitize_text_field( wp_unslash( $_GET['favorite'] ) );
				}
				if ( isset( $_GET['txtsearch'] ) ) {
					$search = sanitize_text_field( wp_unslash( $_GET['txtsearch'] ) );
				}
				if ( isset( $_GET['start_date'] ) ) {
					$start_date = sanitize_text_field( wp_unslash( $_GET['start_date'] ) );
				}
				if ( isset( $_GET['end_date'] ) ) {
					$end_date = sanitize_text_field( wp_unslash( $_GET['end_date'] ) );
				}
				if ( isset( $_GET['t_session'] ) ) {
					$t_session = sanitize_text_field( wp_unslash( $_GET['t_session'] ) );
				}
				if ( isset( $_GET['showsiteid'] ) ) {
					$site_id = sanitize_text_field( wp_unslash( $_GET['showsiteid'] ) );
				}
				if ( isset( $_GET['logformat'] ) ) {
					$logformat = sanitize_text_field( wp_unslash( $_GET['logformat'] ) );
				}
				if ( isset( $_GET['showallpost'] ) ) {
					$showallpost = sanitize_text_field( wp_unslash( $_GET['showallpost'] ) );
				}
				if ( isset( $_GET['showposttype'] ) ) {
					$showposttype = sanitize_text_field( wp_unslash( $_GET['showposttype'] ) );
				}
				ualp_export_user_log( $userrole, $username, $type, $ip, $country, $user_agent, $time, $start_date, $end_date, $hook, $favorite, $search, $t_session, $site_id, $logformat, $showallpost, $showposttype );
				exit();
			}
		}
	}
}

if ( ! function_exists( 'ualp_send_csv_in_email' ) ) {
	/**
	 * Send CSV file in email.
	 */
	function ualp_send_csv_in_email() {
		$current_user = wp_get_current_user();
		$f_name       = $current_user->user_firstname;
		$l_name       = $current_user->user_lastname;
		$to           = $current_user->user_email;
		$from         = get_option( 'ualpFromEmail' );
		$headers      = "MIME-Version: 1.0;\r\n";
		$headers     .= 'From: ' . wp_strip_all_tags( $from ) . "\r\n";
		$headers     .= "Content-Type: text/html; charset: utf-8;\r\n";
		$headers     .= "X-Priority: 3\r\n";
		$headers     .= 'X-Mailer: PHP' . phpversion() . "\r\n";
		$subject      = esc_html__( 'User Activity Log file', 'user_activity_log_pro' ) . ' - ' . __( 'User Activity Log Pro', 'user_activity_log_pro' );
		$attachment   = ualp_generate_csv_attachment();
		$body         = '';
		ob_start();
		?>
		<div style="background: #F5F5F5; border-width: 1px; border-style: solid; padding-bottom: 20px; margin: 0px auto; width: 750px; height: auto; border-radius: 3px 3px 3px 3px; border-color: #5C5C5C;">
			<div style="border: #FFF 1px solid; background-color: #ffffff !important; margin: 20px 20px 0;height: auto; -moz-border-radius: 3px; padding-top: 15px;">
				<div style="padding: 20px 20px 20px 20px; font-family: Arial, Helvetica, sans-serif;height: auto; color: #333333; font-size: 13px;">
					<div style="width: 100%;">
						<strong><?php esc_html_e( 'Dear', 'user_activity_log_pro' ); ?> <?php echo esc_html( $f_name ); ?> </strong>,<br /><br />
						<?php esc_html_e( 'Here is the attachment of users activity log file of your', 'user_activity_log_pro' ); ?> <a href="<?php echo esc_url( home_url() ); ?>"><?php esc_html_e( 'website', 'user_activity_log_pro' ); ?></a>.<br /><br />
					</div>
				</div>
			</div>
		</div>
		<?php
		$body = ob_get_clean();
		$sent = wp_mail( $to, $subject, $body, $headers, $attachment );
		return $sent;
	}
}

if ( ! function_exists( 'ualp_generate_csv_attachment' ) ) {
	/**
	 * Generate CSV Attachment.
	 */
	function ualp_generate_csv_attachment() {
		require_once ABSPATH . 'wp-admin/includes/file.php';

		global $wpdb, $query, $externaldb;
		$c           = 0;
		$csv_content = array();
		$header      = array();
		$date_format = get_option( 'date_format' );
		$time_format = get_option( 'time_format' );

		$csv_file_path     = WP_CONTENT_DIR . '/uploads/export_user_logs_' . gmdate( 'Y-m-d_H-i-s', time() ) . '.csv';
		$ualp_file_handler = fopen( $csv_file_path, 'w' );
		$get_log_query     = 'SELECT * FROM ' . UALP_TABLENAME;

		$result_log_query = $externaldb->get_results( $get_log_query );
		$result           = $externaldb->get_col( $get_log_query );

		if ( false === $ualp_file_handler ) {
			wp_die( esc_html__( 'Failed to open export file', 'user_activity_log_pro' ) );
		}
		if ( ! empty( $result_log_query ) ) {
			foreach ( $result_log_query as $result_log ) {
				foreach ( $result_log as $result_log_key => $result_log_val ) {
					if ( 'post_id' != $result_log_key && 'user_id' != $result_log_key && 'post_title' != $result_log_key && 'action' != $result_log_key ) {
						if ( ! in_array( $result_log_key, $header ) ) {
							$header[] = $result_log_key;
						}
					}
				}
			}
		}
		foreach ( $header as $header_key ) {
			if ( is_array( $result_log_query ) ) {
				foreach ( $result_log_query as $key => $val ) {
					$c++;
					if ( array_key_exists( $header_key, array( $val ) ) ) {
						if ( 'uactid' == $header_key ) {
							$csv_content[ $key ][ $header_key ] = $c;
						} elseif ( 'favorite' == $header_key ) {
							if ( 1 == $result_log_query[ $key ]->$header_key ) {
								$csv_content[ $key ][ $header_key ] = 'Yes';
							}
							if ( 0 == $result_log_query[ $key ]->$header_key ) {
								$csv_content[ $key ][ $header_key ] = 'No';
							}
						} elseif ( 'modified_date' == $header_key ) {
							$get_date                           = strtotime( $result_log_query[ $key ]->$header_key );
							$date                               = gmdate( $date_format, $get_date );
							$time                               = gmdate( $time_format, $get_date );
							$csv_content[ $key ][ $header_key ] = $date . ' ' . $time;
						} elseif ( ualp_multi_site_support_return() && 'site_id' == $header_key ) {
							$siteid                             = $result_log_query[ $key ]->$header_key;
							$getsitename                        = get_blog_details( $siteid );
							$csv_content[ $key ][ $header_key ] = $getsitename->blogname;
						} elseif ( 'description' == $header_key ) {
							if ( '' == $result_log_query[ $key ]->$header_key ) {
								$action                             = '';
								$post_title                         = '';
								$action                             = $result_log_query[ $key ]->action;
								$post_title                         = $result_log_query[ $key ]->post_title;
								$csv_content[ $key ][ $header_key ] = $action . ' : ' . $post_title;
							} else {
								$csv_content[ $key ][ $header_key ] = html_entity_decode( $result_log_query[ $key ]->$header_key );
							}
						} else {
							$csv_content[ $key ][ $header_key ] = ' : ' . html_entity_decode( $result_log_query[ $key ]->$header_key ) . ' : ';
						}
					} else {
						$csv_content[ $key ][ $header_key ] = null;
					}
				}
			}
		}
		$count_header = count( $header );
		for ( $h = 0;$h < $count_header;$h++ ) {
			if ( 'uactid' == $header[ $h ] ) {
				$header[ $h ] = esc_html__( 'Sr No.', 'user_activity_log_pro' );
			}
			if ( 'user_name' == $header[ $h ] ) {
				$header[ $h ] = esc_html__( 'Author Name', 'user_activity_log_pro' );
			}
			if ( 'user_role' == $header[ $h ] ) {
				$header[ $h ] = esc_html__( 'Author Role', 'user_activity_log_pro' );
			}
			if ( 'user_email' == $header[ $h ] ) {
				$header[ $h ] = esc_html__( 'Author E-mail', 'user_activity_log_pro' );
			}
			if ( ualp_allow_ip() ) {
				if ( 'ip_address' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'IP Address', 'user_activity_log_pro' );
				}
			}
			if ( ualp_allow_country() ) {
				if ( 'country' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Country', 'user_activity_log_pro' );
				}
			}
			if ( 'modified_date' == $header[ $h ] ) {
				$header[ $h ] = esc_html__( 'Date', 'user_activity_log_pro' );
			}
			if ( 'object_type' == $header[ $h ] ) {
				$header[ $h ] = esc_html__( 'Activity Type', 'user_activity_log_pro' );
			}
			if ( 'hook' == $header[ $h ] ) {
				$header[ $h ] = esc_html__( 'Activity Hook', 'user_activity_log_pro' );
			}
			if ( 'description' == $header[ $h ] ) {
				$header[ $h ] = esc_html__( 'Description', 'user_activity_log_pro' );
			}
			if ( 'favorite' == $header[ $h ] ) {
				$header[ $h ] = esc_html__( 'Favorite?', 'user_activity_log_pro' );
			}
		}
		fputcsv( $ualp_file_handler, $header );
		foreach ( $csv_content as $record ) {
			fputcsv( $ualp_file_handler, $record );
		}
		rewind( $ualp_file_handler );
		fclose( $ualp_file_handler );
		return $csv_file_path;
	}
}

if ( ! function_exists( 'ualp_export_user_logged_log' ) ) {
	/**
	 * Export User activity logged in csv format.
	 *
	 * @param string $username User Name.
	 * @param string $user_role User Role.
	 * @param string $ip IP Address.
	 * @param string $country Country.
	 * @param string $user_agent User Agent.
	 * @param string $search Search.
	 * @param string $loginstatus Login Status.
	 * @param string $timelogin Time Login.
	 * @param string $timelogout Time Logout.
	 * @param string $site_id Site ID.
	 * @param string $logformat Log Format.
	 * @param string $login_start_date Start Date.
	 * @param string $login_end_date End Date.
	 * @param string $logout_start_date Start Date.
	 * @param string $logout_end_date End Date.
	 */
	function ualp_export_user_logged_log( $username, $user_role, $ip, $country, $user_agent, $search, $loginstatus, $timelogin, $timelogout, $site_id, $logformat, $login_start_date, $login_end_date, $logout_start_date, $logout_end_date ) {
		global $wpdb, $query, $externaldb;
		$header = array();
		$where  = ' where 1 = 1';
		if ( isset( $username ) && '' != $username ) {
			$where .= " AND user_name like '$username'";
		}
		if ( isset( $user_role ) && '' != $user_role ) {
			$where .= " AND user_role LIKE '%%$user_role%%'";
		}
		if ( isset( $ip ) && '' != $ip ) {
			$where .= " AND ip_address like '$ip'";
		}
		if ( isset( $country ) && '' != $country ) {
			$where .= " AND country like '$country'";
		}
		if ( isset( $user_agent ) && '' != $user_agent ) {
			$where .= " AND user_agent like '$user_agent'";
		}
		if ( isset( $search ) && '' != $search ) {
			$where .= " AND user_name like '$search'";
		}
		if ( isset( $loginstatus ) && '' != $loginstatus ) {
			$where .= " AND login_status like '$loginstatus'";
		}
		if ( isset( $timelogin ) && '' != $timelogin ) {
			if ( isset( $timelogin ) && '' != $timelogin ) {
				$current_time = current_time( 'timestamp' );

				$start_time = mktime( 0, 0, 0, gmdate( 'm', $current_time ), gmdate( 'd', $current_time ), gmdate( 'Y', $current_time ) );
				$end_time   = mktime( 23, 59, 59, gmdate( 'm', $current_time ), gmdate( 'd', $current_time ), gmdate( 'Y', $current_time ) );

				if ( 'today' === $timelogin ) {
					$start_time = $current_time;
					$end_time   = strtotime( '+1 day', $current_time );
				} elseif ( 'yesterday' === $timelogin ) {
					$start_time = strtotime( 'yesterday', $start_time );
					$end_time   = $current_time;
				} elseif ( 'week' === $timelogin ) {
					$start_time = strtotime( '-1 week', $start_time );
					$end_time   = strtotime( '+1 day', $current_time );
				} elseif ( 'this-month' === $timelogin ) {
					$start_time = gmdate( 'Y-m-01' );
					$start_time = strtotime( $start_time );

					$end_time = gmdate( 'Y-m-31' );
					$end_time = strtotime( $end_time );
				} elseif ( 'month' === $timelogin ) {
					$start_time = strtotime( '-1 month', $start_time );
					$end_time   = strtotime( '+1 day', $current_time );
				} elseif ( '2-month' === $timelogin ) {
					$start_time = strtotime( '-2 month', $start_time );
					$end_time   = strtotime( '+1 day', $current_time );
				} elseif ( '3-month' === $timelogin ) {
					$start_time = strtotime( '-3 month', $start_time );
					$end_time   = strtotime( '+1 day', $current_time );
				} elseif ( '6-month' === $timelogin ) {
					$start_time = strtotime( '-6 month', $start_time );
					$end_time   = strtotime( '+1 day', $current_time );
				} elseif ( 'this-year' === $timelogin ) {
					$start_time = gmdate( 'Y-01-01' );
					$start_time = strtotime( $start_time );

					$end_time = gmdate( 'Y-12-31' );
					$end_time = strtotime( $end_time );
				} elseif ( 'last-year' === $timelogin ) {
					$start_time = gmdate( 'Y-01-01' );
					$start_time = strtotime( $start_time );
					$start_time = strtotime( '-1 year', $start_time );

					$end_time = gmdate( 'Y-12-31' );
					$end_time = strtotime( $end_time );
					$end_time = strtotime( '-1 year', $end_time );
				} elseif ( 'custom' === $timelogin ) {
					if ( isset( $login_start_date ) && '' != $login_start_date ) {
						$custom_start_date = $login_start_date;
						$login_start_date  = strtotime( $custom_start_date . ' 23:59:59' );
						if ( gmdate( 'Y-m-d H:i:s', $login_start_date ) > gmdate( 'Y-m-d' ) ) {
							$login_start_date = strtotime( $custom_start_date . ' 23:59:59' );
						} else {
							$login_start_date = strtotime( '-1 day', $login_start_date );
						}
						$start_time = gmdate( 'Y-m-d H:i:s', $login_start_date );
					}
					if ( isset( $login_end_date ) && '' != $login_end_date ) {
						$end_time = strtotime( $login_end_date . ' 23:59:59' );
						$end_time = strtotime( '+1 day', $end_time );
						$end_time = gmdate( 'Y-m-d H:i:s', $end_time );
					}
				}
				if ( '' != $start_time ) {
					if ( 'custom' === $timelogin ) {
						$where .= " AND time_login >= '$start_time' ";
					} else {
						$where .= " AND time_login > '$start_time' ";
					}
				}
				if ( '' != $end_time ) {
					$where .= " AND time_login < '$end_time'";
				}
			}
		}
		if ( isset( $timelogout ) && '' != $timelogout ) {
			if ( isset( $timelogout ) && '' != $timelogout ) {
				$current_time = current_time( 'timestamp' );

				$start_time = mktime( 0, 0, 0, gmdate( 'm', $current_time ), gmdate( 'd', $current_time ), gmdate( 'Y', $current_time ) );
				$end_time   = mktime( 23, 59, 59, gmdate( 'm', $current_time ), gmdate( 'd', $current_time ), gmdate( 'Y', $current_time ) );

				if ( 'today' === $timelogout ) {
					$start_time = $current_time;
					$end_time   = strtotime( '+1 day', $current_time );

					$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
					$end_time   = gmdate( 'Y-m-d H:i:s', $end_time );
				} elseif ( 'yesterday' === $timelogout ) {
					$start_time = strtotime( 'yesterday', $start_time );

					$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
					$end_time   = gmdate( 'Y-m-d H:i:s', $end_time );
					$end_time   = $current_time;
				} elseif ( 'week' === $timelogout ) {
					$start_time = strtotime( '-1 week', $start_time );
					$end_time   = strtotime( '+1 day', $current_time );

					$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
					$end_time   = gmdate( 'Y-m-d H:i:s', $end_time );
				} elseif ( 'this-month' === $timelogout ) {
					$start_time = gmdate( 'Y-m-01' );
					$start_time = strtotime( $start_time );

					$end_time = gmdate( 'Y-m-31' );
					$end_time = strtotime( $end_time );

					$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
					$end_time   = gmdate( 'Y-m-d H:i:s', $end_time );
				} elseif ( 'month' === $timelogout ) {
					$start_time = strtotime( '-1 month', $start_time );
					$end_time   = strtotime( '+1 day', $current_time );

					$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
					$end_time   = gmdate( 'Y-m-d H:i:s', $end_time );
				} elseif ( '2-month' === $timelogout ) {
					$start_time = strtotime( '-2 month', $start_time );
					$end_time   = strtotime( '+1 day', $current_time );

					$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
					$end_time   = gmdate( 'Y-m-d H:i:s', $end_time );
				} elseif ( '3-month' === $timelogout ) {
					$start_time = strtotime( '-3 month', $start_time );
					$end_time   = strtotime( '+1 day', $current_time );

					$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
					$end_time   = gmdate( 'Y-m-d H:i:s', $end_time );
				} elseif ( '6-month' === $timelogout ) {
					$start_time = strtotime( '-6 month', $start_time );
					$end_time   = strtotime( '+1 day', $current_time );

					$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
					$end_time   = gmdate( 'Y-m-d H:i:s', $end_time );
				} elseif ( 'this-year' === $timelogout ) {
					$start_time = gmdate( 'Y-01-01' );
					$start_time = strtotime( $start_time );

					$end_time = gmdate( 'Y-12-31' );
					$end_time = strtotime( $end_time );

					$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
					$end_time   = gmdate( 'Y-m-d H:i:s', $end_time );
				} elseif ( 'last-year' === $timelogout ) {
					$start_time = gmdate( 'Y-01-01' );
					$start_time = strtotime( $start_time );
					$start_time = strtotime( '-1 year', $start_time );

					$end_time   = gmdate( 'Y-12-31' );
					$end_time   = strtotime( $end_time );
					$end_time   = strtotime( '-1 year', $end_time );
					$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
					$end_time   = gmdate( 'Y-m-d H:i:s', $end_time );
				} elseif ( 'custom' === $timelogout ) {
					if ( isset( $logout_start_date ) && '' != $logout_start_date ) {
						$custom_start_date = $logout_start_date;
						$logout_start_date = strtotime( $custom_start_date . ' 23:59:59' );
						if ( gmdate( 'Y-m-d H:i:s', $logout_start_date ) > gmdate( 'Y-m-d' ) ) {
							$logout_start_date = strtotime( $custom_start_date . ' 23:59:59' );
						} else {
							$logout_start_date = strtotime( '-1 day', $logout_start_date );
						}
						$start_time = gmdate( 'Y-m-d H:i:s', $logout_start_date );
					}
					if ( isset( $logout_end_date ) && '' != $logout_end_date ) {
						$end_time = strtotime( $logout_end_date . ' 23:59:59' );
						$end_time = strtotime( '+1 day', $end_time );
						$end_time = gmdate( 'Y-m-d H:i:s', $end_time );
					}
				}
				if ( '' != $start_time ) {
					if ( 'custom' === $timelogout ) {
						$where .= " AND time_login >= '$start_time' ";
					} else {
						$where .= " AND time_login > '$start_time' ";
					}
				}
				if ( '' != $end_time ) {
					$where .= " AND time_login < '$end_time'";
				}
			}
		}
		if ( isset( $site_id ) && '' != $site_id ) {
			$where .= " AND site_id like '$site_id'";
		}
		$get_log_query = 'SELECT * FROM ' . UALP_LOGIN_TABLENAME . " $where ORDER BY time_login desc";

		$result_log_query = $externaldb->get_results( $get_log_query );
		// exit;.
		$data_content = array();
		$c            = 0;
		$date_format  = get_option( 'date_format' );
		$time_format  = get_option( 'time_format' );
		$logged_head  = '';

		if ( ! empty( $result_log_query ) ) {
			foreach ( $result_log_query as $result_log ) {
				$c++;
				$result_log = (array) $result_log;
				if ( ! ualp_allow_ip() ) {
					if ( isset( $result_log['ip_address'] ) ) {
						unset( $result_log['ip_address'] );
					}
				}
				if ( ! ualp_allow_country() ) {
					if ( isset( $result_log['country'] ) ) {
						unset( $result_log['country'] );
					}
				}
				if ( isset( $result_log['uacltid'] ) ) {
					$result_log['uacltid'] = $c;
				}
				if ( isset( $result_log['time_login'] ) ) {
					$time_login               = strtotime( $result_log['time_login'] );
					$date                     = gmdate( $date_format, $time_login );
					$time                     = gmdate( $time_format, $time_login );
					$result_log['time_login'] = $date . ' ' . $time;
				}
				if ( isset( $result_log['time_logout'] ) ) {
					$time_logout               = strtotime( $result_log['time_logout'] );
					$date                      = gmdate( $date_format, $time_logout );
					$time                      = gmdate( $time_format, $time_logout );
					$result_log['time_logout'] = $date . ' ' . $time;
				}
				if ( isset( $result_log['time_last_seen'] ) ) {
					$time_last_seen               = strtotime( $result_log['time_last_seen'] );
					$date                         = gmdate( $date_format, $time_last_seen );
					$time                         = gmdate( $time_format, $time_last_seen );
					$result_log['time_last_seen'] = $date . ' ' . $time;
				}
				if ( isset( $result_log['user_agent'] ) ) {
					$result_log['user_agent'] = $result_log['user_agent'];
				} else {
					$result_log['user_agent'] = '';
				}
				if ( isset( $result_log['site_id'] ) ) {
					unset( $result_log['site_id'] );
				}
				unset( $result_log['user_role'] );
				unset( $result_log['expiration'] );
				unset( $result_log['session_token'] );
				unset( $result_log['user_id'] );
				unset( $result_log['action'] );
				unset( $result_log['t_session'] );
				if ( 'yes' != $logged_head ) {
					foreach ( $result_log as $result_log_key => $result_log_val ) {
						if ( ! in_array( $result_log_key, $header ) ) {
							$header[] = $result_log_key;
						}
					}
					$result_log[ $result_log_key ] = html_entity_decode( $result_log_val );
				}
				$logged_head    = 'yes';
				$data_content[] = $result_log;
			}
		}
		if ( 'csv' == $logformat ) {
			$header       = array_values( $header );
			$count_header = count( $header );
			for ( $h = 0;$h < $count_header;$h++ ) {
				if ( 'uacltid' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Sr No.', 'user_activity_log_pro' );
				}
				if ( 'user_name' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Author Name', 'user_activity_log_pro' );
				}
				if ( 'user_email' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Author E-mail', 'user_activity_log_pro' );
				}
				if ( ualp_allow_ip() ) {
					if ( 'ip_address' == $header[ $h ] ) {
						$header[ $h ] = esc_html__( 'IP Address', 'user_activity_log_pro' );
					}
				}
				if ( ualp_allow_country() ) {
					if ( 'country' == $header[ $h ] ) {
						$header[ $h ] = esc_html__( 'Country', 'user_activity_log_pro' );
					}
				}
				if ( ualp_allow_user_agent() ) {
					if ( 'user_agent' == $header[ $h ] ) {
						$header[ $h ] = esc_html__( 'User Agent', 'user_activity_log_pro' );
					}
				}
				if ( 'time_login' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Logged in Time', 'user_activity_log_pro' );
				}
				if ( 'time_logout' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Logged out Time', 'user_activity_log_pro' );
				}
				if ( 'time_last_seen' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Last seen', 'user_activity_log_pro' );
				}
				if ( 'login_status' == $header[ $h ] ) {
					$header[ $h ] = esc_html__( 'Login Status', 'user_activity_log_pro' );
				}
			}
			$export_delimiter = ',';
			$random_id        = wp_rand();
			$csv_file_name    = 'export_user_logged_' . gmdate( 'Y-m-d_H-i-s', time() ) . '.csv';
			ualplogged_csv_output( $csv_file_name, $data_content, $header, $export_delimiter );
		}
		if ( 'json' == $logformat ) {
			$json_file_name = 'export_user_logged_' . gmdate( 'Y-m-d_H-i-s', time() ) . '.json';
			ualp_json_output( $json_file_name, $data_content );
		}
		do_action( 'ualp_export_activity_log' );
	}
}

if ( ! function_exists( 'ualplogged_csv_output' ) ) {
	/**
	 * CSV logged in output.
	 *
	 * @param string $filename File name.
	 * @param array  $data Data.
	 * @param array  $fields Fields.
	 * @param string $delimiter Delimiter.
	 */
	function ualplogged_csv_output( $filename = null, $data = array(), $fields = array(), $delimiter = null ) {
		if ( null === $delimiter ) {
			$delimiter = ',';
		}
		$random_id = wp_rand();
		$filename  = 'export_user_logged_' . gmdate( 'Y-m-d_H-i-s', time() ) . '.csv';
		if ( $filename ) {
			$data = ualp_unparse( $data, $fields, null, null, $delimiter );
			header( 'Content-type: application/csv' );
			header( 'Content-Disposition: attachment; filename="' . $filename . '"' );
			echo $data;
		}
		return $data;
	}
}

add_action( 'admin_init', 'ualp_export_user_logged' );
if ( ! function_exists( 'ualp_export_user_logged' ) ) {
	/**
	 * Export logged in users.
	 */
	function ualp_export_user_logged() {
		if ( is_admin() && is_user_logged_in() && current_user_can( 'administrator' ) ) {
			if ( isset( $_GET['export'] ) && 'user_login' == $_GET['export'] && isset( $_GET['export-nonce'] ) && '' != $_GET['export-nonce'] ) {
				$username          = '';
				$user_role         = '';
				$ip                = '';
				$timelogin         = '';
				$search            = '';
				$user_agent        = '';
				$country           = '';
				$loginstatus       = '';
				$timelogout        = '';
				$user_role         = '';
				$site_id           = '';
				$logformat         = '';
				$login_start_date  = '';
				$login_end_date    = '';
				$logout_start_date = '';
				$logout_end_date   = '';

				if ( isset( $_GET['username'] ) ) {
					$username = sanitize_text_field( wp_unslash( $_GET['username'] ) );
				}
				if ( isset( $_GET['user_role'] ) ) {
					$user_role = sanitize_text_field( wp_unslash( $_GET['user_role'] ) );
				}
				if ( isset( $_GET['ip'] ) ) {
					$ip = sanitize_text_field( wp_unslash( $_GET['ip'] ) );
				}
				if ( isset( $_GET['country'] ) ) {
					$country = sanitize_text_field( wp_unslash( $_GET['country'] ) );
				}
				if ( isset( $_GET['user_agent'] ) ) {
					$user_agent = sanitize_text_field( wp_unslash( $_GET['user_agent'] ) );
				}
				if ( isset( $_GET['loginstatus'] ) ) {
					$loginstatus = sanitize_text_field( wp_unslash( $_GET['loginstatus'] ) );
				}
				if ( isset( $_GET['timelogin'] ) ) {
					$timelogin = sanitize_text_field( wp_unslash( $_GET['timelogin'] ) );
				}
				if ( isset( $_GET['timelogout'] ) ) {
					$timelogout = sanitize_text_field( wp_unslash( $_GET['timelogout'] ) );
				}
				if ( isset( $_GET['txtsearch'] ) ) {
					$search = sanitize_text_field( wp_unslash( $_GET['txtsearch'] ) );
				}
				if ( isset( $_GET['user_role'] ) ) {
					$user_role = sanitize_text_field( wp_unslash( $_GET['user_role'] ) );
				}
				if ( isset( $_GET['showsiteid'] ) ) {
					$site_id = sanitize_text_field( wp_unslash( $_GET['showsiteid'] ) );
				}
				if ( isset( $_GET['logformat'] ) ) {
					$logformat = sanitize_text_field( wp_unslash( $_GET['logformat'] ) );
				}
				if ( isset( $_GET['login_start_date'] ) ) {
					$login_start_date = sanitize_text_field( wp_unslash( $_GET['login_start_date'] ) );
				}
				if ( isset( $_GET['login_end_date'] ) ) {
					$login_end_date = sanitize_text_field( wp_unslash( $_GET['login_end_date'] ) );
				}
				if ( isset( $_GET['logout_start_date'] ) ) {
					$logout_start_date = sanitize_text_field( wp_unslash( $_GET['logout_start_date'] ) );
				}
				if ( isset( $_GET['logout_end_date'] ) ) {
					$logout_end_date = sanitize_text_field( wp_unslash( $_GET['logout_end_date'] ) );
				}
				ualp_export_user_logged_log( $username, $user_role, $ip, $country, $user_agent, $search, $loginstatus, $timelogin, $timelogout, $site_id, $logformat, $login_start_date, $login_end_date, $logout_start_date, $logout_end_date );
				exit();
			}
		}
	}
}

if ( ! function_exists( 'ualp_report_csv_output' ) ) {
	/**
	 * CSV report output.
	 *
	 * @param string $filename File name.
	 * @param array  $data Data.
	 * @param array  $fields Fields.
	 * @param string $delimiter Delimiter.
	 */
	function ualp_report_csv_output( $filename = null, $data = array(), $fields = array(), $delimiter = null ) {
		if ( null === $delimiter ) {
			$delimiter = ',';
		}
		$random_id = wp_rand();
		$filename  = 'export_user_report_' . gmdate( 'Y-m-d_H-i-s', time() ) . '.csv';
		if ( $filename ) {
			$data = ualp_unparse( $data, $fields, null, null, $delimiter );
			header( 'Content-type: application/csv; charset=utf-8' );
			header( 'Content-Disposition: attachment; filename="' . $filename . '"' );
			header( 'Pragma: no-cache' );
			header( 'Expires: 0' );
			echo $data;
		}
		return $data;
	}
}
if ( ! function_exists( 'ualp_report_html_output' ) ) {
	/**
	 * HTML report output.
	 *
	 * @param string $data Data.
	 * @param string $header Header.
	 * @param string $filename File name.
	 * @param string $delimiter Delimiter.
	 */
	function ualp_report_html_output( $data, $header, $filename = null, $delimiter = null ) {
		if ( null === $delimiter ) {
			$delimiter = ',';
		}
		$random_id = wp_rand();
		$filename  = 'export_user_report_' . gmdate( 'Y-m-d_H-i-s', time() ) . '.html';
		if ( $filename ) {
			header( 'Content-type: text/html; charset=utf-8' );
			header( 'Content-Disposition: attachment; filename="' . $filename . '"' );
			header( 'Pragma: no-cache' );
			header( 'Expires: 0' );
			$data .= '<style>
            .report_header_title_wrap {
                display: inline-block;
                width: 100%;
                text-align: center;
            }
            .report_details_cover .report_details_title {
                display: inline-block;
                width: 100%;
                border-bottom: 1px solid #000;
                padding-bottom: 10px;
            }
            .report_generated_span {
                display: inline-block;
                width: 100%;
                padding: 10px 0;
            }
            table {
                font-family: arial, sans-serif;
                border-collapse: collapse;
                width: 100%;
            }
    
            td, th {
                border:0;
                text-align: left;
                padding: 20px 10px;
            }
            thead th {
                background: #000;
                color: #fff;
                opacity: 0.6;
            }
            tr:nth-child(even) {
                background-color: #f1f1f1;
            }
            </style>';
			echo $data;
		}
		return $data;
	}
}

/**
 * JSON Output.
 *
 * @param string $file_name File name.
 * @param string $content Content.
 */
function ualp_json_output( $file_name, $content ) {
	file_put_contents( $file_name, wp_json_encode( $content ) );
	header( 'Content-type: application/json' );
	header( 'Content-Disposition: attachment; filename="' . basename( $file_name ) . '"' );
	header( 'Content-Length: ' . filesize( $file_name ) );
	readfile( $file_name );
}
