<?php
/**
 * BuddyPress Hook.
 *
 * @package User Activity Log PRO
 */

/**
 * Exit if accessed directly
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'ualp_bubby_press_create_group' ) ) {
	/**
	 * Create a group.
	 *
	 * @param int    $group_id Group ID.
	 * @param string $member Member.
	 * @param string $group Group.
	 */
	function ualp_bubby_press_create_group( $group_id, $member, $group ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'groups_create_group', $log_hook_list ) ) {
			$action      = 'Group created';
			$obj_type    = 'BubbyPress';
			$post_id     = $group->id;
			$hook        = 'groups_create_group';
			$post_title  = $group->name;
			$description = "$obj_type : $post_title $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'groups_create_group', 'ualp_bubby_press_create_group', 15, 3 );

if ( ! function_exists( 'ualp_bubby_press_update_group' ) ) {
	/**
	 * Update a group.
	 *
	 * @param int    $group_id Group ID.
	 * @param string $group Group.
	 */
	function ualp_bubby_press_update_group( $group_id, $group ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'groups_update_group', $log_hook_list ) ) {
			$action      = 'Group Update';
			$obj_type    = 'BubbyPress';
			$post_id     = $group->id;
			$hook        = 'groups_update_group';
			$post_title  = $group->name;
			$description = "$obj_type : $post_title $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'groups_update_group', 'ualp_bubby_press_update_group', 15, 2 );

if ( ! function_exists( 'ualp_bubby_press_delete_group' ) ) {
	/**
	 * Delete a group.
	 *
	 * @param int $group_id Group ID.
	 */
	function ualp_bubby_press_delete_group( $group_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'groups_before_delete_group', $log_hook_list ) ) {
			$action   = 'Group Delete';
			$obj_type = 'BubbyPress';
			$post_id  = $group_id;
			if ( is_numeric( $group_id ) ) {
				$group = groups_get_group(
					array(
						'group_id' => $group_id,
					)
				);
			}
			$hook        = 'groups_before_delete_group';
			$post_title  = $group->name;
			$description = "$obj_type : $post_title $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'groups_before_delete_group', 'ualp_bubby_press_delete_group', 15, 1 );

if ( ! function_exists( 'ualp_bubby_press_leave_group' ) ) {
	/**
	 * Leave a group for user.
	 *
	 * @param int $group_id Group ID.
	 * @param int $user_id User ID.
	 */
	function ualp_bubby_press_leave_group( $group_id, $user_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'groups_leave_group', $log_hook_list ) ) {
			$action   = 'Leave Group';
			$obj_type = 'BubbyPress';
			$post_id  = $group_id;
			$user     = get_user_by( 'id', $user_id );
			if ( is_numeric( $group_id ) ) {
				$group = groups_get_group(
					array(
						'group_id' => $group_id,
					)
				);
			}
			$hook        = 'groups_leave_group';
			$post_title  = $user->user_login . ' Leave Group ' . $group->name;
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'groups_leave_group', 'ualp_bubby_press_leave_group', 15, 2 );

if ( ! function_exists( 'ualp_bubby_press_join_group' ) ) {
	/**
	 * Join a group.
	 *
	 * @param int $group_id Group ID.
	 * @param int $user_id User ID.
	 */
	function ualp_bubby_press_join_group( $group_id, $user_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'groups_join_group', $log_hook_list ) ) {
			$action   = 'Join Group';
			$obj_type = 'BubbyPress';
			$post_id  = $group_id;
			$user     = get_user_by( 'id', $user_id );
			if ( is_numeric( $group_id ) ) {
				$group = groups_get_group(
					array(
						'group_id' => $group_id,
					)
				);
			}
			$hook        = 'groups_join_group';
			$post_title  = $user->user_login . ' Join Group ' . $group->name;
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'groups_join_group', 'ualp_bubby_press_join_group', 15, 2 );

if ( ! function_exists( 'ualp_bubby_press_promote_group' ) ) {
	/**
	 * Promote a group.
	 *
	 * @param int    $group_id Group ID.
	 * @param int    $user_id User ID.
	 * @param string $status Status.
	 */
	function ualp_bubby_press_promote_group( $group_id, $user_id, $status ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'groups_promote_member', $log_hook_list ) ) {
			$action   = 'promoted Group';
			$obj_type = 'BubbyPress';
			$post_id  = $group_id;
			$user     = get_user_by( 'id', $user_id );
			if ( is_numeric( $group_id ) ) {
				$group = groups_get_group(
					array(
						'group_id' => $group_id,
					)
				);
			}
			$hook        = 'groups_promote_member';
			$post_title  = $user->user_login . ' Promoted Group ' . $group->name;
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'groups_promote_member', 'ualp_bubby_press_promote_group', 15, 3 );

if ( ! function_exists( 'ualp_bubby_press_demote_group' ) ) {
	/**
	 * Demote a group.
	 *
	 * @param int $group_id Group ID.
	 * @param int $user_id User ID.
	 */
	function ualp_bubby_press_demote_group( $group_id, $user_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'groups_demote_member', $log_hook_list ) ) {
			$action   = 'demoted Group';
			$obj_type = 'BubbyPress';
			$post_id  = $group_id;
			$user     = get_user_by( 'id', $user_id );
			if ( is_numeric( $group_id ) ) {
				$group = groups_get_group(
					array(
						'group_id' => $group_id,
					)
				);
			}
			$hook        = 'groups_demote_member';
			$post_title  = $user->user_login . ' Demoted Group ' . $group->name;
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'groups_demote_member', 'ualp_bubby_press_demote_group', 15, 2 );


if ( ! function_exists( 'ualp_bubby_press_ban_group' ) ) {
	/**
	 * Ban a group.
	 *
	 * @param int $group_id Group ID.
	 * @param int $user_id User ID.
	 */
	function ualp_bubby_press_ban_group( $group_id, $user_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'groups_ban_member', $log_hook_list ) ) {
			$action   = 'Ban Member';
			$obj_type = 'BubbyPress';
			$post_id  = $group_id;
			$user     = get_user_by( 'id', $user_id );
			if ( is_numeric( $group_id ) ) {
				$group = groups_get_group(
					array(
						'group_id' => $group_id,
					)
				);
			}
			$hook        = 'groups_ban_member';
			$post_title  = $user->user_login . ' Ban Member ' . $group->name;
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'groups_ban_member', 'ualp_bubby_press_ban_group', 15, 2 );

if ( ! function_exists( 'ualp_bubby_press_un_ban_group' ) ) {
	/**
	 * Unban a group.
	 *
	 * @param int $group_id Group ID.
	 * @param int $user_id User ID.
	 */
	function ualp_bubby_press_un_ban_group( $group_id, $user_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'groups_unban_member', $log_hook_list ) ) {
			$action   = 'unban member';
			$obj_type = 'BubbyPress';
			$post_id  = $group_id;
			$user     = get_user_by( 'id', $user_id );
			if ( is_numeric( $group_id ) ) {
				$group = groups_get_group(
					array(
						'group_id' => $group_id,
					)
				);
			}
			$hook        = 'groups_unban_member';
			$post_title  = $user->user_login . ' Unban Member ' . $group->name;
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'groups_unban_member', 'ualp_bubby_press_un_ban_group', 15, 2 );

if ( ! function_exists( 'ualp_bubby_press_remove_member_group' ) ) {
	/**
	 * Remove member a group.
	 *
	 * @param int $group_id Group ID.
	 * @param int $user_id User ID.
	 */
	function ualp_bubby_press_remove_member_group( $group_id, $user_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'groups_remove_member', $log_hook_list ) ) {
			$action   = 'Remove Member';
			$obj_type = 'BubbyPress';
			$post_id  = $group_id;
			$user     = get_user_by( 'id', $user_id );
			if ( is_numeric( $group_id ) ) {
				$group = groups_get_group(
					array(
						'group_id' => $group_id,
					)
				);
			}
			$hook        = 'groups_remove_member';
			$post_title  = $user->user_login . ' Remove Member ' . $group->name;
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}

	}
}
add_action( 'groups_remove_member', 'ualp_bubby_press_remove_member_group', 15, 2 );

if ( ! function_exists( 'ualp_bubby_press_profile_field_save' ) ) {
	/**
	 * Profile field save.
	 *
	 * @param string $field Field.
	 */
	function ualp_bubby_press_profile_field_save( $field ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'xprofile_field_after_save', $log_hook_list ) ) {
			$action      = isset( $field->id ) ? 'Updated' : 'Created';
			$obj_type    = 'BubbyPress';
			$post_id     = '';
			$hook        = 'xprofile_field_after_save';
			$post_title  = $action . ' profile field group ' . $field->name;
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'xprofile_field_after_save', 'ualp_bubby_press_profile_field_save', 15, 1 );

if ( ! function_exists( 'ualp_bubby_press_profile_field_delete' ) ) {
	/**
	 * Profile field delete.
	 *
	 * @param string $field Field.
	 */
	function ualp_bubby_press_profile_field_delete( $field ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'xprofile_fields_deleted_field', $log_hook_list ) ) {
			$action      = 'Deleted';
			$obj_type    = 'BubbyPress';
			$post_id     = '';
			$post_title  = $action . ' profile field group ' . $field->name;
			$hook        = 'xprofile_fields_deleted_field';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'xprofile_fields_deleted_field', 'ualp_bubby_press_profile_field_delete', 15, 1 );

if ( ! function_exists( 'ualp_bubby_press_profile_group_save' ) ) {
	/**
	 *  Create/Update Profile Field Group.
	 *
	 * @param string $group Group.
	 */
	function ualp_bubby_press_profile_group_save( $group ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'xprofile_group_after_save', $log_hook_list ) ) {
			$action      = ( $group->id === $wpdb->insert_id ) ? 'created' : 'updated';
			$obj_type    = 'BubbyPress';
			$post_id     = '';
			$hook        = 'xprofile_group_after_save';
			$post_title  = $action . ' profile field group ' . $group->name;
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'xprofile_group_after_save', 'ualp_bubby_press_profile_group_save', 15, 1 );

if ( ! function_exists( 'ualp_bubby_press_profile_group_delete' ) ) {
	/**
	 * Deleted Profile Field Group.
	 *
	 * @param string $group Group.
	 */
	function ualp_bubby_press_profile_group_delete( $group ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'xprofile_groups_deleted_group', $log_hook_list ) ) {
			$action      = 'Deleted';
			$obj_type    = 'BubbyPress';
			$post_id     = '';
			$hook        = 'xprofile_groups_deleted_group';
			$post_title  = $action . ' profile field group ' . $group->name;
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'xprofile_groups_deleted_group', 'ualp_bubby_press_profile_group_delete', 15, 1 );
