<?php
/**
 * All in One Reservation Hook.
 *
 * @package User Activity Log PRO
 */

/**
 * Exit if accessed directly
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'ualp_hook_update_reservation_status' ) ) {
	/**
	 * Add log for update reservation status.
	 *
	 * @param string $old_settings Old Settings.
	 * @param string $new_settings New Settings.
	 */
	function ualp_hook_update_reservation_status( $old_settings, $new_settings ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'rest_update_reservation_status', $log_hook_list ) ) {
			$request_status = isset( $_REQUEST['status'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['status'] ) ) : '';
			$action         = "'" . $request_status . "' successfully";
			$obj_type       = 'All in one Reservation';
			$post_id        = isset( $_REQUEST['postId'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['postId'] ) ) : '';
			$post_title     = get_the_title( $post_id );
			$hook           = 'rest_update_reservation_status';
			$description    = "$obj_type : $post_title $action";
			$uactid         = ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
			if ( 0 != $uactid ) {
				ualp_add_reservation_settings_log_detail( $uactid, $old_settings, $new_settings );
			}
		}
	}
}
add_action( 'wp_ajax_rest_update_reservation_status', 'ualp_hook_update_reservation_status', 2, 20 ); // new.


if ( ! function_exists( 'ualp_hook_reset_reservation_settings' ) ) {
	/**
	 * Add log for reset reservation settings.
	 */
	function ualp_hook_reset_reservation_settings() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'reset_reservation_settings', $log_hook_list ) ) {
			$action      = 'Reset';
			$post_title  = 'All in one Reservation';
			$obj_type    = 'Settings';
			$post_id     = '';
			$hook        = 'reset_reservation_settings';
			$description = "$post_title : $action $obj_type";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_reset_rest_settings', 'ualp_hook_reset_reservation_settings' ); // new.

if ( ! function_exists( 'ualp_hook_reservation_security_settings' ) ) {
	/**
	 * Add log for security settings.
	 *
	 * @param string $option Option.
	 * @param string $oldvalue Old Value.
	 * @param string $newvalue New Value.
	 */
	function ualp_hook_reservation_security_settings( $option, $oldvalue, $newvalue ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'save_reservation_settings', $log_hook_list ) ) {
			if ( 'rest_settings' == $option ) {
				$action      = 'Updated';
				$post_title  = 'All in one Reservation';
				$obj_type    = 'Settings';
				$post_id     = '';
				$hook        = 'save_reservation_settings';
				$description = "$post_title : $obj_type $action";
				$uactid      = ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
				if ( 0 != $uactid ) {
					ualp_add_wordpress_settings_log_detail( $uactid, $oldvalue, $newvalue, $obj_type, $option );
				}
			}
		}

	}
}
add_action( 'updated_option', 'ualp_hook_reservation_security_settings', 50, 3 ); // new.
