<?php
/**
 * AutoOptimizer Hook.
 *
 * @package User Activity Log PRO
 */

if ( ! function_exists( 'ualp_hook_autoptimizer_delete_cache' ) ) {
	/**
	 * Fires after autoptimize options updated.
	 */
	function ualp_hook_autoptimizer_delete_cache() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wp_ajax_autoptimize_delete_cache', $log_hook_list ) ) {
			$action      = 'deleted';
			$obj_type    = 'Autoptimizer Settings';
			$post_id     = '';
			$post_title  = 'Cache';
			$hook        = 'wp_ajax_autoptimize_delete_cache';
			$description = "$obj_type $post_title $action successfully";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_autoptimize_delete_cache', 'ualp_hook_autoptimizer_delete_cache' );

if ( ! function_exists( 'ualp_hook_autoptimizer_update_options' ) ) {
	/**
	 * Fires after autoptimize options updated.
	 *
	 * @param string $option Option.
	 * @param string $oldvalue Old Value.
	 * @param string $newvalue New Value.
	 */
	function ualp_hook_autoptimizer_update_options( $option, $oldvalue, $newvalue ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'autoptimizer_settings', $log_hook_list ) ) {
			$whitelisted_options = ualp_get_autoptimizer_options();
			if ( ! in_array( $option, $whitelisted_options ) ) {
				return;
			}
			$action      = 'updated';
			$obj_type    = 'Autoptimizer Settings';
			$post_id     = '';
			$post_title  = $option;
			$hook        = 'autoptimizer_settings';
			$description = "$obj_type $action : $post_title";
			$uactid      = ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
			if ( 0 != $uactid ) {
				ualp_add_wordpress_settings_log_detail( $uactid, $oldvalue, $newvalue, $obj_type, $option );
			}
		}
	}
}
add_action( 'updated_option', 'ualp_hook_autoptimizer_update_options', 25, 3 );

if ( ! function_exists( 'ualp_get_autoptimizer_options' ) ) {
	/**
	 * Get autoptimizer options.
	 */
	function ualp_get_autoptimizer_options() {
		$whitelisted_options = apply_filters(
			'ualp_get_autoptimizer_options',
			array(
				'autoptimize_html',
				'autoptimize_html_keepcomments',
				'autoptimize_js',
				'autoptimize_js_exclude',
				'autoptimize_js_aggregate',
				'autoptimize_js_trycatch',
				'autoptimize_js_justhead',
				'autoptimize_js_forcehead',
				'autoptimize_js_include_inline',
				'autoptimize_css',
				'autoptimize_css_aggregate',
				'autoptimize_css_exclude',
				'autoptimize_css_justhead',
				'autoptimize_css_datauris',
				'autoptimize_css_defer',
				'autoptimize_css_defer_inline',
				'autoptimize_css_inline',
				'autoptimize_css_include_inline',
				'autoptimize_cdn_url',
				'autoptimize_cache_clean',
				'autoptimize_cache_nogzip',
				'autoptimize_show_adv',
				'autoptimize_optimize_logged',
				'autoptimize_optimize_checkout',
				'autoptimize_extra_settings',
				'autoptimize_minify_excluded',
			)
		);
		return $whitelisted_options;
	}
}
