<?php
/**
 * Blog Designer PRO Hook.
 *
 * @package User Activity Log PRO
 */

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


if ( ! function_exists( 'ualp_get_blog_layout_name' ) ) {
	/**
	 * Get setting from database from shortcode id.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 * @global object $wpdb
	 * @return string Shortcode name
	 */
	function ualp_get_blog_layout_name( $shortcode_id ) {
		global $wpdb;
		$settings_val = $wpdb->get_results( $wpdb->prepare( "SELECT single_name FROM {$wpdb->prefix}blog_designer_pro_shortcodes WHERE id = %d", $shortcode_id ), ARRAY_A );
		if ( ! $settings_val ) {
			return;
		}
		foreach ( $settings_val as $settings ) {
			return $settings['shortcode_name'];
		}
		return false;
	}
}

if ( ! function_exists( 'ualp_get_archive_layout_name' ) ) {
	/**
	 * Get Archive layout name from database from shortcode id.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 * @global object $wpdb
	 * @return string Archive name
	 */
	function ualp_get_archive_layout_name( $shortcode_id ) {
		global $wpdb;
		$settings_val = $wpdb->get_results( $wpdb->prepare( "SELECT single_name FROM {$wpdb->prefix}bdp_archives WHERE id = %d", $shortcode_id ), ARRAY_A );
		if ( ! $settings_val ) {
			return;
		}
		foreach ( $settings_val as $settings ) {
			return $settings['archive_name'];
		}
		return false;
	}
}

if ( ! function_exists( 'ualp_get_single_layout_name' ) ) {
	/**
	 * Get Single layout name from database from shortcode id.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 * @global object $wpdb
	 * @return string Single name
	 */
	function ualp_get_single_layout_name( $shortcode_id ) {
		global $wpdb;
		$settings_val = $wpdb->get_results( $wpdb->prepare( "SELECT single_name FROM {$wpdb->prefix}bdp_single_layouts WHERE id = %d", $shortcode_id ), ARRAY_A );

		if ( ! $settings_val ) {
			return;
		}
		foreach ( $settings_val as $settings ) {
			return $settings['single_name'];
		}
		return false;
	}
}

if ( ! function_exists( 'ualp_hook_bdp_update_shortcode' ) ) {
	/**
	 * Get activity for blog layout shortcode update.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 */
	function ualp_hook_bdp_update_shortcode( $shortcode_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_update_shortcode', $log_hook_list ) ) {
			$action      = 'Blog Layout Updated';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_blog_layout_name( $shortcode_id );
			$hook        = 'bdp_update_shortcode';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_update_shortcode', 'ualp_hook_bdp_update_shortcode', 10, 1 );

if ( ! function_exists( 'ualp_hook_bdp_reset_shortcode' ) ) {
	/**
	 * Get activity for blog layout shortcode reset.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 */
	function ualp_hook_bdp_reset_shortcode( $shortcode_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_reset_shortcode', $log_hook_list ) ) {
			$action      = 'Blog Layout Reset';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_blog_layout_name( $shortcode_id );
			$hook        = 'bdp_reset_shortcode';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_reset_shortcode', 'ualp_hook_bdp_reset_shortcode', 10, 1 );

if ( ! function_exists( 'ualp_hook_bdp_reset_archive_layout' ) ) {
	/**
	 * Get activity for blog layout shortcode reset.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 */
	function ualp_hook_bdp_reset_archive_layout( $shortcode_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_reset_archive_page', $log_hook_list ) ) {
			$action      = 'Archive Layout Reset';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_archive_layout_name( $shortcode_id );
			$hook        = 'bdp_reset_archive_page';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_reset_archive_page', 'ualp_hook_bdp_reset_archive_layout', 10, 1 );

if ( ! function_exists( 'ualp_hook_bdp_add_shortcode' ) ) {
	/**
	 * Get activity for add blog shortcode.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 */
	function ualp_hook_bdp_add_shortcode( $shortcode_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_add_shortcode', $log_hook_list ) ) {
			$action      = 'Blog Layout Created';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = $shortcode_id;
			$post_title  = ualp_get_blog_layout_name( $shortcode_id );
			$hook        = 'bdp_add_shortcode';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_add_shortcode', 'ualp_hook_bdp_add_shortcode' );


if ( ! function_exists( 'ualp_hook_bdp_update_single_file' ) ) {
	/**
	 * Get activity for Single file update.
	 */
	function ualp_hook_bdp_update_single_file() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_update_single_file', $log_hook_list ) ) {
			$action      = 'updated in theme';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = 'Single template file';
			$hook        = 'bdp_update_single_file';
			$description = "$obj_type : $post_title $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_update_single_file', 'ualp_hook_bdp_update_single_file' );

if ( ! function_exists( 'ualp_hook_bdp_add_archive_layout' ) ) {
	/**
	 * Get activity for add archive layout.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 */
	function ualp_hook_bdp_add_archive_layout( $shortcode_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_add_archive_layout', $log_hook_list ) ) {
			$action      = 'Archive Layout Created';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_archive_layout_name( $shortcode_id );
			$hook        = 'bdp_add_archive_layout';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_add_archive_layout', 'ualp_hook_bdp_add_archive_layout' );

if ( ! function_exists( 'ualp_hook_bdp_delete_shortcode' ) ) {
	/**
	 * Get activity for delete shortcode.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 */
	function ualp_hook_bdp_delete_shortcode( $shortcode_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_delete_shortcode', $log_hook_list ) ) {
			$action      = 'Blog Layout Deleted';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_blog_layout_name( $shortcode_id );
			$hook        = 'bdp_delete_shortcode';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_delete_shortcode', 'ualp_hook_bdp_delete_shortcode' );

if ( ! function_exists( 'ualp_hook_bdp_delete_single_template' ) ) {
	/**
	 * Get activity for delete single template.
	 */
	function ualp_hook_bdp_delete_single_template() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_delete_single_template', $log_hook_list ) ) {
			$action      = 'deleted from theme';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = 'Single template file';
			$hook        = 'bdp_delete_single_template';
			$description = "$obj_type : $post_title $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_delete_single_template', 'ualp_hook_bdp_delete_single_template' );

if ( ! function_exists( 'ualp_hook_bdp_copy_single_template' ) ) {
	/**
	 * Get activity for copy single template.
	 */
	function ualp_hook_bdp_copy_single_template() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_copy_single_template', $log_hook_list ) ) {
			$action      = 'created in theme';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = 'Single template file';
			$hook        = 'bdp_copy_single_template';
			$description = "$obj_type : $post_title $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_copy_single_template', 'ualp_hook_bdp_copy_single_template' );

if ( ! function_exists( 'ualp_hook_bdp_duplicate_layout' ) ) {
	/**
	 * Get activity for duplicate layout.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 */
	function ualp_hook_bdp_duplicate_layout( $shortcode_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_duplicate_layout_settings', $log_hook_list ) ) {
			$action      = 'Blog Layout Duplicated';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_blog_layout_name( $shortcode_id );
			$hook        = 'bdp_duplicate_layout_settings';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_duplicate_layout_settings', 'ualp_hook_bdp_duplicate_layout' );

if ( ! function_exists( 'ualp_hook_bdp_import_blog_layout' ) ) {
	/**
	 * Get activity for import blog layout.
	 *
	 * @param string $shortcode_name shortcode name.
	 */
	function ualp_hook_bdp_import_blog_layout( $shortcode_name ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_import_blog_layout_settings', $log_hook_list ) ) {
			$action      = 'Blog Layout Imported';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = $shortcode_name;
			$hook        = 'bdp_import_blog_layout_settings';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_import_blog_layout_settings', 'ualp_hook_bdp_import_blog_layout' );

if ( ! function_exists( 'ualp_hook_bdp_import_archive_layout' ) ) {
	/**
	 * Get activity for import archive layout.
	 *
	 * @param string $archive_name Archive Layout Name.
	 */
	function ualp_hook_bdp_import_archive_layout( $archive_name ) {
		$log_hook_list = get_option( 'enableLogHookList' );

		if ( in_array( 'bdp_import_archive_layout_settings', $log_hook_list ) ) {
			$action      = 'Archive Layout Imported';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_archive_layout_name( $archive_id );
			$hook        = 'bdp_import_archive_layout_settings';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_import_archive_layout_settings', 'ualp_hook_bdp_import_archive_layout' );

if ( ! function_exists( 'ualp_hook_bdp_export_archive_layout' ) ) {
	/**
	 * Get activity for export archive layout.
	 *
	 * @param int $archive_id Archive Layout ID.
	 */
	function ualp_hook_bdp_export_archive_layout( $archive_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_export_archive_layout_settings', $log_hook_list ) ) {
			$action      = 'Archive Layout Exported';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_archive_layout_name( $archive_id );
			$hook        = 'bdp_export_archive_layout_settings';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_export_archive_layout_settings', 'ualp_hook_bdp_export_archive_layout' );

if ( ! function_exists( 'ualp_hook_bdp_export_blog_layout' ) ) {
	/**
	 * Get activity for export blog layout.
	 *
	 * @param int $layout_id Layout Id.
	 */
	function ualp_hook_bdp_export_blog_layout( $layout_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_export_blog_layout_settings', $log_hook_list ) ) {
			$action      = 'Blog Layout Exported';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_blog_layout_name( $layout_id );
			$hook        = 'bdp_export_blog_layout_settings';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_export_blog_layout_settings', 'ualp_hook_bdp_export_blog_layout' );

if ( ! function_exists( 'ualp_hook_bdp_update_archive_layout' ) ) {
	/**
	 * Get activity for update archive layout.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 */
	function ualp_hook_bdp_update_archive_layout( $shortcode_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_update_archive_page', $log_hook_list ) ) {
			$action      = 'Archive Layout Updated';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_archive_layout_name( $shortcode_id );
			$hook        = 'bdp_update_archive_page';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_update_archive_page', 'ualp_hook_bdp_update_archive_layout' );


if ( ! function_exists( 'ualp_hook_bdp_import_single_layout' ) ) {
	/**
	 * Get activity for import file.
	 *
	 * @param string $single_layout_name Layout name.
	 */
	function ualp_hook_bdp_import_single_layout( $single_layout_name ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_import_single_layout_settings', $log_hook_list ) ) {
			$action      = 'Single layout Imported';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = $single_layout_name;
			$hook        = 'bdp_import_single_layout_settings';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_import_single_layout_settings', 'ualp_hook_bdp_import_single_layout' );

if ( ! function_exists( 'ualp_hook_bdp_export_single_layout' ) ) {
	/**
	 * Get activity for export file.
	 *
	 * @param int $single_layout_ids Layout ID.
	 */
	function ualp_hook_bdp_export_single_layout( $single_layout_ids ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_export_single_layout_settings', $log_hook_list ) ) {
			$action      = 'Single Layout Exported';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_single_layout_name( $single_layout_ids );
			$hook        = 'bdp_export_single_layout_settings';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_export_single_layout_settings', 'ualp_hook_bdp_export_single_layout' );

if ( ! function_exists( 'ualp_hook_bdp_delete_archive_layouts' ) ) {
	/**
	 * Get activity for delete archive.
	 *
	 * @param int $archive Archive layout id.
	 */
	function ualp_hook_bdp_delete_archive_layouts( $archive ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_delete_archive', $log_hook_list ) ) {
			$action      = 'Archive layout deleted';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_archive_layout_name( $archive );
			$hook        = 'bdp_delete_archive';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_delete_archive', 'ualp_hook_bdp_delete_archive_layouts' );


if ( ! function_exists( 'ualp_hook_bdp_delete_single_layout' ) ) {
	/**
	 * Get activity for delete single layout.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 */
	function ualp_hook_bdp_delete_single_layout( $shortcode_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_delete_single_layout', $log_hook_list ) ) {
			$action      = 'Single Layout Deleted';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_single_layout_name( $shortcode_id );
			$hook        = 'bdp_delete_single_layout';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_delete_single_layout', 'ualp_hook_bdp_delete_single_layout' );


if ( ! function_exists( 'ualp_hook_bdp_update_single_layout' ) ) {
	/**
	 * Get activity for update single page.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 */
	function ualp_hook_bdp_update_single_layout( $shortcode_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_update_single_page', $log_hook_list ) ) {
			$action      = 'Single Layout Updated';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_single_layout_name( $shortcode_id );
			$hook        = 'bdp_update_single_page';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_update_single_page', 'ualp_hook_bdp_update_single_layout' );

if ( ! function_exists( 'ualp_hook_bdp_reset_single_layout' ) ) {
	/**
	 * Get activity for reset single page.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 */
	function ualp_hook_bdp_reset_single_layout( $shortcode_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_reset_single_page', $log_hook_list ) ) {
			$action      = 'Single Layout Reset';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_single_layout_name( $shortcode_id );
			$hook        = 'bdp_reset_single_page';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_reset_single_page', 'ualp_hook_bdp_reset_single_layout' );

if ( ! function_exists( 'ualp_hook_bdp_add_single_layout' ) ) {
	/**
	 * Get activity for add single layout.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 */
	function ualp_hook_bdp_add_single_layout( $shortcode_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_add_single_layout', $log_hook_list ) ) {
			$action      = 'Single Layout Created';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_single_layout_name( $shortcode_id );
			$hook        = 'bdp_add_single_layout';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_add_single_layout', 'ualp_hook_bdp_add_single_layout' );

if ( ! function_exists( 'ualp_hook_bdp_duplicate_single_layout' ) ) {
	/**
	 * Get activity for duplicate single layout.
	 *
	 * @param int $shortcode_id Shortcode ID.
	 */
	function ualp_hook_bdp_duplicate_single_layout( $shortcode_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'bdp_duplicate_single_layout_settings', $log_hook_list ) ) {
			$action      = 'Single Layout Duplicated';
			$obj_type    = 'Blog Designer Pro';
			$post_id     = '';
			$post_title  = ualp_get_single_layout_name( $shortcode_id );
			$hook        = 'bdp_duplicate_single_layout_settings';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'bdp_duplicate_single_layout_settings', 'ualp_hook_bdp_duplicate_single_layout' );
