<?php
/**
 * Easy Digital Download Hook.
 *
 * @package User Activity Log PRO
 */

/**
 * Exit if accessed directly
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'ualp_hook_activate_discount_code' ) ) {
	/**
	 * Get activity for the user - Activate Discount code.
	 *
	 * @param array $data dicount data.
	 */
	function ualp_hook_activate_discount_code( $data ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'edd_activate_discount', $log_hook_list ) ) {
			$action      = 'Activate';
			$obj_type    = 'edd_discount';
			$post_id     = absint( $data['discount'] );
			$post_title  = get_the_title( $post_id );
			$hook        = 'edd_activate_discount';
			$description = "$obj_type $action : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}

add_action( 'edd_activate_discount', 'ualp_hook_activate_discount_code' ); // new.

if ( ! function_exists( 'ualp_hook_deactivate_discount_code' ) ) {
	/**
	 * Get activity for the user - Deactivate Discount code.
	 *
	 * @param array $data dicount data.
	 */
	function ualp_hook_deactivate_discount_code( $data ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'edd_deactivate_discount', $log_hook_list ) ) {
			$action      = 'Deactivate';
			$obj_type    = 'edd_discount';
			$post_id     = absint( $data['discount'] );
			$post_title  = get_the_title( $post_id );
			$hook        = 'edd_deactivate_discount';
			$description = "$obj_type $action : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}

add_action( 'edd_deactivate_discount', 'ualp_hook_deactivate_discount_code' ); // new.

if ( ! function_exists( 'ualp_hook_add_discount_code' ) ) {
	/**
	 * Get activity for the user - Add Discount.
	 *
	 * @param array $data dicount data.
	 */
	function ualp_hook_add_discount_code( $data ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'edd_add_discount', $log_hook_list ) ) {
			$action      = 'Added';
			$obj_type    = 'edd_discount';
			$post_id     = isset( $data['discount'] ) ? $data['discount'] : '';
			$post_title  = 'Add Discount Code';
			$hook        = 'edd_add_discount';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}

add_action( 'edd_add_discount', 'ualp_hook_add_discount_code' ); // new.


if ( ! function_exists( 'ualp_hook_delete_discount_code' ) ) {
	/**
	 * Get activity for the user - Delete Discount.
	 *
	 * @param array $data dicount data.
	 */
	function ualp_hook_delete_discount_code( $data ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'edd_delete_discount', $log_hook_list ) ) {
			$action      = 'Deleted';
			$obj_type    = 'edd_discount';
			$post_id     = $data['discount'];
			$post_title  = 'Discount Code Deleted';
			$hook        = 'edd_delete_discount';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}

add_action( 'edd_delete_discount', 'ualp_hook_delete_discount_code' ); // new.

if ( ! function_exists( 'ualp_hook_edit_discount_code' ) ) {
	/**
	 * Get activity for the user - Edit Discount.
	 */
	function ualp_hook_edit_discount_code() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( isset( $_POST['edd-discount-nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['edd-discount-nonce'] ) ), 'edd_discount_nonce' ) ) {
			if ( ! empty( $_POST['discount-id'] ) ) {
				$post_ID = isset( $_POST['discount-id'] ) ? (int) $_POST['discount-id'] : 0;
				if ( ! $post_ID ) {
					return;
				}
				if ( ! current_user_can( 'edit_post', $post_ID ) ) {
					return;
				};
				$old_post_data  = array(
					'post_data' => '',
					'post_meta' => get_post_custom( $post_ID ),
					'post_tax'  => '',
				);
				$post_meta_data = ualp_get_post_meta_data( 'discount' );
				$new_post_meta  = '';
				foreach ( $post_meta_data as $post_meta_key => $post_meta_value ) {
					if ( ! is_numeric( $post_meta_key ) ) {
						if ( isset( $_POST[ $post_meta_key ] ) ) {
							$meta_key_value                       = maybe_serialize( sanitize_text_field( wp_unslash( $_POST[ $post_meta_key ] ) ) );
							$new_post_meta[ $post_meta_value ][0] = sanitize_text_field( $meta_key_value );
						}
					} else {
						if ( isset( $_POST[ $post_meta_value ] ) ) {
							$meta_key_value                       = maybe_serialize( sanitize_text_field( wp_unslash( $_POST[ $post_meta_value ] ) ) );
							$new_post_meta[ $post_meta_value ][0] = sanitize_text_field( $meta_key_value );
						}
					}
				}
				$new_post_data = array(
					'post_data' => '',
					'post_meta' => $new_post_meta,
					'post_tax'  => '',
				);
				if ( in_array( 'edd_discount', $log_hook_list ) ) {
					$action     = 'updated';
					$obj_type   = 'edd_discount';
					$hook       = 'transition_post_status';
					$post_title = isset( $_POST['name'] ) ? sanitize_text_field( wp_unslash( $_POST['name'] ) ) : '';
					$page_link  = get_edit_post_link( $post_ID );
					if ( '' == $page_link ) {
						$page_link = get_the_permalink( $post_ID );
					}
					$description = "$obj_type $action : <a target='blank' href='" . $page_link . "'>$post_title</a>";
					$uactid      = ualp_get_activity_log( $action, $obj_type, $post_ID, $post_title, $hook, $description );
					if ( 0 != $uactid ) {
						ualp_add_activity_log_detail_post_update( $uactid, $old_post_data, $new_post_data, $obj_type );
					}
				}
			}
		}
	}
}
add_action( 'init', 'ualp_hook_edit_discount_code' );

if ( ! function_exists( 'ualp_hook_edd_option' ) ) {
	/**
	 * Get activity for the user - update options.
	 *
	 * @param string $option option name.
	 * @param string $oldvalue Old Option Value.
	 * @param string $_newvalue New Option Value.
	 */
	function ualp_hook_edd_option( $option, $oldvalue, $_newvalue ) {
		if ( 'edd_settings' != $option && 'edd_tax_rates' != $option ) {
			return;
		}
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'edd_settings', $log_hook_list ) ) {
			$action      = 'updated';
			$obj_type    = 'Settings';
			$post_id     = '';
			$post_title  = $option;
			$hook        = 'edd_settings';
			$description = "$obj_type $action : $post_title";
			$uactid      = ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
			if ( 0 != $uactid ) {
				ualp_add_wordpress_settings_log_detail( $uactid, $oldvalue, $_newvalue, $obj_type, $option );
			}
		}
	}
}
add_action( 'updated_option', 'ualp_hook_edd_option', 10, 3 );
