<?php
/**
 * Gravity Form Hook.
 *
 * @package User Activity Log PRO
 */

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'ualp_hook_gforms_save_entry' ) ) {
	/**
	 * Fires once the admin request has been validated or not.
	 *
	 * @param string    $action_type The nonce action.
	 * @param false|int $result False if the nonce is invalid,
	 *                  1 if the nonce is valid and generated between 0-12 hours ago,
	 *                  2 if the nonce is valid and generated between 12-24 hours ago.
	 */
	function ualp_hook_gforms_save_entry( $action_type, $result ) {
		$obj_type      = 'Gravity Form';
		$post_id       = '';
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gf_export_forms', $log_hook_list ) ) {
			if ( 'gf_export_forms' == $action_type ) {
				$action = 'Form exported';
				$hook   = 'gf_export_forms';
				if ( isset( $_POST['gf_export_forms_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['gf_export_forms_nonce'] ) ), 'gf_export_forms' ) ) {
					if ( isset( $_POST['export_forms'] ) ) {
						$selected_forms = rgpost( 'gf_form_id' );
						if ( is_array( $selected_forms ) ) {
							foreach ( $selected_forms as $selected_form ) {
								$form        = GFFormsModel::get_form_meta( $selected_form );
								$post_title  = $form['title'];
								$description = "$obj_type : '$post_title' $action";
								ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
							}
						}
					}
				}
			}
		}
	}
}

add_action( 'check_admin_referer', 'ualp_hook_gforms_save_entry', 10, 2 );


if ( ! function_exists( 'ualp_hook_gforms_duplicate_notify' ) ) {
	/**
	 * Fires once Notification duplicated.
	 *
	 * @param string    $action The nonce action.
	 * @param false|int $result False if the nonce is invalid,
	 *                  1 if the nonce is valid and generated between 0-12 hours ago,
	 *                  2 if the nonce is valid and generated between 12-24 hours ago.
	 */
	function ualp_hook_gforms_duplicate_notify( $action, $result ) {
		if ( 'gform_notification_list_action' == $action ) {
			$log_hook_list = get_option( 'enableLogHookList' );
			if ( in_array( 'notification_duplicated', $log_hook_list ) ) {
				$actions = rgpost( 'action' );
				if ( 'duplicate' == $actions ) {
					$form_id            = rgget( 'id' );
					$notification_id    = rgpost( 'action_argument' );
					$form               = GFFormsModel::get_form_meta( $form_id );
					$notification_title = $form['notifications'][ $notification_id ]['name'];
					$post_title         = $form['title'];
					$obj_type           = 'Gravity Form';
					$post_id            = '';
					$hook               = 'notification_duplicated';
					$description        = "$obj_type : '$notification_title' notification duplicated for '$post_title'";
					ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
				}
			}
		}
	}
}

add_action( 'check_admin_referer', 'ualp_hook_gforms_duplicate_notify', 10, 2 );


if ( ! function_exists( 'ualp_hook_gform_entry_created' ) ) {
	/**
	 * Fired after an entry is created.
	 *
	 * @param array $lead The Entry object.
	 * @param array $form The Form object.
	 */
	function ualp_hook_gform_entry_created( $lead, $form ) {
		$lead_id = ( isset( $lead ) ) ? $lead['id'] : '';
		if ( isset( $lead_id ) && '' != $lead_id ) {
			$lead_title    = $lead[1];
			$log_hook_list = get_option( 'enableLogHookList' );
			if ( in_array( 'gform_entry_created', $log_hook_list ) ) {
				$form_title = '';
				if ( isset( $form['title'] ) && ! empty( $form['title'] ) ) {
					$form_title = $form['title'];
				}
				$action      = 'created';
				$obj_type    = 'Gravity Form';
				$post_id     = '';
				$post_title  = $lead_title;
				$hook        = 'gform_entry_created';
				$description = "$obj_type : New entry '$post_title' $action in '" . $form_title . "' Form";
				ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
			}
		}
	}
}

add_action( 'gform_entry_created', 'ualp_hook_gform_entry_created', 20, 2 );

if ( ! function_exists( 'ualp_hook_wp_ajax_gf_resend_notifications' ) ) {
	/**
	 * Fires when resend email notifications.
	 */
	function ualp_hook_wp_ajax_gf_resend_notifications() {
		$form_id = absint( rgpost( 'formId' ) );
		$leads   = rgpost( 'leadIds' );
		if ( ! empty( $leads ) && ! empty( $form_id ) ) {
			$form          = GFFormsModel::get_form_meta( $form_id );
			$log_hook_list = get_option( 'enableLogHookList' );
			if ( in_array( 'gf_resend_notifications', $log_hook_list ) ) {
				$action     = '';
				$obj_type   = 'Gravity Form';
				$post_id    = '';
				$post_title = $form['title'];
				$hook       = 'gf_resend_notifications';
				foreach ( $leads as $single_lead ) {
					$lead        = GFFormsModel::get_lead( $single_lead );
					$description = "$obj_type : Notifications for '$lead[1]' entry resent for '$post_title' form";
					ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
				}
			}
		}
	}
}

add_action( 'wp_ajax_gf_resend_notifications', 'ualp_hook_wp_ajax_gf_resend_notifications' );

if ( ! function_exists( 'ualp_hookgform_pre_note_deleted' ) ) {
	/**
	 * Fires before a note is deleted.
	 *
	 * @param int $note_id The current note ID.
	 * @param int $lead_id The current lead ID.
	 */
	function ualp_hookgform_pre_note_deleted( $note_id, $lead_id ) {
		$lead          = GFFormsModel::get_lead( $lead_id );
		$form          = GFFormsModel::get_form_meta( $lead['form_id'] );
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_pre_note_deleted', $log_hook_list ) ) {
			$action      = 'deleted';
			$post_id     = '';
			$obj_type    = 'Gravity Form';
			$post_title  = $form['title'];
			$hook        = 'gform_pre_note_deleted';
			$description = "$obj_type : '$note_id' note $action from lead '$lead_id' on '$post_title' form";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_pre_note_deleted', 'ualp_hookgform_pre_note_deleted', 10, 2 ); // todo.

if ( ! function_exists( 'ualp_hook_garvity_form_updated_option' ) ) {
	/**
	 * Fires when settings updated.
	 *
	 * @param string $option Option.
	 * @param string $oldvalue Old Value.
	 * @param string $_newvalue New Value.
	 */
	function ualp_hook_garvity_form_updated_option( $option, $oldvalue = null, $_newvalue = null ) {
		$whitelist_options = array(
			'gform_enable_noconflict',
			'gform_enable_toolbar_menu',
			'gform_enable_background_updates',
			'gform_enable_logging',
			'rg_gforms_currency',
			'rg_gforms_key',
			'rg_gforms_enable_html5',
			'rg_gforms_disable_css',
			'rg_gforms_captcha_public_key',
			'rg_gforms_captcha_private_key',
		);

		if ( ! in_array( $option, $whitelist_options ) ) {
			return;
		}
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gravityforms_updated_option', $log_hook_list ) ) {
			$action      = 'updated';
			$obj_type    = 'Settings';
			$post_id     = '';
			$post_title  = $option;
			$hook        = 'gravityforms_updated_option';
			$description = "$obj_type $action : $post_title";
			$uactid      = ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
			if ( 0 != $uactid ) {
				ualp_add_wordpress_settings_log_detail( $uactid, $oldvalue, $_newvalue, $obj_type, $option );
			}
		}
	}
}

add_action( 'updated_option', 'ualp_hook_garvity_form_updated_option', 20, 3 );
add_action( 'delete_option', 'ualp_hook_garvity_form_updated_option', 20, 3 );
add_action( 'add_option', 'ualp_hook_garvity_form_updated_option', 20, 3 );

if ( ! function_exists( 'ualp_hookgform_post_export_entries' ) ) {
	/**
	 * Fires after exporting all the entries in form.
	 *
	 * @param array  $form       The Form object to get the entries from.
	 * @param string $start_date The start date for when the export of entries should take place.
	 * @param string $end_date   The end date for when the export of entries should stop.
	 * @param array  $fields     The specified fields where the entries should be exported from.
	 */
	function ualp_hookgform_post_export_entries( $form, $start_date, $end_date, $fields ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_post_export_entries', $log_hook_list ) ) {
			$action      = 'form entries exported';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$post_title  = $form['title'];
			$hook        = 'gform_post_export_entries';
			$description = "$obj_type : '$post_title' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_post_export_entries', 'ualp_hookgform_post_export_entries', 10, 4 );

if ( ! function_exists( 'ualp_hookgform_post_note_added' ) ) {
	/**
	 * Fires after a note has been added to an entry.
	 *
	 * @param int    $note_id         The row ID of this note in the database.
	 * @param int    $lead_id         The ID of the entry that the note was added to.
	 * @param int    $user_id         The ID of the current user adding the note.
	 * @param string $user_name       The user name of the current user.
	 * @param string $note            The content of the note being added.
	 * @param string $note_type       The type of note being added.  Defaults to 'note'.
	 */
	function ualp_hookgform_post_note_added( $note_id, $lead_id, $user_id, $user_name, $note, $note_type ) {
		$lead          = GFFormsModel::get_lead( $lead_id );
		$form          = GFFormsModel::get_form_meta( $lead['form_id'] );
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_post_note_added', $log_hook_list ) ) {
			$action      = 'added';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$post_title  = $note_id;
			$hook        = 'gform_post_note_added';
			$description = "$obj_type : '$post_title' note $action to lead '$lead_id' on '" . $form['title'] . "' form";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_post_note_added', 'ualp_hookgform_post_note_added', 10, 6 ); // todo.

if ( ! function_exists( 'ualp_hookgform_delete_entries' ) ) {
	/**
	 * Fires when you delete entries for a specific form.
	 *
	 * @param int    $form_id The form ID to specify from which form to delete entries.
	 * @param string $status  Allows you to set the form entries to a deleted status.
	 */
	function ualp_hookgform_delete_entries( $form_id, $status ) {
		$form          = GFFormsModel::get_form_meta( $form_id );
		$form_title    = $form['title'];
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_delete_entries', $log_hook_list ) ) {
			$action      = '';
			$post_id     = '';
			$obj_type    = 'Gravity Form';
			$post_title  = 'Entry deleted';
			$hook        = 'gform_delete_entries';
			$description = "$obj_type : $post_title from '$form_title'";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_delete_entries', 'ualp_hookgform_delete_entries', 10, 2 ); // todo.


if ( ! function_exists( 'ualp_hookgform_post_form_views_deleted' ) ) {
	/**
	 * Fires after form views are deleted.
	 *
	 * @param int $form_id The ID of the form that views were deleted from.
	 */
	function ualp_hookgform_post_form_views_deleted( $form_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_post_form_views_deleted', $log_hook_list ) ) {
			$action      = 'view Reset';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$form        = GFFormsModel::get_form_meta( $form_id );
			$post_title  = $form['title'];
			$hook        = 'gform_post_form_views_deleted';
			$description = "$obj_type : '$post_title' Form $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_post_form_views_deleted', 'ualp_hookgform_post_form_views_deleted', 10, 1 );


if ( ! function_exists( 'ualp_hookgform_post_form_activated' ) ) {
	/**
	 * Fires after an inactive form gets marked as active.
	 *
	 * @param int $form_id The Form ID used to specify which form to activate.
	 */
	function ualp_hookgform_post_form_activated( $form_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_post_form_activated', $log_hook_list ) ) {
			$action      = 'activated';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$form        = GFFormsModel::get_form_meta( $form_id );
			$post_title  = $form['title'];
			$hook        = 'gform_post_form_activated';
			$description = "$obj_type : '$post_title' Form $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_post_form_activated', 'ualp_hookgform_post_form_activated', 10, 1 );

if ( ! function_exists( 'ualp_hookgform_post_form_deactivated' ) ) {
	/**
	 * Fires after an active form gets marked as inactive.
	 *
	 * @param int $form_id The Form ID used to specify which form to activate.
	 */
	function ualp_hookgform_post_form_deactivated( $form_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_post_form_deactivated', $log_hook_list ) ) {
			$action      = 'deactivated';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$form        = GFFormsModel::get_form_meta( $form_id );
			$post_title  = $form['title'];
			$hook        = 'gform_post_form_deactivated';
			$description = "$obj_type : '$post_title' Form $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_post_form_deactivated', 'ualp_hookgform_post_form_deactivated', 10, 1 );


if ( ! function_exists( 'ualp_hookgform_before_delete_form' ) ) {
	/**
	 * Fires before a form is deleted.
	 *
	 * @param int $form_id The ID of the form being deleted.
	 */
	function ualp_hookgform_before_delete_form( $form_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_before_delete_form', $log_hook_list ) ) {
			$action      = 'deleted';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$form        = GFFormsModel::get_form_meta( $form_id );
			$post_title  = $form['title'];
			$hook        = 'gform_before_delete_form';
			$description = "$obj_type : '$post_title' Form $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_before_delete_form', 'ualp_hookgform_before_delete_form', 10, 1 );


if ( ! function_exists( 'ualp_hookgform_post_form_trashed' ) ) {
	/**
	 * Fires after a form is trashed.
	 *
	 * @param int $form_id The ID of the form that was trashed.
	 */
	function ualp_hookgform_post_form_trashed( $form_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		$form          = GFFormsModel::get_form_meta( $form_id );
		if ( in_array( 'gform_post_form_trashed', $log_hook_list ) ) {
			$action      = 'trashed';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$post_title  = $form['title'];
			$hook        = 'gform_post_form_trashed';
			$description = "$obj_type : '$post_title' Form $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_post_form_trashed', 'ualp_hookgform_post_form_trashed', 10, 1 );


if ( ! function_exists( 'ualp_hookgform_post_form_restored' ) ) {
	/**
	 * Fires after a form is restored from trash.
	 *
	 * @param int $form_id The ID of the form that was restored.
	 */
	function ualp_hookgform_post_form_restored( $form_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_post_form_restored', $log_hook_list ) ) {
			$action      = 'restored';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$form        = GFFormsModel::get_form_meta( $form_id );
			$post_title  = $form['title'];
			$hook        = 'gform_post_form_restored';
			$description = "$obj_type : '$post_title' Form $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_post_form_restored', 'ualp_hookgform_post_form_restored', 10, 1 );


if ( ! function_exists( 'ualp_hookgform_post_form_duplicated' ) ) {
	/**
	 * Fires after a form is duplicated.
	 *
	 * @param int $form_id The original form's ID.
	 * @param int $new_id  The ID of the new, duplicated form.
	 */
	function ualp_hookgform_post_form_duplicated( $form_id, $new_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_post_form_duplicated', $log_hook_list ) ) {
			$action      = 'duplicated';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$form        = GFFormsModel::get_form_meta( $form_id );
			$post_title  = $form['title'];
			$hook        = 'gform_post_form_duplicated';
			$description = "$obj_type : '$post_title' Form $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_post_form_duplicated', 'ualp_hookgform_post_form_duplicated', 10, 2 );


if ( ! function_exists( 'ualp_hookgform_after_save_form' ) ) {
	/**
	 * Fires after a form is saved.
	 *
	 * Used to run additional actions after the form is saved.
	 *
	 * @param array $form_meta The form meta.
	 * @param bool  $flag Returns true if this is a new form.
	 */
	function ualp_hookgform_after_save_form( $form_meta, $flag ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_after_save_form', $log_hook_list ) ) {
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$action      = $flag ? 'created' : 'updated';
			$hook        = 'gform_after_save_form';
			$post_title  = $form_meta['title'];
			$description = "$obj_type : '$post_title' form $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_after_save_form', 'ualp_hookgform_after_save_form', 10, 2 );


if ( ! function_exists( 'ualp_hookgform_forms_post_import' ) ) {
	/**
	 * Fires after forms have been imported.
	 *
	 * Used to perform additional actions after import
	 *
	 * @param array $forms An array imported form objects.
	 */
	function ualp_hookgform_forms_post_import( $forms ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_forms_post_import', $log_hook_list ) ) {
			$forms_total  = count( $forms );
			$forms_label  = ( 1 === $forms_total ) ? 'form' : 'forms';
			$forms_ids    = wp_list_pluck( $forms, 'id' );
			$forms_titles = wp_list_pluck( $forms, 'title' );
			$forms_title  = implode( ',', $forms_titles );
			$action       = 'imported';
			$obj_type     = 'Gravity Form';
			$post_id      = '';
			$post_title   = '';
			$hook         = 'gform_forms_post_import';
			$description  = "$obj_type : '$forms_title' $forms_total $forms_label $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_forms_post_import', 'ualp_hookgform_forms_post_import', 10, 1 );


if ( ! function_exists( 'ualp_hookgform_pre_notification_deleted' ) ) {
	/**
	 * Fires before a notification is deleted.
	 *
	 * @param array $notification_id    The notification being deleted.
	 * @param array $form               The Form Object that the notification is being deleted from.
	 */
	function ualp_hookgform_pre_notification_deleted( $notification_id, $form ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_pre_notification_deleted', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$post_title  = $form['title'];
			$hook        = 'gform_pre_notification_deleted';
			$description = "$obj_type : '" . $notification_id['name'] . "' Notification deleted from '$post_title'";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_pre_notification_deleted', 'ualp_hookgform_pre_notification_deleted', 10, 2 );


if ( ! function_exists( 'ualp_hookgform_pre_confirmation_deleted' ) ) {
	/**
	 * Fires right before a confirmation is deleted.
	 *
	 * @param int   $confirmation_id The ID of the confirmation being deleted.
	 * @param array $form The Form object.
	 */
	function ualp_hookgform_pre_confirmation_deleted( $confirmation_id, $form ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_pre_confirmation_deleted', $log_hook_list ) ) {
			$action      = 'confirmation deleted';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$post_title  = $confirmation_id['name'];
			$hook        = 'gform_pre_confirmation_deleted';
			$description = "$obj_type : '$post_title' $action from '" . $form['title'] . "'";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_pre_confirmation_deleted', 'ualp_hookgform_pre_confirmation_deleted', 10, 2 );


if ( ! function_exists( 'ualp_hookwp_ajax_rg_update_notification_active' ) ) {
	/**
	 * Fires when update notification saved.
	 */
	function ualp_hookwp_ajax_rg_update_notification_active() {
		if ( isset( $_POST['rg_update_notification_active'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['rg_update_notification_active'] ) ), 'rg_update_notification_active' ) ) {
			if ( isset( $_POST['is_active'] ) && 1 == $_POST['is_active'] ) {
				$action = 'active';
			} else {
				$action = 'inactive';
			}

			$form_id = ( isset( $_POST['form_id'] ) && ! empty( $_POST['form_id'] ) ) ? intval( $_POST['form_id'] ) : '';
			$form    = GFFormsModel::get_form_meta( $form_id );

			$notification_id    = ( isset( $_POST['notification_id'] ) && ! empty( $_POST['notification_id'] ) ) ? intval( $_POST['notification_id'] ) : '';
			$notification_title = $form['notifications'][ $notification_id ]['name'];
			$log_hook_list      = get_option( 'enableLogHookList' );
			if ( in_array( 'wp_ajax_rg_update_notification_active', $log_hook_list ) ) {
				$obj_type    = 'Gravity Form';
				$post_id     = '';
				$post_title  = $form['title'];
				$hook        = 'wp_ajax_rg_update_notification_active';
				$description = "$obj_type : '$notification_title' notification $action for '$post_title'";
				ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
			}
		}
	}
}
add_action( 'wp_ajax_rg_update_notification_active', 'ualp_hookwp_ajax_rg_update_notification_active' );


if ( ! function_exists( 'ualp_hookwp_ajax_rg_update_confirmation_active' ) ) {
	/**
	 * Fires when confirmation activated.
	 */
	function ualp_hookwp_ajax_rg_update_confirmation_active() {
		if ( isset( $_POST['rg_update_confirmation_active'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['rg_update_confirmation_active'] ) ), 'rg_update_confirmation_active' ) ) {
			$log_hook_list = get_option( 'enableLogHookList' );
			if ( isset( $_POST['is_active'] ) && 1 == $_POST['is_active'] ) {
				$action = 'active';
			} else {
				$action = 'inactive';
			}

			$form_id         = ( isset( $_POST['form_id'] ) && ! empty( $_POST['form_id'] ) ) ? intval( $_POST['form_id'] ) : '';
			$form            = GFFormsModel::get_form_meta( $form_id );
			$confirmation_id = ( isset( $_POST['confirmation_id'] ) && ! empty( $_POST['confirmation_id'] ) ) ? intval( $_POST['confirmation_id'] ) : '';
			$c_title         = $form['confirmations'][ $confirmation_id ]['name'];
			if ( in_array( 'wp_ajax_rg_update_confirmation_active', $log_hook_list ) ) {
				$post_id     = '';
				$obj_type    = 'Gravity Form';
				$post_title  = $form['title'];
				$hook        = 'wp_ajax_rg_update_confirmation_active';
				$description = "$obj_type : '$c_title' confirmation $action for '$post_title'";
				ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
			}
		}
	}
}
add_action( 'wp_ajax_rg_update_confirmation_active', 'ualp_hookwp_ajax_rg_update_confirmation_active' );


if ( ! function_exists( 'ualp_hookgform_confirmation_save' ) ) {
	/**
	 * Fires when saving form confirmations.
	 *
	 * @param array $confirmation Confirmation.
	 * @param array $form Form.
	 * @param bool  $is_new Is New.
	 * @return array
	 */
	function ualp_hookgform_confirmation_save( $confirmation, $form, $is_new = true ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_pre_confirmation_save', $log_hook_list ) ) {
			$confirmation_name = $confirmation['name'];
			$action            = $is_new ? 'created' : 'updated';
			$obj_type          = 'Gravity Form';
			$post_id           = '';
			$post_title        = $form['title'];
			$hook              = 'gform_pre_confirmation_save';
			$description       = "$obj_type : '$confirmation_name' confirmation $action for '$post_title'";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
		return $confirmation;
	}
}
add_filter( 'gform_pre_confirmation_save', 'ualp_hookgform_confirmation_save', 10, 3 );


if ( ! function_exists( 'ualp_hookgform_notification_save' ) ) {
	/**
	 * Fires when saving form notification.
	 *
	 * @param array $notification Notification.
	 * @param array $form Form.
	 * @param bool  $is_new Is New.
	 * @return array
	 */
	function ualp_hookgform_notification_save( $notification, $form, $is_new = true ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_pre_notification_save', $log_hook_list ) ) {
			$action      = $is_new ? 'created' : 'updated';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$post_title  = $notification['name'] . ' notification';
			$hook        = 'gform_pre_notification_save';
			$description = "$obj_type : '$post_title' $action for '" . $form['title'] . "'";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
		return $notification;
	}
}
add_filter( 'gform_pre_notification_save', 'ualp_hookgform_notification_save', 10, 3 );


if ( ! function_exists( 'ualp_hookgform_post_lead_deleted' ) ) {
	/**
	 * Fires after form lead is deleted.
	 *
	 * @param int $lead_id The ID of the lead.
	 */
	function ualp_hookgform_post_lead_deleted( $lead_id ) {
		$lead          = GFFormsModel::get_lead( $lead_id );
		$form          = GFFormsModel::get_form_meta( $lead['form_id'] );
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_delete_lead', $log_hook_list ) ) {
			$action      = 'deleted';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$post_title  = "Entry '$lead[1]' from '" . $form['title'] . "'";
			$hook        = 'gform_delete_lead';
			$description = "$obj_type : $post_title $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_delete_lead', 'ualp_hookgform_post_lead_deleted', 10, 1 );


if ( ! function_exists( 'ualp_hookgform_update_status' ) ) {
	/**
	 * Fires before form status updated.
	 *
	 * @param int    $lead_id The current lead ID.
	 * @param string $status Current Status.
	 * @param string $prev Previous Status.
	 */
	function ualp_hookgform_update_status( $lead_id, $status, $prev = '' ) {

		$lead = GFFormsModel::get_lead( $lead_id );
		$form = GFFormsModel::get_form_meta( $lead['form_id'] );

		if ( 'active' === $status && 'trash' === $prev ) {
			$action = 'restore';
		} elseif ( 'active' == $status ) {
			$action = 'active';
		} elseif ( 'spam' == $status ) {
			$action = 'spam';
		} elseif ( 'trash' == $status ) {
			$action = 'trash';
		} elseif ( 'restore' == $status ) {
			$action = 'restore';
		} else {
			$action = $status;
		}
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_update_status', $log_hook_list ) ) {
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$post_title  = "Entry '$lead[1]' $action on '" . $form['title'] . "' form";
			$hook        = 'gform_update_status';
			$description = "$obj_type :  $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_update_status', 'ualp_hookgform_update_status', 10, 3 );


if ( ! function_exists( 'ualp_hookgform_read_entry' ) ) {
	/**
	 * Fires before read entry.
	 *
	 * @param int $lead_id The current lead ID.
	 * @param int $status Current status.
	 */
	function ualp_hookgform_read_entry( $lead_id, $status ) {

		$lead          = GFFormsModel::get_lead( $lead_id );
		$form          = GFFormsModel::get_form_meta( $lead['form_id'] );
		$log_hook_list = get_option( 'enableLogHookList' );

		if ( in_array( 'gform_update_is_read', $log_hook_list ) ) {
			$action      = ( ! empty( $status ) ) ? 'read' : 'unread';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$post_title  = "Entry '$lead[1]' marked as $action on '" . $form['title'] . "' form";
			$hook        = 'gform_update_is_read';
			$description = "$obj_type :  $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_update_is_read', 'ualp_hookgform_read_entry', 10, 2 );


if ( ! function_exists( 'ualp_hookgform_mark_starred' ) ) {
	/**
	 * Fires before entry marked as starred.
	 *
	 * @param int $lead_id The current lead ID.
	 * @param int $status Current status.
	 */
	function ualp_hookgform_mark_starred( $lead_id, $status ) {

		$lead          = GFFormsModel::get_lead( $lead_id );
		$form          = GFFormsModel::get_form_meta( $lead['form_id'] );
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'gform_update_is_starred', $log_hook_list ) ) {
			$action      = ( ! empty( $status ) ) ? 'starred' : 'unstarred';
			$obj_type    = 'Gravity Form';
			$post_id     = '';
			$post_title  = "Entry '$lead[1]' $action on '" . $form['title'] . "' form";
			$hook        = 'gform_update_is_starred';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'gform_update_is_starred', 'ualp_hookgform_mark_starred', 10, 2 );

if ( ! function_exists( 'ualp_hook_garvity_form_licence_updated' ) ) {
	/**
	 * Fires when settings updated.
	 *
	 * @param string $option Option.
	 * @param string $oldvalue Old Value.
	 * @param string $_newvalue New Value.
	 */
	function ualp_hook_garvity_form_licence_updated( $option, $oldvalue, $_newvalue ) {
		if ( 'rg_gforms_key' == $option ) {
			$log_hook_list = get_option( 'enableLogHookList' );
			$is_update     = ( $_newvalue && strlen( $_newvalue ) );
			if ( in_array( 'gravityforms_updated_option', $log_hook_list ) ) {
				$action      = $is_update ? 'updated' : 'deleted';
				$obj_type    = 'Gravity Form';
				$post_id     = '';
				$post_title  = 'Gravity Forms license key';
				$hook        = 'gravityforms_updated_option';
				$description = "$obj_type : $post_title $action";
				$uactid      = ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
				if ( 0 != $uactid ) {
					ualp_add_wordpress_settings_log_detail( $uactid, $oldvalue, $_newvalue, $obj_type, $option );
				}
			}
		}
	}
}
add_action( 'updated_option', 'ualp_hook_garvity_form_licence_updated', 20, 3 );
