<?php
/**
 * Portfolio Designer PRO Hook.
 *
 * @package User Activity Log PRO
 */

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'ualp_hook_one_click_install' ) ) {
	/**
	 * Add log for one click installation.
	 */
	function ualp_hook_one_click_install() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'import_sample_portfolio_data', $log_hook_list ) ) {
			$action      = 'One Click Installation completed successfully';
			$post_title  = $layout;
			$obj_type    = 'Portfolio Designer';
			$post_id     = '';
			$hook        = 'import_sample_portfolio_data';
			$description = "$obj_type : $post_title $action";
			$uactid      = ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
			$update_info = array(
				'title'  => $post_title,
				'action' => $action,
			);
			if ( 0 != $uactid ) {
				ualp_add_activity_log_detail( $uactid, $update_info );
			}
		}
	}
}
add_action( 'import_sample_portfolio_data', 'ualp_hook_one_click_install', 1, 20 ); // new.

if ( ! function_exists( 'ualp_hook_create_portfolio_layout' ) ) {
	/**
	 * Add log for create portfolio layout.
	 *
	 * @param int    $layout_id Layout ID.
	 * @param string $layout_name Layout Name.
	 */
	function ualp_hook_create_portfolio_layout( $layout_id, $layout_name ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'create_portfolio_layout', $log_hook_list ) ) {
			$action      = 'Layout created successfully';
			$post_title  = $layout_name;
			$obj_type    = 'Portfolio Designer';
			$post_id     = '';
			$hook        = 'create_portfolio_layout';
			$description = "$obj_type : '" . ucfirst( $post_title ) . "' $action";
			$uactid      = ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
			$update_info = array(
				'title'  => $post_title,
				'action' => $action,
			);
			if ( 0 != $uactid ) {
				ualp_add_activity_log_detail( $uactid, $update_info );
			}
		}
	}
}
add_action( 'create_portfolio_layout', 'ualp_hook_create_portfolio_layout', 2, 20 );

if ( ! function_exists( 'ualp_hook_duplicate_portfolio_layout' ) ) {
	/**
	 * Add log for duplicate portfolio layout.
	 *
	 * @param string $layout Layout.
	 */
	function ualp_hook_duplicate_portfolio_layout( $layout ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'duplicate_portfolio_layout', $log_hook_list ) ) {
			$action      = 'Layout duplicated successfully';
			$post_title  = $layout;
			$obj_type    = 'Portfolio Designer';
			$post_id     = '';
			$hook        = 'duplicate_portfolio_layout';
			$description = "$obj_type : '" . ucfirst( $post_title ) . "' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'duplicate_portfolio_layout', 'ualp_hook_duplicate_portfolio_layout', 1, 20 );

if ( ! function_exists( 'ualp_hook_delete_portfolio_layout' ) ) {
	/**
	 * Add log for delete portfolio layout.
	 *
	 * @param string $layout Layout.
	 */
	function ualp_hook_delete_portfolio_layout( $layout ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'delete_portfolio_layout', $log_hook_list ) ) {
			$action      = 'Layout deleted successfully';
			$post_title  = $layout;
			$obj_type    = 'Portfolio Designer';
			$post_id     = '';
			$hook        = 'delete_portfolio_layout';
			$description = "$obj_type : '" . ucfirst( $post_title ) . "' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'delete_portfolio_layout', 'ualp_hook_delete_portfolio_layout', 1, 20 );

if ( ! function_exists( 'ualp_hook_update_portfolio_layout' ) ) {
	/**
	 * Add log for update portfolio layout.
	 *
	 * @param int    $id ID.
	 * @param string $layout Layout.
	 */
	function ualp_hook_update_portfolio_layout( $id, $layout ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'update_portfolio_layout', $log_hook_list ) ) {
			$action      = 'Layout updated successfully';
			$post_title  = $layout;
			$obj_type    = 'Portfolio Designer';
			$post_id     = '';
			$hook        = 'update_portfolio_layout';
			$description = "$obj_type : '" . ucfirst( $post_title ) . "' $action";
			$uactid      = ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
			$update_info = array(
				'title'  => $post_title,
				'action' => $action,
			);
			if ( 0 != $uactid ) {
				ualp_add_activity_log_detail( $uactid, $update_info );
			}
		}
	}
}
add_action( 'update_portfolio_layout', 'ualp_hook_update_portfolio_layout', 2, 20 );

if ( ! function_exists( 'ualp_hook_reset_portfolio_layout' ) ) {
	/**
	 * Add log for reset portfolio layout.
	 *
	 * @param int    $id ID.
	 * @param string $layout Layout.
	 */
	function ualp_hook_reset_portfolio_layout( $id, $layout ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'reset_portfolio_layout', $log_hook_list ) ) {
			$action      = 'Layout reset successfully';
			$post_title  = $layout;
			$obj_type    = 'Portfolio Designer';
			$post_id     = '';
			$hook        = 'reset_portfolio_layout';
			$description = "$obj_type : '" . ucfirst( $post_title ) . "' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'reset_portfolio_layout', 'ualp_hook_reset_portfolio_layout', 2, 20 );

if ( ! function_exists( 'ualp_hook_import_portfolio_data' ) ) {
	/**
	 * Add log for import portfolio layout.
	 *
	 * @param string $layout Layout.
	 */
	function ualp_hook_import_portfolio_data( $layout ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'import_portfolio_layout', $log_hook_list ) ) {
			$action      = 'Layout Imported Successfully';
			$post_title  = $layout;
			$obj_type    = 'Portfolio Designer';
			$post_id     = '';
			$hook        = 'import_portfolio_layout';
			$description = "$obj_type : '" . ucfirst( $post_title ) . "' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'import_portfolio_layout', 'ualp_hook_import_portfolio_data', 1, 20 );

if ( ! function_exists( 'ualp_hook_export_portfolio_layout' ) ) {
	/**
	 * Add log for export portfolio layout.
	 *
	 * @param string $layout Layout.
	 */
	function ualp_hook_export_portfolio_layout( $layout ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'export_portfolio_layout', $log_hook_list ) ) {
			$action      = 'Layout exported successfully';
			$post_title  = $layout;
			$obj_type    = 'Portfolio Designer';
			$post_id     = '';
			$hook        = 'export_portfolio_layout';
			$description = "$obj_type : '" . ucfirst( $post_title ) . "' $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'export_portfolio_layout', 'ualp_hook_export_portfolio_layout', 1, 20 );

if ( ! function_exists( 'ualp_hook_create_post_type' ) ) {
	/**
	 * Add log for create custom post type.
	 *
	 * @param string $layout Layout.
	 */
	function ualp_hook_create_post_type( $layout ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'create_post_type', $log_hook_list ) ) {
			$action      = 'Post type created successfully';
			$post_title  = $layout;
			$obj_type    = 'Portfolio Designer';
			$post_id     = '';
			$hook        = 'create_post_type';
			$description = "$obj_type : '" . ucfirst( $post_title ) . "' $action";
			$uactid      = ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
			$update_info = array(
				'title'  => $post_title,
				'action' => $action,
			);
			if ( 0 != $uactid ) {
				ualp_add_activity_log_detail( $uactid, $update_info );
			}
		}
	}
}
add_action( 'create_post_type', 'ualp_hook_create_post_type', 1, 20 );


if ( ! function_exists( 'ualp_hook_post_type_updated' ) ) {
	/**
	 * Add log for update custom post type.
	 *
	 * @param int $id ID.
	 */
	function ualp_hook_post_type_updated( $id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'update_post_type', $log_hook_list ) ) {
			$action      = 'Post type updated successfully';
			$obj_type    = 'Portfolio Designer';
			$post_id     = $id;
			$post_title  = $post_id;
			$hook        = 'update_post_type';
			$description = "$obj_type : '" . ucfirst( $post_title ) . "' $action";
			$uactid      = ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
			$update_info = array(
				'title'  => $post_title,
				'action' => $action,
			);
			if ( 0 != $uactid ) {
				ualp_add_activity_log_detail( $uactid, $update_info );
			}
		}
	}
}
add_action( 'update_post_type', 'ualp_hook_post_type_updated', 1, 20 );


if ( ! function_exists( 'ualp_hook_delete_post_type' ) ) {
	/**
	 * Add log for delete custom post type.
	 *
	 * @param string $layout Layout.
	 */
	function ualp_hook_delete_post_type( $layout ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'delete_post_type', $log_hook_list ) ) {
			$action      = 'Post type deleted successfully';
			$post_title  = $layout;
			$obj_type    = 'Portfolio Designer';
			$post_id     = '';
			$hook        = 'delete_post_type';
			$description = "$obj_type : '" . ucfirst( $post_title ) . "' $action";
			$uactid      = ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
			$update_info = array(
				'title'  => $post_title,
				'action' => $action,
			);
			if ( 0 != $uactid ) {
				ualp_add_activity_log_detail( $uactid, $update_info );
			}
		}
	}
}
add_action( 'delete_post_type', 'ualp_hook_delete_post_type', 1, 20 );
