<?php
/**
 * User Swtiching Hook.
 *
 * @package User Activity Log PRO
 */

if ( ! function_exists( 'ualp_hook_switch_to_user' ) ) {
	/**
	 * Fires when a user switches to another user account.
	 *
	 * @param int $user_id User ID.
	 * @param int $old_user_id Old User ID.
	 */
	function ualp_hook_switch_to_user( $user_id, $old_user_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'switch_to_user', $log_hook_list ) ) {
			$user_info     = get_userdata( $user_id );
			$user_name     = isset( $user_info->display_name ) ? $user_info->display_name : '';
			$old_user_info = get_userdata( $old_user_id );
			$old_user_name = isset( $old_user_info->display_name ) ? $old_user_info->display_name : '';
			$obj_type      = 'User Switching';
			$action        = 'Switched to';
			$post_id       = '';
			$post_title    = '';
			$hook          = 'switch_to_user';
			$description   = "$obj_type : '" . ucfirst( $old_user_name ) . "' $action '" . ucfirst( $user_name ) . "'";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'switch_to_user', 'ualp_hook_switch_to_user', 15, 2 );

if ( ! function_exists( 'ualp_hook_switch_back_user' ) ) {
	/**
	 * Fires when a user switches back to their originating account.
	 *
	 * @param int $user_id User ID.
	 * @param int $old_user_id Old User ID.
	 */
	function ualp_hook_switch_back_user( $user_id, $old_user_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'switch_back_user', $log_hook_list ) ) {
			$user_info     = get_userdata( $user_id );
			$user_name     = isset( $user_info->display_name ) ? $user_info->display_name : '';
			$old_user_info = get_userdata( $old_user_id );
			$old_user_name = isset( $old_user_info->display_name ) ? $old_user_info->display_name : '';
			$obj_type      = 'User Switching';
			$action        = 'Switched back to';
			$post_id       = '';
			$post_title    = '';
			$hook          = 'switch_back_user';
			$description   = "$obj_type : '" . ucfirst( $old_user_name ) . "' $action '" . ucfirst( $user_name ) . "'";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'switch_back_user', 'ualp_hook_switch_back_user', 15, 2 );

if ( ! function_exists( 'ualp_hook_switch_off_user' ) ) {
	/**
	 * Fires when a user switches off.
	 *
	 * @param int $old_user_id Old User ID.
	 */
	function ualp_hook_switch_off_user( $old_user_id ) {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'switch_off_user', $log_hook_list ) ) {
			$old_user_info = get_userdata( $old_user_id );
			$old_user_name = isset( $old_user_info->display_name ) ? $old_user_info->display_name : '';
			$obj_type      = 'User Switching';
			$action        = 'Switched off user';
			$post_id       = '';
			$post_title    = $old_user_id;
			$hook          = 'switch_off_user';
			$description   = "$obj_type : '" . ucfirst( $old_user_name ) . "' $action '";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'switch_off_user', 'ualp_hook_switch_off_user', 15, 1 );
