<?php
/**
 * Wordfence Hook.
 *
 * @package User Activity Log PRO
 */

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'ualp_hook_update_issue_status' ) ) {
	/**
	 * Fires when Issue Status Updated.
	 */
	function ualp_hook_update_issue_status() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wp_ajax_wordfence_updateIssueStatus', $log_hook_list ) ) {
			$action      = 'Updated';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Issue Status';
			$hook        = 'wordfence_updateIssueStatus';
			$description = "$obj_type : $post_title $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_updateIssueStatus', 'ualp_hook_update_issue_status' );

if ( ! function_exists( 'ualp_hook_save_waf_config' ) ) {
	/**
	 * Fires when WAF Config Updated.
	 */
	function ualp_hook_save_waf_config() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wp_ajax_wordfence_saveWAFConfig', $log_hook_list ) ) {
			$action      = 'Updated';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'WAF Config';
			$hook        = 'wordfence_saveWAFConfig';
			$description = "$obj_type : $post_title $action";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_saveWAFConfig', 'ualp_hook_save_waf_config' );

if ( ! function_exists( 'ualp_hook_optimize_waf_firewall' ) ) {
	/**
	 * Fires when optimize WAF Firewall.
	 */
	function ualp_hook_optimize_waf_firewall() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wp_ajax_wordfence_wafConfigureAutoPrepend', $log_hook_list ) ) {
			$action      = 'Optimize';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Firewall';
			$hook        = 'wordfence_wafConfigureAutoPrepend';
			$description = "$action : $obj_type $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_wafConfigureAutoPrepend', 'ualp_hook_optimize_waf_firewall' );

if ( ! function_exists( 'ualp_hook_whitelist_bulk_enable' ) ) {
	/**
	 * Fires when Bulk Enable whitelist.
	 */
	function ualp_hook_whitelist_bulk_enable() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wp_ajax_wordfence_whitelistBulkEnable', $log_hook_list ) ) {
			$action      = 'Updated';
			$obj_type    = 'WordFence';
			$post_id     = '';
			$post_title  = 'Bulk Enable whitelist';
			$hook        = 'wordfence_whitelistBulkEnable';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_whitelistBulkEnable', 'ualp_hook_whitelist_bulk_enable' );

if ( ! function_exists( 'ualp_hook_whitelist_bulk_disable' ) ) {
	/**
	 * Fires when Bulk Disable Whitelist.
	 */
	function ualp_hook_whitelist_bulk_disable() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_whitelistBulkDisable', $log_hook_list ) ) {
			$action      = 'Updated';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Bulk Disable Whitelist';
			$hook        = 'wordfence_whitelistBulkDisable';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_whitelistBulkDisable', 'ualp_hook_whitelist_bulk_disable' );

if ( ! function_exists( 'ualp_hook_whitelist_bulk_delete' ) ) {
	/**
	 * Fires when Bulk Deleted Whitelist.
	 */
	function ualp_hook_whitelist_bulk_delete() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_whitelistBulkDelete', $log_hook_list ) ) {
			$action      = 'Updated';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Bulk Deleted Whitelist';
			$hook        = 'wordfence_whitelistBulkDelete';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_whitelistBulkDelete', 'ualp_hook_whitelist_bulk_delete' );

if ( ! function_exists( 'ualp_hook_update_word_fence_config' ) ) {
	/**
	 * Fires when Wordfence config updated.
	 */
	function ualp_hook_update_word_fence_config() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_updateConfig', $log_hook_list ) ) {
			$action      = 'Updated';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Wordfence config updated';
			$hook        = 'wordfence_updateConfig';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_updateConfig', 'ualp_hook_update_word_fence_config' );

if ( ! function_exists( 'ualp_hook_load_live_traffic' ) ) {
	/**
	 * Fires when Load Live Traffic.
	 */
	function ualp_hook_load_live_traffic() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_loadLiveTraffic', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Load Live Traffic';
			$hook        = 'wordfence_loadLiveTraffic';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_loadLiveTraffic', 'ualp_hook_load_live_traffic' );

if ( ! function_exists( 'ualp_hook_load_cache_exclusions' ) ) {
	/**
	 * Fires when Load Cache Exclusions.
	 */
	function ualp_hook_load_cache_exclusions() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_loadCacheExclusions', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Load Cache Exclusions';
			$hook        = 'wordfence_loadCacheExclusions';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_loadCacheExclusions', 'ualp_hook_load_cache_exclusions' );

if ( ! function_exists( 'ualp_hook_save_cache_config' ) ) {
	/**
	 * Fires when Save Cache Config.
	 */
	function ualp_hook_save_cache_config() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_saveCacheConfig', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Save Cache Config';
			$hook        = 'wordfence_saveCacheConfig';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_saveCacheConfig', 'ualp_hook_save_cache_config' );

if ( ! function_exists( 'ualp_hook_wordfence_cache_clear' ) ) {
	/**
	 * Fires when Clear cache.
	 */
	function ualp_hook_wordfence_cache_clear() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_cache_clear', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Clear cache';
			$hook        = 'wordfence_cache_clear';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wordfence_cache_clear', 'ualp_hook_wordfence_cache_clear' );

if ( ! function_exists( 'ualp_hook_reverse_lookup' ) ) {
	/**
	 * Fires when Reverse Look up.
	 */
	function ualp_hook_reverse_lookup() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_reverseLookup', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Reverse Look up';
			$hook        = 'wordfence_reverseLookup';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_reverseLookup', 'ualp_hook_reverse_lookup' );

if ( ! function_exists( 'ualp_hook_whois' ) ) {
	/**
	 * Fires when WHOIS Lookup.
	 */
	function ualp_hook_whois() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_whois', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'WHOIS Lookup';
			$hook        = 'wordfence_whois';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_whois', 'ualp_hook_whois' );

if ( ! function_exists( 'ualp_hook_clear_page_cache' ) ) {
	/**
	 * Fires when Clear Page Cache.
	 */
	function ualp_hook_clear_page_cache() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_clearPageCache', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Clear Page Cache';
			$hook        = 'wordfence_clearPageCache';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_clearPageCache', 'ualp_hook_clear_page_cache' );

if ( ! function_exists( 'ualp_hook_save_config' ) ) {
	/**
	 * Fires when Save Configuration.
	 */
	function ualp_hook_save_config() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_saveConfig', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Save Configuration';
			$hook        = 'wordfence_saveConfig';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_saveConfig', 'ualp_hook_save_config' );

if ( ! function_exists( 'ualp_hook_block_ip' ) ) {
	/**
	 * Fires when add IP for Block.
	 */
	function ualp_hook_block_ip() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_blockIP', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'wordfence';
			$post_id     = '';
			$post_title  = 'Block IP';
			$hook        = 'wordfence_blockIP';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_blockIP', 'ualp_hook_block_ip' );

if ( ! function_exists( 'ualp_hook_add_two_factor' ) ) {
	/**
	 * Fires when Enable Cellphone Sign in.
	 */
	function ualp_hook_add_two_factor() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_addTwoFactor', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Add Two Factor - Enable Cellphone Sign in';
			$hook        = 'wordfence_addTwoFactor';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_addTwoFactor', 'ualp_hook_add_two_factor' );

if ( ! function_exists( 'ualp_hook_export_settings' ) ) {
	/**
	 * Fires when Export Settings.
	 */
	function ualp_hook_export_settings() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_exportSettings', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Export Settings';
			$hook        = 'wordfence_exportSettings';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_exportSettings', 'ualp_hook_export_settings' );

if ( ! function_exists( 'ualp_hook_clear_all_blocked' ) ) {
	/**
	 * Fires when Clear All Blocked IP.
	 */
	function ualp_hook_clear_all_blocked() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_clearAllBlocked', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Clear All Blocked';
			$hook        = 'wordfence_clearAllBlocked';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_clearAllBlocked', 'ualp_hook_clear_all_blocked' );

if ( ! function_exists( 'ualp_hook_block_ip_ua_range' ) ) {
	/**
	 * Fires when set Block IP UA Range.
	 */
	function ualp_hook_block_ip_ua_range() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_blockIPUARange', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Block IP UA Range';
			$hook        = 'wordfence_blockIPUARange';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_blockIPUARange', 'ualp_hook_block_ip_ua_range' );

if ( ! function_exists( 'ualp_hook_unblock_range' ) ) {
	/**
	 * Fires when Unblock IP Range.
	 */
	function ualp_hook_unblock_range() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_unblockRange', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Unblock Range';
			$hook        = 'wordfence_unblockRange';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_unblockRange', 'ualp_hook_unblock_range' );

if ( ! function_exists( 'ualp_hook_save_country_blocking' ) ) {
	/**
	 * Fires when save country blocking.
	 */
	function ualp_hook_save_country_blocking() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_saveCountryBlocking', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Save Country Blocking';
			$hook        = 'wordfence_saveCountryBlocking';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_saveCountryBlocking', 'ualp_hook_save_country_blocking' );

if ( ! function_exists( 'ualp_hook_save_debugging_config' ) ) {
	/**
	 * Fires when Save Debugging Config.
	 */
	function ualp_hook_save_debugging_config() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_saveDebuggingConfig', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Save Debugging Config';
			$hook        = 'wordfence_saveDebuggingConfig';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_saveDebuggingConfig', 'ualp_hook_save_debugging_config' );

if ( ! function_exists( 'ualp_hook_start_passwd_audit' ) ) {
	/**
	 * Fires when Start Password Audit.
	 */
	function ualp_hook_start_passwd_audit() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_startPasswdAudit', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Start Password Audit';
			$hook        = 'wordfence_startPasswdAudit';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_startPasswdAudit', 'ualp_hook_start_passwd_audit' );

if ( ! function_exists( 'ualp_hook_save_scan_schedule' ) ) {
	/**
	 * Fires when save scan schedule.
	 */
	function ualp_hook_save_scan_schedule() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_saveScanSchedule', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Save Scan Schedule';
			$hook        = 'wordfence_saveScanSchedule';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_saveScanSchedule', 'ualp_hook_save_scan_schedule' );

if ( ! function_exists( 'ualp_hook_update_waf_rules' ) ) {
	/**
	 * Fires when WAF Rules update.
	 */
	function ualp_hook_update_waf_rules() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_updateWAFRules', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'update WAF Rules';
			$hook        = 'wordfence_updateWAFRules';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_updateWAFRules', 'ualp_hook_update_waf_rules' );

if ( ! function_exists( 'ualp_hook_send_test_email' ) ) {
	/**
	 * Fires when Send Test Email.
	 */
	function ualp_hook_send_test_email() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_sendTestEmail', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Send Test Email';
			$hook        = 'wordfence_sendTestEmail';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_sendTestEmail', 'ualp_hook_send_test_email' );

if ( ! function_exists( 'ualp_hook_send_diagnostic' ) ) {
	/**
	 * Fires when Send Diagnostic.
	 */
	function ualp_hook_send_diagnostic() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_sendDiagnostic', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Send Diagnostic';
			$hook        = 'wordfence_sendDiagnostic';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_sendDiagnostic', 'ualp_hook_send_diagnostic' );

if ( ! function_exists( 'ualp_hook_update_all_issues' ) ) {
	/**
	 * Fires when Update All Issues.
	 */
	function ualp_hook_update_all_issues() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_updateAllIssues', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Update All Issues';
			$hook        = 'wordfence_updateAllIssues';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_updateAllIssues', 'ualp_hook_update_all_issues' );

if ( ! function_exists( 'ualp_hook_send_activity_log' ) ) {
	/**
	 * Fires when Send Activity Log.
	 */
	function ualp_hook_send_activity_log() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_sendActivityLog', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Send Activity Log';
			$hook        = 'wordfence_sendActivityLog';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_sendActivityLog', 'ualp_hook_send_activity_log' );

if ( ! function_exists( 'ualp_hook_add_cache_exclusion' ) ) {
	/**
	 * Fires when Add Cache Exclusion.
	 */
	function ualp_hook_add_cache_exclusion() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_addCacheExclusion', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Add Cache Exclusion';
			$hook        = 'wordfence_addCacheExclusion';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_addCacheExclusion', 'ualp_hook_add_cache_exclusion' );

if ( ! function_exists( 'ualp_hook_daily_auto_update' ) ) {
	/**
	 * Fires when Daily Auto Update.
	 */
	function ualp_hook_daily_auto_update() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Daily Auto Update';
			$hook        = 'wordfence_daily_autoUpdate';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wordfence_daily_autoUpdate', 'ualp_hook_daily_auto_update' );

if ( ! function_exists( 'ualp_hook_update_blocked_ips' ) ) {
	/**
	 * Fires when Update blocked IPs.
	 */
	function ualp_hook_update_blocked_ips() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_update_blocked_IPs', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Update blocked IPs';
			$hook        = 'wordfence_update_blocked_IPs';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wordfence_update_blocked_IPs', 'ualp_hook_update_blocked_ips' );

if ( ! function_exists( 'ualp_hook_start_scheduled_scan' ) ) {
	/**
	 * Fires when Start scheduled scan.
	 */
	function ualp_hook_start_scheduled_scan() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_start_scheduled_scan', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Start scheduled scan';
			$hook        = 'wordfence_start_scheduled_scan';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wordfence_start_scheduled_scan', 'ualp_hook_start_scheduled_scan' );

if ( ! function_exists( 'ualp_hook_wordfence_do_scan' ) ) {
	/**
	 * Fires when Do Scan.
	 */
	function ualp_hook_wordfence_do_scan() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_doScan', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Do Scan';
			$hook        = 'wordfence_doScan';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_doScan', 'ualp_hook_wordfence_do_scan' );

if ( ! function_exists( 'ualp_hook_daily_cron' ) ) {
	/**
	 * Fires when do Daily cron.
	 */
	function ualp_hook_daily_cron() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_daily_cron', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Daily cron';
			$hook        = 'wordfence_daily_cron';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wordfence_daily_cron', 'ualp_hook_daily_cron' );

if ( ! function_exists( 'ualp_hook_wordfence_hourly_cron' ) ) {
	/**
	 * Fires when do Hourly cron.
	 */
	function ualp_hook_wordfence_hourly_cron() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_hourly_cron', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Hourly cron';
			$hook        = 'wordfence_hourly_cron';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wordfence_hourly_cron', 'ualp_hook_wordfence_hourly_cron' );

if ( ! function_exists( 'ualp_hook_email_activity_report' ) ) {
	/**
	 * Fires when Email activity report.
	 */
	function ualp_hook_email_activity_report() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_email_activity_report', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Email activity report';
			$hook        = 'wordfence_email_activity_report';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wordfence_email_activity_report', 'ualp_hook_email_activity_report' );

if ( ! function_exists( 'ualp_hook_wordfence_scan' ) ) {
	/**
	 * Fires when start Scan.
	 */
	function ualp_hook_wordfence_scan() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_scan', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'wordfence';
			$post_id     = '';
			$post_title  = 'Scan';
			$hook        = 'wordfence_scan';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_scan', 'ualp_hook_wordfence_scan' );

if ( ! function_exists( 'ualp_hook_update_alert_email' ) ) {
	/**
	 * Fires when Update Alert Email.
	 */
	function ualp_hook_update_alert_email() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_updateAlertEmail', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Update Alert Email';
			$hook        = 'wordfence_updateAlertEmail';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_updateAlertEmail', 'ualp_hook_update_alert_email' );

if ( ! function_exists( 'ualp_hook_restore_file' ) ) {
	/**
	 * Fires when Restore File.
	 */
	function ualp_hook_restore_file() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_restoreFile', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Restore File';
			$hook        = 'wordfence_restoreFile';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_restoreFile', 'ualp_hook_restore_file' );

if ( ! function_exists( 'ualp_hook_delete_passwd_audit' ) ) {
	/**
	 * Fires when Delete Password Audit.
	 */
	function ualp_hook_delete_passwd_audit() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_deletePasswdAudit', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Delete Password Audit';
			$hook        = 'wordfence_deletePasswdAudit';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_deletePasswdAudit', 'ualp_hook_delete_passwd_audit' );

if ( ! function_exists( 'ualp_hook_weak_passwords_fix' ) ) {
	/**
	 * Fires when Fix weak passwords.
	 */
	function ualp_hook_weak_passwords_fix() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_weakPasswordsFix', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'wordfence';
			$post_id     = '';
			$post_title  = 'Fix weak passwords';
			$hook        = 'wordfence_weakPasswordsFix';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_weakPasswordsFix', 'ualp_hook_weak_passwords_fix' );

if ( ! function_exists( 'ualp_hook_kill_passwd_audit' ) ) {
	/**
	 * Fires when Kill Password Audit.
	 */
	function ualp_hook_kill_passwd_audit() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_killPasswdAudit', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Kill Password Audit';
			$hook        = 'wordfence_killPasswdAudit';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_killPasswdAudit', 'ualp_hook_kill_passwd_audit' );

if ( ! function_exists( 'ualp_hook_import_settings' ) ) {
	/**
	 * Fires when Import Settings.
	 */
	function ualp_hook_import_settings() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_importSettings', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Import Settings';
			$hook        = 'wordfence_importSettings';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_importSettings', 'ualp_hook_import_settings' );

if ( ! function_exists( 'ualp_hook_bulk_operation' ) ) {
	/**
	 * Fires when Bulk Operation.
	 */
	function ualp_hook_bulk_operation() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_bulkOperation', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'wordfence';
			$post_id     = '';
			$post_title  = 'Bulk Operation';
			$hook        = 'wordfence_bulkOperation';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_bulkOperation', 'ualp_hook_bulk_operation' );

if ( ! function_exists( 'ualp_hook_delete_file' ) ) {
	/**
	 * Fires when Delete File.
	 */
	function ualp_hook_delete_file() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_deleteFile', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Delete File';
			$hook        = 'wordfence_deleteFile';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_deleteFile', 'ualp_hook_delete_file' );

if ( ! function_exists( 'ualp_hook_delete_database_option' ) ) {
	/**
	 * Fires when Delete Database Option.
	 */
	function ualp_hook_delete_database_option() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_deleteDatabaseOption', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'wordfence';
			$post_id     = '';
			$post_title  = 'Delete Database Option';
			$hook        = 'wordfence_deleteDatabaseOption';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_deleteDatabaseOption', 'ualp_hook_delete_database_option' );

if ( ! function_exists( 'ualp_hook_remove_exclusion' ) ) {
	/**
	 * Fires when Remove Exclusion.
	 */
	function ualp_hook_remove_exclusion() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_removeExclusion', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Remove Exclusion';
			$hook        = 'wordfence_removeExclusion';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_removeExclusion', 'ualp_hook_remove_exclusion' );

if ( ! function_exists( 'ualp_hook_delete_issue' ) ) {
	/**
	 * Fires when Delete Issue.
	 */
	function ualp_hook_delete_issue() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_deleteIssue', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Delete Issue';
			$hook        = 'wordfence_deleteIssue';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_deleteIssue', 'ualp_hook_delete_issue' );

if ( ! function_exists( 'ualp_hook_unlock_out_ip' ) ) {
	/**
	 * Fires when Unlock Out IP.
	 */
	function ualp_hook_unlock_out_ip() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_unlockOutIP', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Unlock Out IP';
			$hook        = 'wordfence_unlockOutIP';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_unlockOutIP', 'ualp_hook_unlock_out_ip' );

if ( ! function_exists( 'ualp_hook_load_block_ranges' ) ) {
	/**
	 * Fires when Load Block Ranges.
	 */
	function ualp_hook_load_block_ranges() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_loadBlockRanges', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Load Block Ranges';
			$hook        = 'wordfence_loadBlockRanges';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_loadBlockRanges', 'ualp_hook_load_block_ranges' );

if ( ! function_exists( 'ualp_hook_unblock_ip' ) ) {
	/**
	 * Fires when Unblock IP.
	 */
	function ualp_hook_unblock_ip() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_unblockIP', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Unblock IP';
			$hook        = 'wordfence_unblockIP';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_unblockIP', 'ualp_hook_unblock_ip' );

if ( ! function_exists( 'ualp_hook_perm_block_ip' ) ) {
	/**
	 * Fires when Permanently Block IP.
	 */
	function ualp_hook_perm_block_ip() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_permBlockIP', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Permanently Block IP';
			$hook        = 'wordfence_permBlockIP';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_permBlockIP', 'ualp_hook_perm_block_ip' );

if ( ! function_exists( 'ualp_hook_download_htaccess' ) ) {
	/**
	 * Fires when Download Htaccess file.
	 */
	function ualp_hook_download_htaccess() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_downloadHtaccess', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Download Htaccess';
			$hook        = 'wordfence_downloadHtaccess';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_downloadHtaccess', 'ualp_hook_download_htaccess' );

if ( ! function_exists( 'ualp_hook_check_falcon_htaccess' ) ) {
	/**
	 * Fires when Check Falcon Htaccess.
	 */
	function ualp_hook_check_falcon_htaccess() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_checkFalconHtaccess', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Check Falcon Htaccess';
			$hook        = 'wordfence_checkFalconHtaccess';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_checkFalconHtaccess', 'ualp_hook_check_falcon_htaccess' );

if ( ! function_exists( 'ualp_hook_remove_from_cache' ) ) {
	/**
	 * Fires when Remove Cache.
	 */
	function ualp_hook_remove_from_cache() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_removeFromCache', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Remove From Cache';
			$hook        = 'wordfence_removeFromCache';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_removeFromCache', 'ualp_hook_remove_from_cache' );

if ( ! function_exists( 'ualp_hook_auto_update_choice' ) ) {
	/**
	 * Fires when Enable auto update.
	 */
	function ualp_hook_auto_update_choice() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_autoUpdateChoice', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Enable auto update';
			$hook        = 'wordfence_autoUpdateChoice';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_autoUpdateChoice', 'ualp_hook_auto_update_choice' );

if ( ! function_exists( 'ualp_hook_save_cache_options' ) ) {
	/**
	 * Fires when Save Cache Options.
	 */
	function ualp_hook_save_cache_options() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_saveCacheOptions', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Save Cache Options';
			$hook        = 'wordfence_saveCacheOptions';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_saveCacheOptions', 'ualp_hook_save_cache_options' );

if ( ! function_exists( 'ualp_hook_admin_email_choice' ) ) {
	/**
	 * Fires when Admin Email Choice.
	 */
	function ualp_hook_admin_email_choice() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_adminEmailChoice', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Admin Email Choice';
			$hook        = 'wordfence_adminEmailChoice';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_adminEmailChoice', 'ualp_hook_admin_email_choice' );

if ( ! function_exists( 'ualp_hook_get_cache_stats' ) ) {
	/**
	 * Fires when Get Cache Stats.
	 */
	function ualp_hook_get_cache_stats() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_getCacheStats', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Get Cache Stats';
			$hook        = 'wordfence_getCacheStats';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_getCacheStats', 'ualp_hook_get_cache_stats' );

if ( ! function_exists( 'ualp_hook_kill_scan' ) ) {
	/**
	 * Fires when Kill Scan.
	 */
	function ualp_hook_kill_scan() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_killScan', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Kill Scan';
			$hook        = 'wordfence_killScan';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_killScan', 'ualp_hook_kill_scan' );

if ( ! function_exists( 'ualp_hook_tour_closed' ) ) {
	/**
	 * Fires when plugin Tour Closed.
	 */
	function ualp_hook_tour_closed() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_tourClosed', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Tour Closed';
			$hook        = 'wordfence_tourClosed';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_tourClosed', 'ualp_hook_tour_closed' );


if ( ! function_exists( 'ualp_hook_remove_cache_exclusion' ) ) {
	/**
	 * Fires when Remove Cache Exclusion.
	 */
	function ualp_hook_remove_cache_exclusion() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_removeCacheExclusion', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Remove Cache Exclusion';
			$hook        = 'wordfence_removeCacheExclusion';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_removeCacheExclusion', 'ualp_hook_remove_cache_exclusion' );

if ( ! function_exists( 'ualp_hook_unblock_network' ) ) {
	/**
	 * Fires when Unblock Network.
	 */
	function ualp_hook_unblock_network() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_unblockNetwork', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Unblock Network';
			$hook        = 'wordfence_unblockNetwork';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_unblockNetwork', 'ualp_hook_unblock_network' );

if ( ! function_exists( 'ualp_hook_permanently_block_all_ips' ) ) {
	/**
	 * Fires when Permanently Block All IPs.
	 */
	function ualp_hook_permanently_block_all_ips() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_permanentlyBlockAllIPs', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Permanently Block All IPs';
			$hook        = 'wordfence_permanentlyBlockAllIPs';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_permanentlyBlockAllIPs', 'ualp_hook_permanently_block_all_ips' );

if ( ! function_exists( 'ualp_hook_delete_admin_user' ) ) {
	/**
	 * Fires when Delete Admin User.
	 */
	function ualp_hook_delete_admin_user() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_deleteAdminUser', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Delete Admin User';
			$hook        = 'wordfence_deleteAdminUser';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_deleteAdminUser', 'ualp_hook_delete_admin_user' );

if ( ! function_exists( 'ualp_hook_revoke_admin_user' ) ) {
	/**
	 * Fires when Revoke Admin User.
	 */
	function ualp_hook_revoke_admin_user() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_revokeAdminUser', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = 'Wordfence';
			$post_id     = '';
			$post_title  = 'Revoke Admin User';
			$hook        = 'wordfence_revokeAdminUser';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_revokeAdminUser', 'ualp_hook_revoke_admin_user' );

if ( ! function_exists( 'ualp_hook_hide_file_htaccess' ) ) {
	/**
	 * Fires when Hide htaccess file.
	 */
	function ualp_hook_hide_file_htaccess() {
		$log_hook_list = get_option( 'enableLogHookList' );
		if ( in_array( 'wordfence_hideFileHtaccess', $log_hook_list ) ) {
			$action      = '';
			$obj_type    = '';
			$post_id     = '';
			$post_title  = 'Hide htaccess file';
			$hook        = 'wordfence_hideFileHtaccess';
			$description = "$obj_type : $post_title";
			ualp_get_activity_log( $action, $obj_type, $post_id, $post_title, $hook, $description );
		}
	}
}
add_action( 'wp_ajax_wordfence_hideFileHtaccess', 'ualp_hook_hide_file_htaccess' );
