<?php
/**
 * List Table.
 *
 * @package User Activity Log PRO
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @author     Solwin Infotech <info@solwininfotech.com>
 */
class UALP_Admin_Ui {
	/**
	 * The current version of the plugin.
	 *
	 * @since  1.0.0
	 * @access protected
	 * @var    string    $list_table    List Table.
	 */
	protected $list_table = null;

	/**
	 * The current version of the plugin.
	 *
	 * @since  1.0.0
	 * @access protected
	 * @var    array    $screens    Screens.
	 */
	protected $screens = array();
	/**
	 * Class Cunstructor.
	 *
	 * @since  1.0.0
	 */
	public function __construct() {
		if ( ualp_multi_site_support_return() ) {
			add_action( 'network_admin_menu', array( &$this, 'create_admin_menu' ), 20 );
		}
		add_action( 'admin_menu', array( &$this, 'create_admin_menu' ), 20 );
		if ( is_admin() ) {
			add_action( 'wp_ajax_ualp_get_show_data_table_ajax', array( $this, 'ualp_get_show_data_table_ajax' ) );
			add_action( 'wp_ajax_nopriv_ualp_get_show_data_table_ajax', array( $this, 'ualp_get_show_data_table_ajax' ) );
		}
	}
	/**
	 * Creates Admin menu.
	 */
	public function create_admin_menu() {
		$ualp_role_access_list = get_option( 'ualpRoleAccessList' );
		$ualp_user_access_list = get_option( 'ualpUserAccessList' );
		$current_user          = wp_get_current_user();
		$current_user_name     = $current_user->ID;
		$ualp_multisite_menu   = get_site_option( 'ualpMultisiteMenu' );

		if ( is_plugin_active( 'bbpress/bbpress.php' ) ) {
			if ( is_multisite() ) {
				$id              = get_current_user_id();
				$primary_blog_no = get_user_meta( $id, 'primary_blog' );
				if ( $primary_blog_no[0] > 1 ) {
					$usermeta = get_user_meta( $id, 'wp_' . $primary_blog_no[0] . '_capabilities' );
				} else {
					$usermeta = get_user_meta( $id, 'wp_capabilities' );
				}
				if ( is_array( $usermeta[0] ) ) {
					$current_userrolls = array_keys( $usermeta[0] );
				} else {
					$current_userrolls = $usermeta;
				}
				if ( isset( $current_userrolls[0] ) ) {
					$current_user_role = $current_userrolls[0];
				}
			} else {
				if ( isset( $current_user->roles[0] ) ) {
					$current_user_role = $current_user->roles[0];
				}
			}
		} else {
			if ( isset( $current_user->roles[0] ) ) {
				$current_user_role = $current_user->roles[0];
			} else {
				if ( is_multisite() ) {
					$id       = get_current_user_id();
					$usermeta = get_user_meta( $id, 'wp_capabilities' );
					if ( is_array( $usermeta[0] ) ) {
						$current_userrolls = array_keys( $usermeta[0] );
					} else {
						$current_userrolls = $usermeta;
					}
					if ( isset( $current_userrolls[0] ) ) {
						$current_user_role = $current_userrolls[0];
					}
				}
			}
		}
		if ( is_array( $ualp_role_access_list ) && is_array( $ualp_user_access_list ) && ! empty( $ualp_role_access_list ) && ! empty( $ualp_user_access_list ) && isset( $current_user_role ) && 'administrator' != $current_user_role ) {
			if ( in_array( $current_user_role, $ualp_role_access_list ) && in_array( $current_user_name, $ualp_user_access_list ) ) {
				if ( ualp_multi_site_support_return() && ! is_network_admin() ) {
					$this->screens['main'] = add_menu_page( __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'User Activity Log', 'user_activity_log_pro' ), $current_user_role, 'ual_pro', array( &$this, 'ualp_log_page_func' ), UALP_PLUGIN_URL . '/assets/images/menu-icon.png' );
					if ( 1 == $ualp_multisite_menu ) {
						add_submenu_page( 'ual_pro', esc_html__( 'Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Settings', 'user_activity_log_pro' ), 'manage_options', 'ualp_settings', 'ualp_settings_panel', 40 );
					}
					$hook = add_submenu_page( 'ual_pro', esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ), $current_user_role, 'ualp_user_details', 'ualp_logged_in_users_settings', 10 );
					add_action( 'load-' . $hook, array( &$this, 'usersetting_logged_submenupage_screen_options' ) );
				} else {
					$this->screens['main'] = add_menu_page( __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'User Activity Log', 'user_activity_log_pro' ), $current_user_role, 'ual_pro', array( &$this, 'ualp_log_page_func' ), UALP_PLUGIN_URL . '/assets/images/menu-icon.png' );
					$hook                  = add_submenu_page( 'ual_pro', esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ), $current_user_role, 'ualp_user_details', 'ualp_logged_in_users_settings', 10 );
					add_action( 'load-' . $hook, array( &$this, 'usersetting_logged_submenupage_screen_options' ) );
					$email_hook = add_submenu_page( 'ual_pro', esc_html__( 'Email Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Email Settings', 'user_activity_log_pro' ), $current_user_role, 'ualp_email_setting', 'ualp_email_settings', 20 );
					add_action( 'load-' . $email_hook, array( &$this, 'usersetting_email_submenupage_screen_options' ) );
					add_submenu_page( 'ual_pro', esc_html__( 'Add Email Notification', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Add Email Notification', 'user_activity_log_pro' ), $current_user_role, 'ualp_add_email_notification', 'ualp_add_email_settings', 30 );
					$sms_hook = add_submenu_page( 'ual_pro', esc_html__( 'SMS Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'SMS Settings', 'user_activity_log_pro' ), $current_user_role, 'ualp_sms_setting', 'ualpSmsSettings', 20 );
					add_action( 'load-' . $sms_hook, array( &$this, 'usersetting_sms_submenupage_screen_options' ) );
					add_submenu_page( 'ual_pro', esc_html__( 'Add SMS Notification', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Add SMS Notification', 'user_activity_log_pro' ), $current_user_role, 'ualp_add_sms_notification', 'ualp_add_sms_settings', 30 );
					add_submenu_page( 'ual_pro', esc_html__( 'Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Settings', 'user_activity_log_pro' ), $current_user_role, 'ualp_settings', 'ualp_settings_panel', 40 );
					add_submenu_page( 'ual_pro', esc_html__( 'Reports', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Reports', 'user_activity_log_pro' ), $current_user_role, 'ualp_reports', 'ualp_reports', 50 );
					add_submenu_page( 'ual_pro', esc_html__( 'DB Integration', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'DB Integration', 'user_activity_log_pro' ), $current_user_role, 'ualp_db_integration', 'ualp_dbintegration', 60 );
					add_submenu_page( 'ual_pro', esc_html__( 'License Key', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'License Key', 'user_activity_log_pro' ), $current_user_role, 'ualp_license_key', 'ualp_licensekey', 70 );
					add_action( 'load-' . $this->screens['main'], array( &$this, 'get_list_table' ) );
				}
			}
		} elseif ( is_array( $ualp_role_access_list ) && ! empty( $ualp_role_access_list ) && isset( $current_user_role ) && 'administrator' != $current_user_role ) {
			foreach ( $ualp_role_access_list as $ualp_role ) {
				if ( isset( $current_user_role ) && $current_user_role == $ualp_role ) {
					if ( ualp_multi_site_support_return() && ! is_network_admin() ) {
						$this->screens['main'] = add_menu_page( __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'User Activity Log', 'user_activity_log_pro' ), $ualp_role, 'ual_pro', array( &$this, 'ualp_log_page_func' ), UALP_PLUGIN_URL . '/assets/images/menu-icon.png' );
						if ( 1 == $ualp_multisite_menu ) {
							add_submenu_page( 'ual_pro', esc_html__( 'Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Settings', 'user_activity_log_pro' ), 'manage_options', 'ualp_settings', 'ualp_settings_panel', 40 );
						}
						$hook = add_submenu_page( 'ual_pro', esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ), $ualp_role, 'ualp_user_details', 'ualp_logged_in_users_settings', 10 );
						add_action( 'load-' . $hook, array( &$this, 'usersetting_logged_submenupage_screen_options' ) );
					} else {
						$this->screens['main'] = add_menu_page( __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'User Activity Log', 'user_activity_log_pro' ), $ualp_role, 'ual_pro', array( &$this, 'ualp_log_page_func' ), UALP_PLUGIN_URL . '/assets/images/menu-icon.png' );
						$hook                  = add_submenu_page( 'ual_pro', esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ), $ualp_role, 'ualp_user_details', 'ualp_logged_in_users_settings', 10 );
						add_action( 'load-' . $hook, array( &$this, 'usersetting_logged_submenupage_screen_options' ) );
						$email_hook = add_submenu_page( 'ual_pro', esc_html__( 'Email Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Email Settings', 'user_activity_log_pro' ), $ualp_role, 'ualp_email_setting', 'ualp_email_settings', 20 );
						add_action( 'load-' . $email_hook, array( &$this, 'usersetting_email_submenupage_screen_options' ) );
						add_submenu_page( 'ual_pro', esc_html__( 'Add Email Notification', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Add Email Notification', 'user_activity_log_pro' ), $ualp_role, 'ualp_add_email_notification', 'ualp_add_email_settings', 30 );
						$sms_hook = add_submenu_page( 'ual_pro', esc_html__( 'SMS Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'SMS Settings', 'user_activity_log_pro' ), $ualp_role, 'ualp_sms_setting', 'ualpSmsSettings', 20 );
						add_action( 'load-' . $sms_hook, array( &$this, 'usersetting_sms_submenupage_screen_options' ) );
						add_submenu_page( 'ual_pro', esc_html__( 'Add SMS Notification', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Add SMS Notification', 'user_activity_log_pro' ), $ualp_role, 'ualp_add_sms_notification', 'ualp_add_sms_settings', 30 );
						add_submenu_page( 'ual_pro', esc_html__( 'Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Settings', 'user_activity_log_pro' ), $ualp_role, 'ualp_settings', 'ualp_settings_panel', 40 );
						add_submenu_page( 'ual_pro', esc_html__( 'Reports', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Reports', 'user_activity_log_pro' ), $ualp_role, 'ualp_reports', 'ualp_reports', 50 );
						add_submenu_page( 'ual_pro', esc_html__( 'DB Integration', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'DB Integration', 'user_activity_log_pro' ), $ualp_role, 'ualp_db_integration', 'ualp_dbintegration', 60 );
						add_submenu_page( 'ual_pro', esc_html__( 'License Key', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'License Key', 'user_activity_log_pro' ), $ualp_role, 'ualp_license_key', 'ualp_licensekey', 70 );
						add_action( 'load-' . $this->screens['main'], array( &$this, 'get_list_table' ) );
					}
				}
			}
		} elseif ( is_array( $ualp_user_access_list ) && ! empty( $ualp_user_access_list ) && isset( $current_user_role ) && 'administrator' != $current_user_role ) {
			foreach ( $ualp_user_access_list as $ualp_user ) {
				if ( isset( $current_user_name ) && $current_user_name == $ualp_user ) {
					if ( ualp_multi_site_support_return() && ! is_network_admin() ) {
						$this->screens['main'] = add_menu_page( __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'User Activity Log', 'user_activity_log_pro' ), $current_user_role, 'ual_pro', array( &$this, 'ualp_log_page_func' ), UALP_PLUGIN_URL . '/assets/images/menu-icon.png' );
						if ( 1 == $ualp_multisite_menu ) {
							add_submenu_page( 'ual_pro', esc_html__( 'Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Settings', 'user_activity_log_pro' ), 'manage_options', 'ualp_settings', 'ualp_settings_panel', 40 );
						}
						$hook = add_submenu_page( 'ual_pro', esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ), $current_user_role, 'ualp_user_details', 'ualp_logged_in_users_settings' );
						add_action( 'load-' . $hook, array( &$this, 'usersetting_logged_submenupage_screen_options' ) );
					} else {
						$this->screens['main'] = add_menu_page( __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'User Activity Log', 'user_activity_log_pro' ), $current_user_role, 'ual_pro', array( &$this, 'ualp_log_page_func' ), UALP_PLUGIN_URL . '/assets/images/menu-icon.png' );
						$hook                  = add_submenu_page( 'ual_pro', esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ), $current_user_role, 'ualp_user_details', 'ualp_logged_in_users_settings', 10 );
						add_action( 'load-' . $hook, array( &$this, 'usersetting_logged_submenupage_screen_options' ) );
						$email_hook = add_submenu_page( 'ual_pro', esc_html__( 'Email Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Email Settings', 'user_activity_log_pro' ), $current_user_role, 'ualp_email_setting', 'ualp_email_settings', 20 );
						add_action( 'load-' . $email_hook, array( &$this, 'usersetting_email_submenupage_screen_options' ) );
						add_submenu_page( 'ual_pro', esc_html__( 'Add Email Notification', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Add Email Notification', 'user_activity_log_pro' ), $current_user_role, 'ualp_add_email_notification', 'ualp_add_email_settings', 30 );
						$sms_hook = add_submenu_page( 'ual_pro', esc_html__( 'SMS Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'SMS Settings', 'user_activity_log_pro' ), $current_user_role, 'ualp_sms_setting', 'ualpSmsSettings', 20 );
						add_action( 'load-' . $sms_hook, array( &$this, 'usersetting_sms_submenupage_screen_options' ) );
						add_submenu_page( 'ual_pro', esc_html__( 'Add SMS Notification', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Add SMS Notification', 'user_activity_log_pro' ), $current_user_role, 'ualp_add_sms_notification', 'ualp_add_sms_settings', 30 );
						add_submenu_page( 'ual_pro', esc_html__( 'Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Settings', 'user_activity_log_pro' ), $current_user_role, 'ualp_settings', 'ualp_settings_panel', 40 );
						add_submenu_page( 'ual_pro', esc_html__( 'Reports', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Reports', 'user_activity_log_pro' ), $current_user_role, 'ualp_reports', 'ualp_reports', 50 );
						add_submenu_page( 'ual_pro', esc_html__( 'DB Integration', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'DB Integration', 'user_activity_log_pro' ), $current_user_role, 'ualp_db_integration', 'ualp_dbintegration', 60 );
						add_submenu_page( 'ual_pro', esc_html__( 'License Key', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'License Key', 'user_activity_log_pro' ), $current_user_role, 'ualp_license_key', 'ualp_licensekey', 70 );
						add_action( 'load-' . $this->screens['main'], array( &$this, 'get_list_table' ) );
					}
				}
			}
		} else {
			if ( isset( $current_user_role ) && 'administrator' == $current_user_role ) {
				if ( ualp_multi_site_support_return() && ! is_network_admin() ) {
					$this->screens['main'] = add_menu_page( __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'User Activity Log', 'user_activity_log_pro' ), 'manage_options', 'ual_pro', array( &$this, 'ualp_log_page_func' ), UALP_PLUGIN_URL . '/assets/images/menu-icon.png' );
					if ( 1 == $ualp_multisite_menu ) {
						add_submenu_page( 'ual_pro', esc_html__( 'Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Settings', 'user_activity_log_pro' ), 'manage_options', 'ualp_settings', 'ualp_settings_panel', 40 );
					}
					$hook = add_submenu_page( 'ual_pro', esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ), 'manage_options', 'ualp_user_details', 'ualp_logged_in_users_settings', 10 );
					add_action( 'load-' . $hook, array( &$this, 'usersetting_logged_submenupage_screen_options' ) );
				} else {
					$this->screens['main'] = add_menu_page( __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'User Activity Log', 'user_activity_log_pro' ), 'manage_options', 'ual_pro', array( &$this, 'ualp_log_page_func' ), UALP_PLUGIN_URL . '/assets/images/menu-icon.png' );
					$hook                  = add_submenu_page( 'ual_pro', esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Logged In/Logged Out Users', 'user_activity_log_pro' ), 'manage_options', 'ualp_user_details', 'ualp_logged_in_users_settings', 10 );
					add_action( 'load-' . $hook, array( &$this, 'usersetting_logged_submenupage_screen_options' ) );
					$email_hook = add_submenu_page( 'ual_pro', esc_html__( 'Email Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Email Settings', 'user_activity_log_pro' ), 'manage_options', 'ualp_email_setting', 'ualp_email_settings', 20 );
					add_action( 'load-' . $email_hook, array( &$this, 'usersetting_email_submenupage_screen_options' ) );
					add_submenu_page( 'ual_pro', esc_html__( 'Add Email Notification', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Add Email Notification', 'user_activity_log_pro' ), 'manage_options', 'ualp_add_email_notification', 'ualp_add_email_settings', 30 );
					$sms_hook = add_submenu_page( 'ual_pro', esc_html__( 'SMS Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'SMS Settings', 'user_activity_log_pro' ), 'manage_options', 'ualp_sms_setting', 'ualpSmsSettings', 20 );
					add_action( 'load-' . $sms_hook, array( &$this, 'usersetting_sms_submenupage_screen_options' ) );
					add_submenu_page( 'ual_pro', esc_html__( 'Add SMS Notification', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Add SMS Notification', 'user_activity_log_pro' ), 'manage_options', 'ualp_add_sms_notification', 'ualp_add_sms_settings', 30 );
					add_submenu_page( 'ual_pro', esc_html__( 'Settings', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Settings', 'user_activity_log_pro' ), 'manage_options', 'ualp_settings', 'ualp_settings_panel', 40 );
					add_submenu_page( 'ual_pro', esc_html__( 'Reports', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'Reports', 'user_activity_log_pro' ), 'manage_options', 'ualp_reports', 'ualp_reports', 50 );
					add_submenu_page( 'ual_pro', esc_html__( 'DB Integration', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'DB Integration', 'user_activity_log_pro' ), 'manage_options', 'ualp_db_integration', 'ualp_dbintegration', 60 );
					add_submenu_page( 'ual_pro', esc_html__( 'License Key', 'user_activity_log_pro' ) . ' | ' . __( 'User Activity Log', 'user_activity_log_pro' ), esc_html__( 'License Key', 'user_activity_log_pro' ), 'manage_options', 'ualp_license_key', 'ualp_licensekey', 70 );
					add_action( 'load-' . $this->screens['main'], array( &$this, 'get_list_table' ) );
				}
			}
		}
	}

	/**
	 * Function for Log Page.
	 */
	public function ualp_log_page_func() {
		global $wpdb, $externaldb,$allhookdetails;
		$types       = $externaldb->get_results( $externaldb->prepare( 'SELECT DISTINCT object_type FROM ' . UALP_TABLENAME . ' WHERE 1 = 1 AND object_type <> %s ORDER BY object_type', '""' ) );
		$host        = isset( $_SERVER['HTTP_HOST'] ) ? esc_url_raw( wp_unslash( $_SERVER['HTTP_HOST'] ) ) : '';
		$request_url = isset( $_SERVER['REQUEST_URI'] ) ? esc_url_raw( wp_unslash( $_SERVER['REQUEST_URI'] ) ) : '';
		$req_page    = isset( $_REQUEST['page'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['page'] ) ) : '';
		?>
		<div id="wpbody-content" class="ual_pro_admin">
			<div class="wrap nosubsub">
				<h1 class="wp-heading-inline"><?php esc_html_e( 'User Activity Log', 'user_activity_log_pro' ); ?></h1>
				<div id="col-container" class="wp-clearfix">
					<div id="col-right" style="width:100%">
						<div class="col-wrap">
							<div class="wrap">
								<?php $current_url = ( isset( $_SERVER['HTTPS'] ) ? 'https://' : 'http://' ) . $host . $request_url; ?>
								<form id="activity-filter" method="get" >
									<input type="hidden" name="page" value="<?php echo esc_attr( $req_page ); ?>" />
									<div id="ual_pro_table_loader">
										<?php $this->show_data_table(); ?>
									</div>
								</form>
							</div>

						</div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}
	/**
	 * Show Data Tables.
	 */
	public function show_data_table() {
		$this->get_list_table()->prepare_items();
		$this->get_list_table()->display();
	}
	/**
	 * Show buffer Data table.
	 */
	public function show_data_table_buffer() {
		ob_start();
		$dump = ob_end_clean();

		ob_start();
		if ( ! empty( $_REQUEST['no_placeholder'] ) ) {
			$this->get_list_table()->display_rows();
		} else {
			$this->get_list_table()->display_rows_or_placeholder();
		}
		$rows = ob_get_clean();

		ob_start();
		$this->get_list_table()->print_column_headers();
		$headers = ob_get_clean();

		ob_start();
		$this->get_list_table()->pagination( 'top' );
		$pagination_top = ob_get_clean();

		ob_start();
		$this->get_list_table()->pagination( 'bottom' );
		$pagination_bottom = ob_get_clean();

		$response = array( 'rows' => $rows );
		return $response;
	}
	/**
	 * AJAX to get data tables.
	 */
	public function ualp_get_show_data_table_ajax() {
		if ( isset( $_POST['nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'ajax-nonce' ) ) {
			if ( isset( $_POST ) ) {
				$act = isset( $_POST['act'] ) ? sanitize_text_field( wp_unslash( $_POST['act'] ) ) : '';
			}
		}
		die();
	}

	/**
	 * Get List Table.
	 *
	 * @return UALP_Activity_Log_List_Table
	 */
	public function get_list_table() {
		if ( is_null( $this->list_table ) && isset( $this->screens['main'] ) ) {
			$this->list_table = new UALP_Activity_Log_List_Table( array( 'screen' => $this->screens['main'] ) );
		}
		return $this->list_table;
	}
	/**
	 * Logged Sub menu page screen options.
	 */
	public function usersetting_logged_submenupage_screen_options() {
		if ( is_null( $this->list_table ) && isset( $this->screens['main'] ) ) {
			$this->list_table = new UALP_User_Logged_Activity_Log_List_Table( array( 'screen' => $this->screens['main'] ) );
		}
		return $this->list_table;
	}
	/**
	 * Email Sub menu page screen options.
	 */
	public function usersetting_email_submenupage_screen_options() {
		if ( is_null( $this->list_table ) && isset( $this->screens['main'] ) ) {
			$this->list_table = new Ualp_Email_Notification_List_Table( array( 'screen' => $this->screens['main'] ) );
		}
		return $this->list_table;
	}
	/**
	 * SMS sub menu page screen options.
	 */
	public function usersetting_sms_submenupage_screen_options() {
		if ( is_null( $this->list_table ) && isset( $this->screens['main'] ) ) {
			$this->list_table = new Ualp_Sms_Notification_List_Table( array( 'screen' => $this->screens['main'] ) );
		}
		return $this->list_table;
	}
}

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @author     Solwin Infotech <info@solwininfotech.com>
 */
class UALP_Activity_Log_List_Table extends WP_List_Table {

	/**
	 * Get Action Lablel.
	 *
	 * @param string $action Action.
	 */
	protected function ualp_get_action_label( $action ) {
		return ucwords( str_replace( '_', ' ', esc_html__( $action, 'user_activity_log_pro' ) ) );
	}
	/**
	 * Class Cunstructor.
	 *
	 * @param array $args Arguments.
	 */
	public function __construct( $args = array() ) {
		parent::__construct(
			array(
				'singular' => 'activity',
				'ajax'     => true,
				'screen'   => isset( $args['screen'] ) ? $args['screen'] : null,
			)
		);
		add_screen_option(
			'per_page',
			array(
				'default' => 20,
				'label'   => esc_html__( 'Number of logs per page', 'user_activity_log_pro' ) . ' : ',
				'option'  => 'ualp_logs_per_page',
			)
		);
		set_screen_options();
		add_filter( 'set-screen-option', array( $this, 'ualp_set_screen_option' ), 10, 3 );
	}
	/**
	 * Get Columns.
	 */
	public function get_columns() {
		$columns = array(
			'check'         => '<input type="checkbox" id="cb-select-all-ual">',
			'modified_date' => esc_html__( 'Date', 'user_activity_log_pro' ),
			'user_id'       => esc_html__( 'Author', 'user_activity_log_pro' ),
		);
		if ( ualp_allow_ip() ) {
			$columns['ip_address'] = esc_html__( 'IP Address', 'user_activity_log_pro' );
		}
		if ( ualp_allow_country() ) {
			$columns['country'] = esc_html__( 'Country', 'user_activity_log_pro' );
		}
		if ( ualp_allow_user_agent() ) {
			$columns['user_agent'] = esc_html__( 'User Agent', 'user_activity_log_pro' );
		}
		$columns['hook']        = esc_html__( 'Activity', 'user_activity_log_pro' );
		$columns['object_type'] = esc_html__( 'Type', 'user_activity_log_pro' );
		$columns['title']       = esc_html__( 'Description', 'user_activity_log_pro' );
		$columns['action']      = esc_html__( 'Action', 'user_activity_log_pro' );
		return $columns;
	}

	/**
	 * Get Sortable Columns.
	 */
	public function get_sortable_columns() {
		return array(
			'ip_address'    => array( 'ip_address', false ),
			'country'       => array( 'country', false ),
			'user_agent'    => array( 'user_agent', false ),
			'modified_date' => array( 'modified_date', true ),
			'object_type'   => array( 'object_type', false ),
			'user_id'       => array( 'user_id', false ),
			'hook'          => array( 'hook', false ),
		);
	}

	/**
	 * Column Defaults.
	 *
	 * @param string $item Item.
	 * @param string $column_name Column Name.
	 */
	public function column_default( $item, $column_name ) {
		global $wpdb, $externaldb;
		$return = '';
		$i      = 1;
		$paged  = 1;
		switch ( $column_name ) {
			case 'check':
				$return = "<input type='checkbox' name='chkual[]' id='cb-select-$item->uactid' value='$item->uactid'>";
				break;
			case 'modified_date':
				$modified_date = strtotime( $item->modified_date );
				$date_format   = get_option( 'date_format' );
				$time_format   = get_option( 'time_format' );
				$date          = gmdate( $date_format, $modified_date );
				$time          = gmdate( $time_format, $modified_date );
				if ( is_network_admin() && ualp_multi_site_support_return() ) {
					$adminurl = network_admin_url( 'admin.php?page=ual_pro&datefilter=' );
				} else {
					$adminurl = admin_url( 'admin.php?page=ual_pro&datefilter=' );
				}
				$return = '<a title="' . $date . '" href="' . $adminurl . $modified_date . '">' . $date . '</a> <br/>' .
							$time . '<br/>' .
						'<b>' . human_time_diff( $modified_date, current_time( 'timestamp' ) ) . ' ' . esc_html__( 'ago', 'user_activity_log_pro' ) . '</b>';
				break;
			case 'user_id':
				global $wp_roles;
				if ( ! empty( $item->user_id ) && 0 !== (int) $item->user_id ) {
					$user = get_user_by( 'id', $item->user_id );
					if ( $user instanceof WP_User && 0 !== $user->ID ) {
						$user_role = isset( $user->roles ) ? $user->roles : esc_html__( 'Unknown', 'user_activity_log_pro' );
						$return    = '';
						$return   .= get_avatar( $user->ID, 40 );
						if ( is_network_admin() && ualp_multi_site_support_return() ) {
							$adminurl = network_admin_url( 'admin.php?page=ual_pro' );
						} else {
							$adminurl = admin_url( 'admin.php?page=ual_pro' );
						}
						$return .= '<a title="' . ucfirst( $user->display_name ) . '" href="' . $adminurl . '&usershow=' . $user->display_name . '"><span>' . $user->display_name . '</span></a></br>';
						foreach ( $user_role as $alluserrole ) {
							if ( is_network_admin() && ualp_multi_site_support_return() ) {
								$userroleadminurl = network_admin_url( 'admin.php?page=ual_pro&capshow=' );
							} else {
								$userroleadminurl = admin_url( 'admin.php?page=ual_pro&capshow=' );
							}
							$return .= sprintf(
								'<a title="' . $alluserrole . '" href="' . $userroleadminurl . $alluserrole . '">' .
								'<small>' . $alluserrole . '</small>' .
								'</a></br>'
							);
						}
					}
					$return .= $item->user_email;
				} else {
					if ( is_network_admin() && ualp_multi_site_support_return() ) {
						$adminurl = network_admin_url( 'admin.php?page=ual_pro' );
					} else {
						$adminurl = admin_url( 'admin.php?page=ual_pro' );
					}
					$return = '<a href="' . $adminurl . '&usershow=Guest">' . __( 'Guest', 'user_activity_log_pro' ) . '</a>';
				}
				break;
			case 'object_type':
				if ( is_network_admin() && ualp_multi_site_support_return() ) {
					$adminurl = network_admin_url( 'admin.php?page=ual_pro&typeshow=' );
				} else {
					$adminurl = admin_url( 'admin.php?page=ual_pro&typeshow=' );
				}
				$return = "<a href='" . $adminurl . $item->object_type . "' title='$item->object_type'>" . $item->object_type . '</a>';
				break;
			case 'ip_address':
				if ( is_network_admin() && ualp_multi_site_support_return() ) {
					$adminurl = network_admin_url( 'admin.php?page=ual_pro&showip=' );
				} else {
					$adminurl = admin_url( 'admin.php?page=ual_pro&showip=' );
				}
				$return = "<a href='" . $adminurl . $item->ip_address . "' title='$item->ip_address'>" . $item->ip_address . '</a>';
				break;
			case 'country':
				if ( isset( $item->country ) ) {
					if ( is_network_admin() && ualp_multi_site_support_return() ) {
						$adminurl = network_admin_url( 'admin.php?page=ual_pro&showcountry=' );
					} else {
						$adminurl = admin_url( 'admin.php?page=ual_pro&showcountry=' );
					}
					$return = "<a href='" . $adminurl . $item->country . "' title='$item->country'>" . $item->country . '</a>';
				}
				break;
			case 'user_agent':
				if ( isset( $item->user_agent ) ) {
					if ( is_network_admin() && ualp_multi_site_support_return() ) {
						$adminurl = network_admin_url( 'admin.php?page=ual_pro&showuser_agent=' );
					} else {
						$adminurl = admin_url( 'admin.php?page=ual_pro&showuser_agent=' );
					}
					$return = "<a href='" . $adminurl . $item->user_agent . "' title='$item->user_agent'>" . $item->user_agent . '</a>';
				}
				break;
			case 'hook':
				if ( is_network_admin() && ualp_multi_site_support_return() ) {
					$adminurl = network_admin_url( 'admin.php?page=ual_pro&showhook=' );
				} else {
					$adminurl = admin_url( 'admin.php?page=ual_pro&showhook=' );
				}
				$return = "<a href='" . $adminurl . $item->hook . "' title='$item->hook'>" . $item->hook . '</a>';
				break;
			case 'title':
				if ( isset( $item->description ) && '' != $item->description ) {
					$filter = '';
					if ( 'transition_post_status' == $item->hook ) {
						if ( is_network_admin() && ualp_multi_site_support_return() ) {
							$adminurl = network_admin_url( 'admin.php?page=ual_pro' );
						} else {
							$adminurl = admin_url( 'admin.php?page=ual_pro' );
						}
						$filter = '<a title="' . $item->post_title . '" href="' . $adminurl . '&filterposts=' . $item->post_id . '">'
									. '<div class="dashicons dashicons-filter post_filter"></div>' .
								'</a>';
					}
					$return .= ucfirst( $item->description ) . $filter;
				} else {
					$return .= $item->action . ' : ' . $item->post_title;
				}
				break;
			case 'action':
				$return = '';
				if ( '1' == $item->favorite ) {
					$fav_title = esc_html__( 'Favorite', 'user_activity_log_pro' );
					$selected  = 'selected';
				} else {
					$fav_title = esc_html__( 'Unfavorite', 'user_activity_log_pro' );
					$selected  = '';
				}
				$view_title                = esc_html__( 'View', 'user_activity_log_pro' );
				$delete_title              = esc_html__( 'Delete', 'user_activity_log_pro' );
				$ualp_delete_log_pwd       = get_option( 'ualp_delete_log_pwd' );
				$ualp_log_password_protect = get_option( 'ualpLogPasswordProtect', true );
				if ( 1 == $ualp_log_password_protect && ( ! $ualp_delete_log_pwd || '' == $ualp_delete_log_pwd ) ) {
					$class = 'setDeletePassword';
				} elseif ( 0 == $ualp_log_password_protect ) {
					$class = 'logPasswordProtect';
				} else {
					$class = 'deleteSingleLog';
				}
				ualp_create_table();
				ualp_create_detail_table();
				ualp_create_external_table();
				ualp_create_detail_external_table();
				ualp_create_login_external_table();
				ualp_create_email_notification_table();
				ualp_create_sms_notification_table();
				ualp_create_email_notification_external_table();
				ualp_create_schedule_report();
				ualp_create_schedule_external_report();
				$view_count = $externaldb->get_var( 'SELECT COUNT(uactd_id) FROM ' . UALP_DETAIL_TABLENAME . ' WHERE uactid = ' . $item->uactid );
				if ( $view_count > 0 ) {
					$return .= '<a data-view="' . $item->uactid . '" title="' . $view_title . '" href="javascript:void(0)" class="ualp_view"><span class="dashicons dashicons-visibility"></span></a>';
				} else {
					$return .= '<span style="float:left;margin-right: 5px;margin-top: 4px;" class="dashicons dashicon-show dashicons-visibility ualp-not-allowed"></span>';
				}
				$return .= '<a title="' . $fav_title . '" class="ualpFavorite ' . $selected . '" id="' . $item->uactid . '"></a>';

				if ( '1' == $item->favorite ) {
					$return .= '<span class="padding_left_right_5 padding_top_bottom_3 ualp-not-allowed dashicons dashicons-trash"></span>';
				} else {
					if ( is_network_admin() && ualp_multi_site_support_return() ) {
						$adminurl = network_admin_url( "admin.php?page=ual_pro&paged=$paged&action=delete&id=$item->uactid" );
					} else {
						$adminurl = admin_url( "admin.php?page=ual_pro&paged=$paged&action=delete&id=$item->uactid" );
					}
					$return .= '<a title="' . $delete_title . '" class="column-delete deleteLog ' . $class . '" data-id="' . $item->uactid . '" href="' . wp_nonce_url( $adminurl, "delete-action$item->uactid", 'delete-nonce' ) . '" ><span class="dashicons dashicons-trash"></span></a>';
				}
				break;
			default:
				if ( isset( $item->$column_name ) ) {
					$return = $item->$column_name;
				}
		}
		$return = apply_filters( 'ualp_table_list_column_default', $return, $item, $column_name );
		return $return;
	}

	/**
	 * Author Columns.
	 *
	 * @param string $item Item.
	 */
	public function column_author( $item ) {
		global $wp_roles;
		if ( ! empty( $item->user_id ) && 0 !== (int) $item->user_id ) {
			$user = get_user_by( 'id', $item->user_id );
			if ( $user instanceof WP_User && 0 !== $user->ID ) {
				$user_link         = get_edit_user_link( $user->ID );
				$user_avatar       = get_avatar( $user->ID, 40 );
				$user_display_name = $user->display_name;
				$user_role         = ( isset( $user->roles[0] ) && isset( $wp_roles->role_names[ $user->roles[0] ] ) ) ? $wp_roles->role_names[ $user->roles[0] ] : 'Unknown';
				return '<a href="' . $user_link . '">'
							. $user_avatar . ' <span>' . $user_display_name . '</span>'
						. '</a><br />'
						. '<small>' . $user_role . '</small>';
			}
		}
		return '<span>' . __( 'Guest', 'user_activity_log_pro' ) . '</span>';
	}

	/**
	 * Column Type.
	 *
	 * @param string $item Item.
	 */
	public function column_type( $item ) {
		$return = $item->object_type;
		$return = apply_filters( 'ualp_table_list_column_type', $return, $item );
		return $return;
	}

	/**
	 * Column Label.
	 *
	 * @param string $item Item.
	 */
	public function column_label( $item ) {
		$return = '';
		if ( ! empty( $item->object_subtype ) ) {
			$pt     = get_post_type_object( $item->object_subtype );
			$return = ! empty( $pt->label ) ? $pt->label : $item->object_subtype;
		}
		$return = apply_filters( 'ualp_table_list_column_label', $return, $item );
		return $return;
	}

	/**
	 * Display Table Navigation.
	 *
	 * @param string $which Condition.
	 */
	public function display_tablenav( $which ) {
		?>
		<div class="tablenav <?php echo esc_attr( $which ); ?>">
			<?php
			global $wpdb, $externaldb;
			ualp_create_table();
			ualp_create_detail_table();
			ualp_create_external_table();
			ualp_create_detail_external_table();
			ualp_create_login_external_table();
			ualp_create_email_notification_table();
			ualp_create_sms_notification_table();
			ualp_create_email_notification_external_table();
			ualp_create_schedule_report();
			ualp_create_schedule_external_report();
			$item_list = $externaldb->get_var( 'SELECT count(uactid) FROM ' . UALP_TABLENAME );
			if ( $item_list ) {
				if ( 'top' == $which ) {
					wp_nonce_field( 'bulk-' . $this->_args['plural'] );
					?>
					<div class="wp-filter">
						<div class="filter-items">
								<?php
									$this->extra_tablenav( $which );
								?>
								<div class="top-cover">
									<div class="alignleft bulkactions">
										<?php
										$ualp_delete_log_pwd       = get_option( 'ualp_delete_log_pwd' );
										$ualp_log_password_protect = get_option( 'ualpLogPasswordProtect', true );
										if ( 1 != $ualp_log_password_protect && ( ! $ualp_delete_log_pwd || '' == $ualp_delete_log_pwd ) ) {
											$class = 'setBulkDeletePassword';
										} else {
											$class = 'deleteBulkLog';
										}
										$id_text = '';
										if ( 0 == $ualp_log_password_protect ) {
											$id_text = 'wopdeleteBulkLog';
										}
										?>
										<label class="screen-reader-text" for="bulk-action-selector-top">
												<?php esc_html_e( 'Select bulk action', 'user_activity_log_pro' ); ?>
										</label>
										<select class="<?php echo esc_attr( $class ); ?> wopdeleteBulkLog" id="bulk-action-selector-top" name="bulk_action_selector" data-id="<?php echo esc_attr( $id_text ); ?>">
											<option value="0"><?php esc_html_e( 'Bulk Actions', 'user_activity_log_pro' ); ?></option>
											<option value="delete"><?php esc_html_e( 'Delete Permanently', 'user_activity_log_pro' ); ?></option>
											<option value="favorite"><?php esc_html_e( 'Favorite', 'user_activity_log_pro' ); ?></option>
											<option value="unfavorite"><?php esc_html_e( 'Unfavorite', 'user_activity_log_pro' ); ?></option>
										</select>
										<input type="submit" value="<?php esc_html_e( 'Apply', 'user_activity_log_pro' ); ?>" name="bulk_action" class="button action" id="doaction">
										<?php
										$items_array = $this->items;
										if ( is_array( $items_array ) && count( $items_array ) > 0 ) {
											if ( ! isset( $_REQUEST['capshow'] ) ) {
												$_REQUEST['capshow'] = '';
											}
											if ( ! isset( $_REQUEST['usershow'] ) ) {
												$_REQUEST['usershow'] = '';
											}
											if ( ! isset( $_REQUEST['typeshow'] ) ) {
												$_REQUEST['typeshow'] = '';
											}
											if ( ! isset( $_REQUEST['showip'] ) ) {
												$_REQUEST['showip'] = '';
											}
											if ( ! isset( $_REQUEST['showcountry'] ) ) {
												$_REQUEST['showcountry'] = '';
											}
											if ( ! isset( $_REQUEST['showuser_agent'] ) ) {
												$_REQUEST['showuser_agent'] = '';
											}
											if ( ! isset( $_REQUEST['dateshow'] ) ) {
												$_REQUEST['dateshow'] = '';
											}
											if ( ! isset( $_REQUEST['showhook'] ) ) {
												$_REQUEST['showhook'] = '';
											}
											if ( ! isset( $_REQUEST['showfavorite'] ) ) {
												$_REQUEST['showfavorite'] = '';
											}
											if ( ! isset( $_REQUEST['s'] ) ) {
												$_REQUEST['s'] = '';
											}
											if ( ! isset( $_REQUEST['start_date'] ) ) {
												$_REQUEST['start_date'] = '';
											}
											if ( ! isset( $_REQUEST['end_date'] ) ) {
												$_REQUEST['end_date'] = '';
											}
											if ( ! isset( $_REQUEST['t_session'] ) ) {
												$_REQUEST['t_session'] = '';
											}
											if ( ! isset( $_REQUEST['showsiteid'] ) ) {
												$_REQUEST['showsiteid'] = '';
											}
											if ( ! isset( $_REQUEST['showallpost'] ) ) {
												$_REQUEST['showallpost'] = '';
											}
											if ( ! isset( $_REQUEST['showposttype'] ) ) {
												$_REQUEST['showposttype'] = '';
											}
											if ( is_network_admin() && ualp_multi_site_support_return() ) {
												$adminurl      = network_admin_url( 'admin.php?page=ual_pro&export=user_logs&logformat=csv&userrole=' . sanitize_text_field( wp_unslash( $_REQUEST['capshow'] ) ) . '&username=' . sanitize_text_field( wp_unslash( $_REQUEST['usershow'] ) ) . '&type=' . sanitize_text_field( wp_unslash( $_REQUEST['typeshow'] ) ) . '&ip=' . sanitize_text_field( wp_unslash( $_REQUEST['showip'] ) ) . '&country=' . sanitize_text_field( wp_unslash( $_REQUEST['showcountry'] ) ) . '&user_agent=' . sanitize_text_field( wp_unslash( $_REQUEST['showuser_agent'] ) ) . '&time=' . sanitize_text_field( wp_unslash( $_REQUEST['dateshow'] ) ) . '&start_date=' . sanitize_text_field( wp_unslash( $_REQUEST['start_date'] ) ) . '&end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['end_date'] ) ) . '&hook=' . sanitize_text_field( wp_unslash( $_REQUEST['showhook'] ) ) . '&favorite=' . sanitize_text_field( wp_unslash( $_REQUEST['showfavorite'] ) ) . '&txtsearch=' . sanitize_text_field( wp_unslash( $_REQUEST['s'] ) ) . '&t_session=' . sanitize_text_field( wp_unslash( $_REQUEST['t_session'] ) ) . '&showsiteid=' . sanitize_text_field( wp_unslash( $_REQUEST['showsiteid'] ) ) . '&showallpost=' . sanitize_text_field( wp_unslash( $_REQUEST['showallpost'] ) ) . '&showposttype=' . sanitize_text_field( wp_unslash( $_REQUEST['showposttype'] ) ) );
												$json_adminurl = network_admin_url( 'admin.php?page=ual_pro&export=user_logs&logformat=json&userrole=' . sanitize_text_field( wp_unslash( $_REQUEST['capshow'] ) ) . '&username=' . sanitize_text_field( wp_unslash( $_REQUEST['usershow'] ) ) . '&type=' . sanitize_text_field( wp_unslash( $_REQUEST['typeshow'] ) ) . '&ip=' . sanitize_text_field( wp_unslash( $_REQUEST['showip'] ) ) . '&country=' . sanitize_text_field( wp_unslash( $_REQUEST['showcountry'] ) ) . '&user_agent=' . sanitize_text_field( wp_unslash( $_REQUEST['showuser_agent'] ) ) . '&time=' . sanitize_text_field( wp_unslash( $_REQUEST['dateshow'] ) ) . '&start_date=' . sanitize_text_field( wp_unslash( $_REQUEST['start_date'] ) ) . '&end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['end_date'] . '&hook=' . sanitize_text_field( wp_unslash( $_REQUEST['showhook'] ) ) . '&favorite=' . sanitize_text_field( wp_unslash( $_REQUEST['showfavorite'] ) ) . '&txtsearch=' . sanitize_text_field( wp_unslash( $_REQUEST['s'] ) ) . '&t_session=' . $_REQUEST['t_session'] ) ) . '&showsiteid=' . sanitize_text_field( wp_unslash( $_REQUEST['showsiteid'] ) ) . '&showallpost=' . sanitize_text_field( wp_unslash( $_REQUEST['showallpost'] ) ) . '&showposttype=' . sanitize_text_field( wp_unslash( $_REQUEST['showposttype'] ) ) );
											} else {
												$adminurl      = admin_url( 'admin.php?page=ual_pro&export=user_logs&logformat=csv&userrole=' . sanitize_text_field( wp_unslash( $_REQUEST['capshow'] ) ) . '&username=' . sanitize_text_field( wp_unslash( $_REQUEST['usershow'] ) ) . '&type=' . sanitize_text_field( wp_unslash( $_REQUEST['typeshow'] ) ) . '&ip=' . sanitize_text_field( wp_unslash( $_REQUEST['showip'] ) ) . '&country=' . sanitize_text_field( wp_unslash( $_REQUEST['showcountry'] ) ) . '&user_agent=' . sanitize_text_field( wp_unslash( $_REQUEST['showuser_agent'] ) ) . '&time=' . sanitize_text_field( wp_unslash( $_REQUEST['dateshow'] ) ) . '&start_date=' . sanitize_text_field( wp_unslash( $_REQUEST['start_date'] ) ) . '&end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['end_date'] ) ) . '&hook=' . sanitize_text_field( wp_unslash( $_REQUEST['showhook'] ) ) . '&favorite=' . sanitize_text_field( wp_unslash( $_REQUEST['showfavorite'] ) ) . '&txtsearch=' . sanitize_text_field( wp_unslash( $_REQUEST['s'] ) ) . '&t_session=' . sanitize_text_field( wp_unslash( $_REQUEST['t_session'] ) ) . '&showsiteid=' . sanitize_text_field( wp_unslash( $_REQUEST['showsiteid'] ) ) . '&showallpost=' . sanitize_text_field( wp_unslash( $_REQUEST['showallpost'] ) ) . '&showposttype=' . sanitize_text_field( wp_unslash( $_REQUEST['showposttype'] ) ) );
												$json_adminurl = admin_url( 'admin.php?page=ual_pro&export=user_logs&logformat=json&userrole=' . sanitize_text_field( wp_unslash( $_REQUEST['capshow'] ) ) . '&username=' . sanitize_text_field( wp_unslash( $_REQUEST['usershow'] ) ) . '&type=' . sanitize_text_field( wp_unslash( $_REQUEST['typeshow'] ) ) . '&ip=' . sanitize_text_field( wp_unslash( $_REQUEST['showip'] ) ) . '&country=' . sanitize_text_field( wp_unslash( $_REQUEST['showcountry'] ) ) . '&user_agent=' . sanitize_text_field( wp_unslash( $_REQUEST['showuser_agent'] ) ) . '&time=' . sanitize_text_field( wp_unslash( $_REQUEST['dateshow'] ) ) . '&start_date=' . sanitize_text_field( wp_unslash( $_REQUEST['start_date'] ) ) . '&end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['end_date'] ) ) . '&hook=' . sanitize_text_field( wp_unslash( $_REQUEST['showhook'] ) ) . '&favorite=' . sanitize_text_field( wp_unslash( $_REQUEST['showfavorite'] ) ) . '&txtsearch=' . sanitize_text_field( wp_unslash( $_REQUEST['s'] ) ) . '&t_session=' . sanitize_text_field( wp_unslash( $_REQUEST['t_session'] ) ) . '&showsiteid=' . sanitize_text_field( wp_unslash( $_REQUEST['showsiteid'] ) ) . '&showallpost=' . sanitize_text_field( wp_unslash( $_REQUEST['showallpost'] ) ) . '&showposttype=' . sanitize_text_field( wp_unslash( $_REQUEST['showposttype'] ) ) );
											}

											?>
											<a href="<?php echo wp_nonce_url( $adminurl, 'export-action', 'export-nonce' ); ?>" class="button-primary action">
												<?php esc_html_e( 'Export Logs (CSV)', 'user_activity_log_pro' ); ?>
											</a>
											<a href="<?php echo wp_nonce_url( $json_adminurl, 'export-action', 'export-nonce' ); ?>" class="button-primary action">
												<?php esc_html_e( 'Export Logs (JSON)', 'user_activity_log_pro' ); ?>
											</a>
											<?php
										}
										do_action( 'ual_pro_after_filter' );
										?>
									</div>
								</div>
								<?php
									$this->search_box( __( 'Search', 'user_activity_log_pro' ), 'ualp-search' );
								?>
						</div>
					</div>
					<?php
				}
				$this->pagination( $which );
			}
			?>
			<br class="clear" />
		</div>
		<div id="show"></div>
		<?php
	}

	/**
	 * Extra Table Navigation.
	 *
	 * @param string $which Condition.
	 */
	public function extra_tablenav( $which ) {

		global $wpdb, $externaldb,$allhookdetails;
		$args_kses = ualp_args_kses();
		if ( 'top' !== $which ) {
			return;
		}
		echo '<div class="alignleft actions1">';
		$users = $externaldb->get_results(
			$externaldb->prepare(
				'SELECT DISTINCT user_name FROM ' . UALP_TABLENAME . '
				WHERE 1 = 1 AND user_name <> %s
				ORDER BY user_name
			',
				'""'
			)
		);
		$types = $externaldb->get_results(
			$externaldb->prepare(
				'SELECT DISTINCT object_type FROM ' . UALP_TABLENAME . '
				WHERE 1 = 1 AND object_type <> %s
				ORDER BY object_type
			',
				'""'
			)
		);
		// Make sure we get items for filter.
		if ( $users || $types ) {
			if ( ! isset( $_REQUEST['dateshow'] ) ) {
				$_REQUEST['dateshow'] = '';
			}
			$date_options = array(
				''           => esc_html__( 'All Time', 'user_activity_log_pro' ),
				'today'      => esc_html__( 'Today', 'user_activity_log_pro' ),
				'yesterday'  => esc_html__( 'Yesterday', 'user_activity_log_pro' ),
				'week'       => esc_html__( 'Week', 'user_activity_log_pro' ),
				'this-month' => esc_html__( 'This Month', 'user_activity_log_pro' ),
				'month'      => esc_html__( 'Last 1 Month', 'user_activity_log_pro' ),
				'2-month'    => esc_html__( 'Last 2 Month', 'user_activity_log_pro' ),
				'3-month'    => esc_html__( 'Last 3 Month', 'user_activity_log_pro' ),
				'6-month'    => esc_html__( 'Last 6 Month', 'user_activity_log_pro' ),
				'this-year'  => esc_html__( 'This Year', 'user_activity_log_pro' ),
				'last-year'  => esc_html__( 'Last Year', 'user_activity_log_pro' ),
				'custom'     => esc_html__( 'Custom Date Range', 'user_activity_log_pro' ),
			);
			echo '<div class="filter-cover"><select name="dateshow" class="chosen-filter" id="ualp-filter-date">';
			foreach ( $date_options as $key => $value ) {
				printf( '<option value="%1$s"%2$s>%3$s</option>', $key, selected( sanitize_text_field( wp_unslash( $_REQUEST['dateshow'] ) ), $key, false ), $value );
			}
			echo '</select>';
		}
		$user_id = $externaldb->get_results(
			'SELECT DISTINCT user_id FROM ' . UALP_TABLENAME . '
                    WHERE 1 = 1
                    ORDER BY user_id
            '
		);

		if ( $user_id ) {
			if ( ! isset( $_REQUEST['capshow'] ) ) {
				$_REQUEST['capshow'] = '';
			}
			$output = array();
			foreach ( $user_id as $alluserroleid ) {
				foreach ( $alluserroleid as $alluserrole ) {
					if ( '' != $alluserrole && 0 != $alluserrole ) {
						$userroles = get_user_by( 'id', $alluserrole );
						if ( isset( $userroles->roles ) ) {
							$user_roles = $userroles->roles;
						} else {
							$user_roles = '';
						}
					} else {
							$user_roles = '';
					}
					if ( '' == $user_roles ) {
						$user_roles = array();
					}
					foreach ( $user_roles as $user_id_role ) {
						$output[] = sprintf( '<option value="%s"%s>%s</option>', $user_id_role, selected( sanitize_text_field( wp_unslash( $_REQUEST['capshow'] ) ), $user_id_role, false ), $user_id_role );
					}
				}
			}

			echo '<select class="chosen-filter" name="capshow" id="ualp-filter-capshow">';
			printf( '<option value="">' . esc_html__( 'All Roles', 'user_activity_log_pro' ) . '</option>' );
			echo wp_kses( implode( '', array_unique( $output ) ), $args_kses );
			echo '</select>';
		}
		if ( $users ) {
			if ( ! isset( $_REQUEST['usershow'] ) ) {
				$_REQUEST['usershow'] = '';
			}
			$output = array();
			foreach ( $users as $_user ) {
				if ( isset( $_user->user_name ) && '' != $_user->user_name ) {
					$output[] = sprintf( '<option value="%s"%s>%s</option>', $_user->user_name, selected( sanitize_text_field( wp_unslash( $_REQUEST['usershow'] ) ), $_user->user_name, false ), $this->ualp_get_action_label( $_user->user_name ) );
				}
			}
			echo '<select class="chosen-filter" name="usershow" id="ualp-filter-usershow">';
			printf( '<option value="">' . esc_html__( 'All Users', 'user_activity_log_pro' ) . '</option>' );
			echo wp_kses( implode( '', $output ), $args_kses );
			echo '</select>';
		}

		$ips = $externaldb->get_results(
			'SELECT DISTINCT ip_address FROM ' . UALP_TABLENAME . '
                    WHERE 1 = 1
                    ORDER BY ip_address
            '
		);
		if ( $ips && ualp_allow_ip() ) {
			if ( ! isset( $_REQUEST['showip'] ) ) {
				$_REQUEST['showip'] = '';
			}
			$output = array();
			foreach ( $ips as $ip ) {
				if ( isset( $ip->ip_address ) && '' != $ip->ip_address ) {
					$output[] = sprintf( '<option value="%s"%s>%s</option>', $ip->ip_address, selected( sanitize_text_field( wp_unslash( $_REQUEST['showip'] ) ), $ip->ip_address, false ), $this->ualp_get_action_label( $ip->ip_address ) );
				}
			}

			echo '<select class="chosen-filter" name="showip" id="ualp-filter-showip">';
			printf( '<option value="">' . esc_html__( 'All IP', 'user_activity_log_pro' ) . '</option>' );
			echo wp_kses( implode( '', $output ), $args_kses );
			echo '</select>';
		}
		$countrys = $externaldb->get_results(
			'SELECT DISTINCT country FROM ' . UALP_TABLENAME . '
                    WHERE 1 = 1
                    ORDER BY country'
		);
		if ( $countrys && ualp_allow_country() ) {
			if ( ! isset( $_REQUEST['showcountry'] ) ) {
				$_REQUEST['showcountry'] = '';
			}
			$output = array();
			foreach ( $countrys as $country ) {
				if ( isset( $country->country ) && '' != $country->country ) {
					$output[] = sprintf( '<option value="%s"%s>%s</option>', $country->country, selected( sanitize_text_field( wp_unslash( $_REQUEST['showcountry'] ) ), $country->country, false ), $this->ualp_get_action_label( $country->country ) );
				}
			}
			echo '<select class="chosen-filter" name="showcountry" id="ualp-filter-showcountry">';
			printf( '<option value="">' . esc_html__( 'All Countries', 'user_activity_log_pro' ) . '</option>' );
			echo wp_kses( implode( '', $output ), $args_kses );
			echo '</select>';
		}
		$user_agents = $externaldb->get_results(
			'SELECT DISTINCT user_agent FROM ' . UALP_TABLENAME . '
                    WHERE 1 = 1
                    ORDER BY user_agent'
		);
		if ( $user_agents && ualp_allow_user_agent() ) {
			if ( ! isset( $_REQUEST['showuser_agent'] ) ) {
				$_REQUEST['showuser_agent'] = '';
			}
			$output = array();
			foreach ( $user_agents as $user_agent ) {
				if ( isset( $user_agent->user_agent ) && '' != $user_agent->user_agent ) {
					$output[] = sprintf( '<option value="%s"%s>%s</option>', $user_agent->user_agent, selected( sanitize_text_field( wp_unslash( $_REQUEST['showuser_agent'] ) ), $user_agent->user_agent, false ), $this->ualp_get_action_label( $user_agent->user_agent ) );
				}
			}
			echo '<select style="max-width:200px" class="chosen-filter" name="showuser_agent" id="ualp-filter-showuser_agent">';
			printf( '<option value="">' . esc_html__( 'All User Agents', 'user_activity_log_pro' ) . '</option>' );
			echo wp_kses( implode( '', $output ), $args_kses );
			echo '</select>';
		}
		if ( $types ) {
			if ( ! isset( $_REQUEST['typeshow'] ) ) {
				$_REQUEST['typeshow'] = '';
			}
			$output = array();
			foreach ( $types as $type ) {
				if ( isset( $type->object_type ) && '' != $type->object_type ) {
					$output[] = sprintf( '<option svalue="' . strtolower( str_replace( ' ', '_', $type->object_type ) ) . '" value="%1$s"%2$s>%3$s</option>', $type->object_type, selected( sanitize_text_field( wp_unslash( $_REQUEST['typeshow'] ) ), $type->object_type, false ), ucfirst( $type->object_type ) );
				}
			}
			echo '<select class="chosen-filter" name="typeshow" id="ualp-filter-typeshow">';
			printf( '<option value="">' . esc_html__( 'All Types', 'user_activity_log_pro' ) . '</option>' );
			echo wp_kses( implode( '', $output ), $args_kses );
			echo '</select>';
		}

		$hooks = $externaldb->get_results(
			'SELECT DISTINCT hook FROM ' . UALP_TABLENAME . '
                    WHERE 1 = 1
                    ORDER BY hook
            '
		);
		if ( $hooks ) {
			if ( ! isset( $_REQUEST['showhook'] ) ) {
				$_REQUEST['showhook'] = '';
			}
			$output = array();

			foreach ( $hooks as $hook ) {
				if ( isset( $hook->hook ) && '' != $hook->hook ) {
					$label = $hook->hook;
					foreach ( $allhookdetails as $key => $val ) {
						if ( $hook->hook == $key ) {
							$label = $val;
						}
					}
					$output[] = sprintf( '<option value="%s"%s>%s</option>', $hook->hook, selected( sanitize_text_field( wp_unslash( $_REQUEST['showhook'] ) ), $hook->hook, false ), $label );
				}
			}
			echo '<select class="chosen-filter" name="showhook" id="ualp-filter-showhook">';
			printf( '<option value="">' . esc_html__( 'All Activity', 'user_activity_log_pro' ) . '</option>' );
			echo wp_kses( implode( '', $output ), $args_kses );
			echo '</select>';
		}

		$favorites = $externaldb->get_results(
			'SELECT DISTINCT favorite FROM ' . UALP_TABLENAME . '
                    WHERE 1 = 1
                    ORDER BY favorite
            '
		);
		if ( $favorites ) {
			if ( ! isset( $_REQUEST['showfavorite'] ) ) {
				$_REQUEST['showfavorite'] = '';
			}
		}

		$start_date = ( isset( $_REQUEST['start_date'] ) && '' != $_REQUEST['start_date'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['start_date'] ) ) : '';
		$end_date   = ( isset( $_REQUEST['end_date'] ) && '' != $_REQUEST['end_date'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['end_date'] ) ) : '';

		$output  = array();
		$output  = sprintf( '<option value="1"%s>%s</option>', selected( sanitize_text_field( wp_unslash( $_REQUEST['showfavorite'] ) ), '1', false ), esc_html__( 'Favorite', 'user_activity_log_pro' ) );
		$output .= sprintf( '<option value="0"%s>%s</option>', selected( sanitize_text_field( wp_unslash( $_REQUEST['showfavorite'] ) ), '0', false ), esc_html__( 'Unfavorite', 'user_activity_log_pro' ) );
		echo '<select class="chosen-filter" name="showfavorite" id="ualp-filter-showfavorite">';
		printf( '<option value="">' . esc_html__( 'All Favorite/Unfavorite', 'user_activity_log_pro' ) . '</option>' );
		echo wp_kses( $output, $args_kses );
		echo '</select>';

		$site_id = $externaldb->get_results(
			'SELECT DISTINCT site_id FROM ' . UALP_TABLENAME . '
                    WHERE 1 = 1
                    ORDER BY site_id'
		);

		if ( ualp_multi_site_support_return() ) {

			$super_admin = is_super_admin( get_current_user_id() );
			if ( is_network_admin() && ualp_multi_site_support_return() ) {
				if ( $site_id ) {
					if ( ! isset( $_REQUEST['showsiteid'] ) ) {
						$_REQUEST['showsiteid'] = '';
					}
					$output = array();
					foreach ( $site_id as $allsiteid ) {
						if ( isset( $allsiteid->site_id ) && 0 != $allsiteid->site_id ) {
							$getsitename = get_blog_details( $allsiteid->site_id );
							$output[]    = sprintf( '<option value="%s"%s>%s</option>', $allsiteid->site_id, selected( sanitize_text_field( wp_unslash( $_REQUEST['showsiteid'] ) ), $allsiteid->site_id, false ), $this->ualp_get_action_label( $getsitename->blogname ) );
						}
					}
					echo '<select class="chosen-filter" name="showsiteid" id="ualp-filter-showsiteid">';
					printf( '<option value="">' . esc_html__( 'All Site', 'user_activity_log_pro' ) . '</option>' );
					echo wp_kses( implode( '', $output ), $args_kses );
					echo '</select>';
				}
			}
		}

		// Parse all query vars into an array.
		$query_vars = array();

		if ( isset( $_SERVER['QUERY_STRING'] ) ) {
			parse_str( urldecode( sanitize_text_field( wp_unslash( $_SERVER['QUERY_STRING'] ) ) ), $query_vars );
		}

		// Ignore certain query vars and query vars that are empty.
		foreach ( $query_vars as $query_var => $value ) {
			if ( '' === $value || 'page' === $query_var || 'paged' === $query_var ) {
				unset( $query_vars[ $query_var ] );
			}
		}
		$transition_where = '1 = 1';
		if ( ! is_network_admin() && ualp_multi_site_support_return() ) {
			$transition_where .= " AND site_id = '" . get_current_blog_id() . "'";
		}
		$transition_post_status = $externaldb->get_results(
			'SELECT * FROM ' . UALP_TABLENAME . '
                    WHERE ' . $transition_where . ' and hook="transition_post_status" and object_type IN ("page","post")
                    ORDER BY hook
            '
		);
		$transition_posttype    = array();
		$transition_posttitle   = array();
		foreach ( $transition_post_status as $all_posts ) {
			$post_id_type  = $all_posts->object_type;
			$post_id_title = $all_posts->post_title;
			if ( '' != $post_id_type ) {
				$transition_posttype[ $post_id_type ] = $post_id_type;
			}
			if ( isset( $_REQUEST['showposttype'] ) && '' != $_REQUEST['showposttype'] ) {
				if ( $post_id_type == $_REQUEST['showposttype'] ) {
					$transition_posttitle[ $all_posts->post_id ] = $post_id_title;
				}
			} else {
				$transition_posttitle[ $all_posts->post_id ] = $post_id_title;
			}
			$transition_posttype  = array_unique( $transition_posttype );
			$transition_posttitle = array_unique( $transition_posttitle );
		}
		echo '<div class="custom-hook pull-left">';
		echo '<div class="ualp-filter-posttype">';
		echo '<span class="custom-hook-title">' . esc_html__( 'Advance Filter', 'user_activity_log_pro' ) . '</span>';
		$tranposttype = array();
		foreach ( $transition_posttype as $key => $val ) {
			if ( ! isset( $_REQUEST['showposttype'] ) ) {
				$_REQUEST['showposttype'] = '';
			}
				$tranposttype[] = sprintf( '<option value="%s"%s>%s</option>', $key, selected( sanitize_text_field( wp_unslash( $_REQUEST['showposttype'] ) ), $key, false ), $val );
		}
		echo '<select class="chosen-filter" name="showposttype" id="ualp-filter-showposttype">';
		printf( '<option value="">' . esc_html__( 'All Post type', 'user_activity_log_pro' ) . '</option>' );
		echo wp_kses( implode( '', $tranposttype ), $args_kses );
		echo '</select>';
		echo '</div>';
		echo '<div class="ualp-filter-allpost">';
		$tranallpost = array();
		foreach ( $transition_posttitle as $key => $val ) {
			if ( ! isset( $_REQUEST['showallpost'] ) ) {
				$_REQUEST['showallpost'] = '';
			}
				$tranallpost[] = sprintf( '<option value="%s"%s>%s</option>', $key, selected( sanitize_text_field( wp_unslash( $_REQUEST['showallpost'] ) ), $key, false ), $val );
		}
		echo '<select class="chosen-filter" name="showallpost" id="ualp-filter-showallpost">';
		printf( '<option value="">' . esc_html__( 'All Posts', 'user_activity_log_pro' ) . '</option>' );
		echo wp_kses( implode( '', $tranallpost ), $args_kses );
		echo '</select>';
		echo '</div>';
		echo '</div>';

		?>
		<div class="filter-btn-cover">
			<?php
			wp_nonce_field( 'ual_filter_nonce', 'filter_nonce' );
			submit_button( __( 'Filter', 'user_activity_log_pro' ), 'primary', false, false, array( 'uactid' => 'activity-query-submit' ) );
			if ( ! empty( $query_vars ) ) {
				if ( is_network_admin() && ualp_multi_site_support_return() ) {
					$adminurl = network_admin_url( 'admin.php?page=ual_pro' );
				} else {
					$adminurl = admin_url( 'admin.php?page=ual_pro' );
				}
				?>
				<a class="button ualp-button-green" href="<?php echo esc_url( $adminurl ); ?>">
					<?php esc_html_e( 'Reset Filter', 'user_activity_log_pro' ); ?>
				</a>
				<?php
			}
			?>
		</div>
		<?php

			echo '<div class="custom-date pull-left">'
					. '<p>'
						. esc_html__( 'Start date', 'user_activity_log_pro' ) . ' : '
						. '<input type="text" name="start_date" value="' . esc_attr( $start_date ) . '" class="datepicker start-date"> '
						. esc_html__( 'End date', 'user_activity_log_pro' ) . ' : '
						. '<input type="text" name="end_date" value="' . esc_attr( $end_date ) . '" class="datepicker end-date">'
					. '</p>'
					. '<p class="custom_date_msg"></p>'
				. '</div>'
		. '</div>';

	}

	/**
	 * Prepare Items.
	 */
	public function prepare_items() {
		global $wpdb, $externaldb;
		$request_url            = isset( $_SERVER['REQUEST_URI'] ) ? esc_url_raw( wp_unslash( $_SERVER['REQUEST_URI'] ) ) : '';
		$_SERVER['REQUEST_URI'] = remove_query_arg( '_wp_http_referer', $request_url );
		$items_per_page         = $this->get_items_per_page( 'ualp_logs_per_page' );
		$this->_column_headers  = array( $this->get_columns(), get_hidden_columns( $this->screen ), $this->get_sortable_columns() );
		$where                  = ' WHERE 1=1';
		if ( ! empty( $_REQUEST['bulk_action_selector'] ) && 'favorite' == $_REQUEST['bulk_action_selector'] ) {
			if ( isset( $_REQUEST['chkual'] ) && ! empty( $_REQUEST['chkual'] ) ) {
				$logs = array_map( 'sanitize_text_field', wp_unslash( $_REQUEST['chkual'] ) );
				foreach ( $logs as $log ) {
					$result = $externaldb->update(
						UALP_TABLENAME,
						array( 'favorite' => '1' ),
						array( 'uactid' => $log ),
						array( '%s' ),
						array( '%d' )
					);
				}

				/*
				Comment
				// if ( is_network_admin() && ualp_multi_site_support_return() ) {
				// wp_redirect( network_admin_url( 'admin.php?page=ual_pro' ) );
				// } else {
				// wp_redirect( admin_url( 'admin.php?page=ual_pro' ) );
				// }
				*/
			}
		}
		if ( ! empty( $_REQUEST['bulk_action_selector'] ) && 'unfavorite' == $_REQUEST['bulk_action_selector'] ) {
			if ( isset( $_REQUEST['chkual'] ) && ! empty( $_REQUEST['chkual'] ) ) {
				$logs = array_map( 'sanitize_text_field', wp_unslash( $_REQUEST['chkual'] ) );
				foreach ( $logs as $log ) {
					$result = $externaldb->update(
						UALP_TABLENAME,
						array( 'favorite' => '0' ),
						array( 'uactid' => $log ),
						array( '%s' ),
						array( '%d' )
					);
				}

				/*
				Comment
				if ( is_network_admin() && ualp_multi_site_support_return() ) {
				// wp_redirect( network_admin_url( 'admin.php?page=ual_pro' ) );
				// } else {
				// wp_redirect( admin_url( 'admin.php?page=ual_pro' ) );
				// }
				*/
			}
		}
		if ( ! isset( $_REQUEST['order'] ) || ! in_array( $_REQUEST['order'], array( 'desc', 'asc' ) ) ) {
			$_REQUEST['order'] = 'desc';
		}
		if ( ! isset( $_REQUEST['orderby'] ) || ! in_array( $_REQUEST['orderby'], array( 'modified_date', 'user_id', 'user_email', 'object_type', 'hook', 'ip_address', 'country' ) ) ) {
			$_REQUEST['orderby'] = 'modified_date';
		}
		if ( ! empty( $_REQUEST['typeshow'] ) ) {
			$where .= $externaldb->prepare( ' AND object_type = %s', sanitize_text_field( wp_unslash( $_REQUEST['typeshow'] ) ) );
		}
		if ( isset( $_REQUEST['showip'] ) && '' !== $_REQUEST['showip'] ) {
			$where .= $externaldb->prepare( ' AND `ip_address` = \'%s\'', sanitize_text_field( wp_unslash( $_REQUEST['showip'] ) ) );
		}
		if ( isset( $_REQUEST['showcountry'] ) && '' !== $_REQUEST['showcountry'] ) {
			$where .= $externaldb->prepare( ' AND `country` = \'%s\'', sanitize_text_field( wp_unslash( $_REQUEST['showcountry'] ) ) );
		}
		if ( isset( $_REQUEST['showuser_agent'] ) && '' !== $_REQUEST['showuser_agent'] ) {
			$where .= $externaldb->prepare( ' AND `user_agent` = \'%s\'', sanitize_text_field( wp_unslash( $_REQUEST['showuser_agent'] ) ) );
		}
		if ( isset( $_REQUEST['showhook'] ) && '' !== $_REQUEST['showhook'] ) {
			$where .= $externaldb->prepare( ' AND `hook` = \'%s\'', sanitize_text_field( wp_unslash( $_REQUEST['showhook'] ) ) );
		}
		if ( isset( $_REQUEST['usershow'] ) && '' !== $_REQUEST['usershow'] ) {
			$where .= $externaldb->prepare( ' AND `user_name` = %s', sanitize_text_field( wp_unslash( $_REQUEST['usershow'] ) ) );
		}
		if ( isset( $_REQUEST['showfavorite'] ) && '' !== $_REQUEST['showfavorite'] ) {
			$where .= $externaldb->prepare( ' AND `favorite` = %s', sanitize_text_field( wp_unslash( $_REQUEST['showfavorite'] ) ) );
		}
		if ( isset( $_REQUEST['capshow'] ) && '' != $_REQUEST['capshow'] ) {
			$where .= ' AND user_role LIKE "%%' . sanitize_text_field( wp_unslash( $_REQUEST['capshow'] ) ) . '%%"';
		}
		if ( isset( $_REQUEST['dateshow'] ) && in_array( $_REQUEST['dateshow'], array( 'today', 'yesterday', 'week', 'this-month', 'month', '2-month', '3-month', '6-month', 'this-year', 'last-year', 'custom' ) ) ) {
			$get_time     = sanitize_text_field( wp_unslash( $_REQUEST['dateshow'] ) );
			$current_time = current_time( 'timestamp' );
			$start_time   = mktime( 0, 0, 0, gmdate( 'm', $current_time ), gmdate( 'd', $current_time ), gmdate( 'Y', $current_time ) );
			$end_time     = mktime( 23, 59, 59, gmdate( 'm', $current_time ), gmdate( 'd', $current_time ), gmdate( 'Y', $current_time ) );
			if ( 'today' == $get_time ) {
				$start_time = $current_time;
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time );

			} elseif ( 'yesterday' === $get_time ) {
				$start_time = strtotime( 'yesterday', $start_time );
				$end_time   = $current_time;

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time );

			} elseif ( 'week' === $get_time ) {
				$start_time = strtotime( '-1 week', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time );

			} elseif ( 'this-month' === $get_time ) {
				$start_time = gmdate( 'Y-m-01' );
				$start_time = strtotime( $start_time );

				$end_time = gmdate( 'Y-m-31' );
				$end_time = strtotime( $end_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time );

			} elseif ( 'month' === $get_time ) {
				$start_time = strtotime( '-1 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time );

			} elseif ( '2-month' === $get_time ) {
				$start_time = strtotime( '-2 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time );

			} elseif ( '3-month' === $get_time ) {
				$start_time = strtotime( '-3 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time );

			} elseif ( '6-month' === $get_time ) {
				$start_time = strtotime( '-6 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time );

			} elseif ( 'this-year' === $get_time ) {
				$start_time = gmdate( 'Y-01-01' );
				$start_time = strtotime( $start_time );

				$end_time = gmdate( 'Y-12-31' );
				$end_time = strtotime( $end_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time );
			} elseif ( 'last-year' === $get_time ) {

				$start_time = gmdate( 'Y-01-01' );
				$start_time = strtotime( $start_time );
				$start_time = strtotime( '-1 year', $start_time );

				$end_time = gmdate( 'Y-12-31' );
				$end_time = strtotime( $end_time );
				$end_time = strtotime( '-1 year', $end_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time );
			} elseif ( 'custom' === $get_time ) {
				$custom_start_date = isset( $_REQUEST['start_date'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['start_date'] ) ) : '';
				$custom_end_date   = isset( $_REQUEST['end_date'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['end_date'] ) ) : '';
				if ( isset( $custom_start_date ) && '' != $custom_start_date ) {
					$start_time = strtotime( $custom_start_date . ' 23:59:59' );
					if ( gmdate( 'Y-m-d H:i:s', $start_time ) > gmdate( 'Y-m-d H:i:s' ) ) {
						$start_time = strtotime( $custom_start_date . ' 23:59:59' );
					} else {
						$start_time = strtotime( '-1 day', $start_time );
					}
					$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
					$where     .= $externaldb->prepare( ' AND modified_date >= "%s"', $start_time );
				}
				if ( isset( $custom_end_date ) && '' != $custom_end_date ) {
					$end_time = strtotime( $custom_end_date . ' 23:59:59' );
					$end_time = strtotime( '+1 day', $end_time );
					$end_time = gmdate( 'Y-m-d H:i:s', $end_time );
					$where   .= $externaldb->prepare( ' AND modified_date < "%s"', $end_time );
				}
			}
		}

		if ( isset( $_REQUEST['datefilter'] ) && '' != $_REQUEST['datefilter'] ) {
			$date_filter = sanitize_text_field( wp_unslash( $_REQUEST['datefilter'] ) );
			$date_filter = gmdate( 'Y-m-d', $date_filter );
			$where      .= ' AND modified_date LIKE "%%' . $date_filter . '%%"';
		}
		if ( isset( $_REQUEST['filterposts'] ) && '' != $_REQUEST['filterposts'] ) {
			$where .= ' AND post_id = ' . sanitize_text_field( wp_unslash( $_REQUEST['filterposts'] ) );
		}
		if ( isset( $_REQUEST['t_session'] ) && '' != $_REQUEST['t_session'] ) {
			$where .= " AND t_session = '" . sanitize_text_field( wp_unslash( $_REQUEST['t_session'] ) ) . "'";
		}
		if ( isset( $_REQUEST['showhook'] ) && 'transition_post_status' == $_REQUEST['showhook'] ) {
			if ( isset( $_REQUEST['showposttype'] ) && '' != $_REQUEST['showposttype'] ) {
				$where .= " AND object_type = '" . sanitize_text_field( wp_unslash( $_REQUEST['showposttype'] ) ) . "'";
			}
			if ( isset( $_REQUEST['showallpost'] ) && '' != $_REQUEST['showallpost'] ) {
				$where .= " AND post_id = '" . sanitize_text_field( wp_unslash( $_REQUEST['showallpost'] ) ) . "'";
			}
		}

		if ( ualp_multi_site_support_return() ) {
			if ( is_network_admin() ) {
				if ( isset( $_REQUEST['showsiteid'] ) && '' != $_REQUEST['showsiteid'] ) {
					$where .= " AND site_id = '" . sanitize_text_field( wp_unslash( $_REQUEST['showsiteid'] ) ) . "'";
				}
			} else {
				$where .= " AND site_id = '" . get_current_blog_id() . "'";
			}
		}
		if ( isset( $_REQUEST['s'] ) && '' != $_REQUEST['s'] ) {
			$search_s = sanitize_text_field( wp_unslash( $_REQUEST['s'] ) );
			$where   .= ' AND (user_name LIKE \'%%' . $externaldb->esc_like( $search_s ) . '%%\' OR user_role LIKE \'%%' . $externaldb->esc_like( $search_s ) . '%%\' OR object_type LIKE \'%%' . $externaldb->esc_like( $search_s ) . '%%\')';
		}
		$offset = ( $this->get_pagenum() - 1 ) * $items_per_page;
		ualp_create_table();
		ualp_create_detail_table();
		ualp_create_external_table();
		ualp_create_detail_external_table();
		ualp_create_login_external_table();
		ualp_create_email_notification_table();
		ualp_create_sms_notification_table();
		ualp_create_email_notification_external_table();
		ualp_create_schedule_report();
		ualp_create_schedule_external_report();
		$total_items = $externaldb->get_var( 'SELECT COUNT(`uactid`) FROM ' . UALP_TABLENAME . $where );
		$this->items = $externaldb->get_results( $externaldb->prepare( 'SELECT * FROM ' . UALP_TABLENAME . $where . ' ORDER BY ' . sanitize_text_field( wp_unslash( $_REQUEST['orderby'] ) ) . ' ' . sanitize_text_field( wp_unslash( $_REQUEST['order'] ) ) . ' LIMIT %d, %d', $offset, $items_per_page ) );
		$this->set_pagination_args(
			array(
				'total_items' => $total_items,
				'per_page'    => $items_per_page,
				'total_pages' => ceil( $total_items / $items_per_page ),
			)
		);
	}

	/**
	 * Set Screen Options.
	 *
	 * @param string $status Status.
	 * @param string $option Option.
	 * @param string $value Value.
	 */
	public function ualp_set_screen_option( $status, $option, $value ) {
		if ( 'ualp_logs_per_page' == $option ) {
			return $value;
		}
	}

	/**
	 * No Items Message.
	 */
	public function no_items() {
		esc_html_e( 'No Activity found.', 'user_activity_log_pro' );
	}

	/**
	 * Search Box.
	 *
	 * @param string $text Text.
	 * @param string $input_id Input ID.
	 */
	public function search_box( $text, $input_id ) {
		$search_data = isset( $_REQUEST['s'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['s'] ) ) : '';
		$input_id    = $input_id . '-search-input';
		?>
		<p class="search-box">
			<label class="screen-reader-text" for="<?php echo esc_attr( $input_id ); ?>"><?php echo esc_html( $text ); ?>:</label>
			<input type="search" id="<?php echo esc_attr( $input_id ); ?>" name="s" placeholder="<?php esc_html_e( 'User, Role, Type', 'user_activity_log_pro' ); ?>" value="<?php echo esc_attr( $search_data ); ?>" />
			<?php submit_button( $text, 'button', false, false, array( 'uactid' => 'search-submit' ) ); ?>
		</p>
		<?php
	}

	/**
	 * Delete the Logs by time.
	 */
	public function button_delete_logs_by_time() {

		if ( isset( $_GET ) ) {
			global $wpdb;
			/**
			* Delete all Logs.
			*/
			$table_1 = $wpdb->prefix . 'ualp_user_activity';
			$table_2 = $wpdb->prefix . 'ualp_user_activity_detail';
			if ( isset( $_GET['delete_all_logs'] ) ) {
				$wpdb->query( "DELETE FROM {$wpdb->prefix}ualp_user_activity" );
				ualp_admin_notice_message( 'notice-success', 'All logs removed.' );
			}

			/**
			* Delete log by time.
			*/
			if ( isset( $_GET['del_log_by_time'] ) && isset( $_GET['del_log_by_time_btn'] ) ) {
				$log_time_to_delete = sanitize_text_field( wp_unslash( $_GET['del_log_by_time'] ) );
				if ( 0 != $log_time_to_delete ) {
					$wpdb->query( $wpdb->prepare( "DELETE {$wpdb->prefix}ualp_user_activity,{$wpdb->prefix}ualp_user_activity_detail FROM $wpdb->prefix}ualp_user_activity LEFT JOIN {$wpdb->prefix}ualp_user_activity_detail ON $wpdb->prefix}ualp_user_activity.uactid = {$wpdb->prefix}ualp_user_activity_detail.uactid WHERE `modified_date` >= NOW() - INTERVAL %s", $log_time_to_delete ) );
					ualp_admin_notice_message( 'notice-success', 'Logs removed.' );
				} else {
					ualp_admin_notice_message( 'error', 'Select a time to delete logs' );
				}
			}
		}

		?>
		<input type="submit" value="<?php esc_html_e( 'Delete All Logs', 'user_activity_log_pro' ); ?>" name="delete_all_logs" class="button-primary action del_log_btn" id="doaction">
		<div class="del_log_by_time">
			<select name="del_log_by_time">
				<option value="0"><?php echo esc_html__( 'Delete Logs by Time', 'user_activity_log_pro' ); ?></option>
				<option value="1 MINUTE"><?php echo esc_html__( 'Delete 1 Minute logs', 'user_activity_log_pro' ); ?></option>
				<option value="3 MINUTE"><?php echo esc_html__( 'Delete 3 Minute logs', 'user_activity_log_pro' ); ?></option>
				<option value="5 MINUTE"><?php echo esc_html__( 'Delete 5 Minute logs', 'user_activity_log_pro' ); ?></option>
				<option value="1 DAY"><?php echo esc_html__( 'Delete 1 day logs', 'user_activity_log_pro' ); ?></option>
				<option value="2 DAY"><?php echo esc_html__( 'Delete 2 day logs', 'user_activity_log_pro' ); ?></option>
				<option value="3 DAY"><?php echo esc_html__( 'Delete 3 day logs', 'user_activity_log_pro' ); ?></option>
				<option value="5 DAY"><?php echo esc_html__( 'Delete 5 day logs', 'user_activity_log_pro' ); ?></option>
				<option value="1 WEEK"><?php echo esc_html__( 'Delete 1 week logs', 'user_activity_log_pro' ); ?></option>
				<option value="2 WEEK"><?php echo esc_html__( 'Delete 2 weeks logs', 'user_activity_log_pro' ); ?></option>
				<option value="1 MONTH"><?php echo esc_html__( 'Delete 1 Month logs', 'user_activity_log_pro' ); ?></option>
				<option value="3 MONTH"><?php echo esc_html__( 'Delete 3 Month logs', 'user_activity_log_pro' ); ?></option>
			</select>
			<input type="submit" name="del_log_by_time_btn" value="Delete Now" class="button-primary action del_log_btn">
		</div>
		<?php
	}

}

/**
 * Do Refresh.
 */
function ualp_do_refresh() {
	$screen = get_current_screen();
	if ( 'toplevel_page_ual_pro' != $screen->id ) {
		return;
	}
	?>
	<script type="text/javascript">
		jQuery(document).ready(function(){
			(function($){
				setInterval(function() {
				$.ajax({
					type:'POST',dataType: 'json',url:ajaxurl,data:{'action':'ualp_get_show_data_table_ajax','act':'ualp_get_log_list_latest_table', 'nonce': ualpJSObject.ajax_nonce,},success:function(response){
						if(response){
							var response = JSON.parse(JSON.stringify(response));
							$('#ual_pro_table_loader .wp-list-table #the-list').html(response.rows);
						}
					}
				});
			   }, 10000);
			}(jQuery))
		});
	</script>
	<?php
}


$ualp_admin_ui = new UALP_Admin_Ui();



/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @author     Solwin Infotech <info@solwininfotech.com>
 */
class UALP_User_Logged_Activity_Log_List_Table extends WP_List_Table {

	/**
	 * Get Action Lablel.
	 *
	 * @param string $action Action.
	 */
	protected function ualp_get_action_label( $action ) {
		return ucwords( str_replace( '_', ' ', esc_html__( $action, 'user_activity_log_pro' ) ) );
	}

	/**
	 * Class Cunstructor.
	 */
	public function __construct() {
		global $status, $page;
		parent::__construct(
			array(
				'singular' => 'logingactivity',
				'screen'   => isset( $args['screen'] ) ? $args['screen'] : null,
			)
		);
		add_screen_option(
			'per_page',
			array(
				'default' => 20,
				'label'   => esc_html__( 'Number of logged per page', 'user_activity_log_pro' ) . ' : ',
				'option'  => 'ualp_user_logged_per_page',
			)
		);
		add_filter( 'set-screen-option', array( &$this, 'ualp_logged_set_screen_option' ), 10, 3 );
		set_screen_options();
	}

	/**
	 * Set Screen Options.
	 *
	 * @param string $status Status.
	 * @param string $option Option.
	 * @param string $value Value.
	 */
	public function ualp_logged_set_screen_option( $status, $option, $value ) {
		if ( 'ualp_user_logged_per_page' === $option ) {
			return $value;
		}
	}

	/**
	 * Default Columns.
	 *
	 * @param string $item Item.
	 * @param string $column_name Column Name.
	 */
	public function column_default( $item, $column_name ) {
		return $item[ $column_name ];
	}

	/**
	 * Add Checkbox on Column.
	 *
	 * @param string $item Item.
	 */
	public function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="id[]" value="%s" />',
			$item->uacltid
		);
	}

	/**
	 * User ID Column.
	 *
	 * @param string $item Item.
	 */
	public function column_user_id( $item ) {
		global $wp_roles;
		if ( ! empty( $item->user_id ) && 0 !== (int) $item->user_id ) {
			$user = get_user_by( 'id', $item->user_id );
			if ( $user instanceof WP_User && 0 !== $user->ID ) {
				$user_link         = get_edit_user_link( $user->ID );
				$user_avatar       = get_avatar( $user->ID, 40 );
				$user_display_name = $user->display_name;
				$useremail         = $user->user_email;
				$user_role         = ( isset( $user->roles ) ) ? $user->roles : 'Unknown';
				$alluserrole       = '';
				if ( is_network_admin() && ualp_multi_site_support_return() ) {
					$adminusername = network_admin_url( 'admin.php?page=ualp_user_details&usershow=' );
					$adminuserrole = network_admin_url( 'admin.php?page=ualp_user_details&user_role=' );
				} else {
					$adminusername = admin_url( 'admin.php?page=ualp_user_details&usershow=' );
					$adminuserrole = admin_url( 'admin.php?page=ualp_user_details&user_role=' );
				}
				$alluserrole .= $user_avatar . ' <a title="' . ucfirst( $user_display_name ) . '" href="' . $adminusername . $user->display_name . '">' . $user_display_name . '</a></br>';
				foreach ( $user_role as $all_rols ) {
					$alluserrole .= '<a title="' . ucfirst( $user_display_name ) . '"  href="' . $adminuserrole . $all_rols . '">' . $all_rols . '</a></br>';
				}
				$alluserrole .= '<span>' . $useremail . '</span>';
				return $alluserrole;
			}
		} else {
			return '<span>' . __( 'Guest', 'user_activity_log_pro' ) . '</span>';
		}
	}

	/**
	 * IP Address Column.
	 *
	 * @param string $item Item.
	 */
	public function column_ip_address( $item ) {
		$ip_address = $item->ip_address;
		if ( is_network_admin() && ualp_multi_site_support_return() ) {
			$return = '<a title="' . $ip_address . '" href="' . network_admin_url( 'admin.php?page=ualp_user&showip=' ) . $ip_address . '">' . $ip_address . '</a>';
		} else {
			$return = '<a title="' . $ip_address . '" href="' . admin_url( 'admin.php?page=ualp_user_details&showip=' ) . $ip_address . '">' . $ip_address . '</a>';
		}
		return $return;
	}

	/**
	 * Country Column.
	 *
	 * @param string $item Item.
	 */
	public function column_country( $item ) {
		return $item->country;
	}

	/**
	 * User Agent Column.
	 *
	 * @param string $item Item.
	 */
	public function column_user_agent( $item ) {
		if ( is_network_admin() && ualp_multi_site_support_return() ) {
			$return = "<a href='" . network_admin_url( 'admin.php?page=ualp_user_details&showuser_agent=' ) . esc_attr( $item->user_agent ) . "' title='" . esc_attr( $item->user_agent ) . "'>" . esc_html( $item->user_agent ) . '</a>';
		} else {
			$return = "<a href='" . admin_url( 'admin.php?page=ualp_user_details&showuser_agent=' ) . esc_attr( $item->user_agent ) . "' title='" . esc_attr( $item->user_agent ) . "'>" . esc_html( $item->user_agent ) . '</a>';
		}

		return $return;
	}

	/**
	 * Logiin Time Column.
	 *
	 * @param string $item Item.
	 */
	public function column_time_login( $item ) {
		$time_login_data = strtotime( $item->time_login );
		$date_format     = get_option( 'date_format' );
		$time_format     = get_option( 'time_format' );
		$date            = gmdate( $date_format, $time_login_data );
		$time            = gmdate( $time_format, $time_login_data );
		if ( is_network_admin() && ualp_multi_site_support_return() ) {
			$adminurl = network_admin_url( 'admin.php?page=ualp_user_details&datefilterlogin=' );
		} else {
			$adminurl = admin_url( 'admin.php?page=ualp_user_details&datefilterlogin=' );
		}
		$return = '<a title="' . $date . '" href="' . $adminurl . $time_login_data . '">' . $date . '</a> <br/>' .
					$time . '<br/>' .
				'<b>' . human_time_diff( $time_login_data, current_time( 'timestamp' ) ) . ' ' . esc_html__( 'ago', 'user_activity_log_pro' ) . '</b>';
				return $return;
	}

	/**
	 * Logout Time Column.
	 *
	 * @param string $item Item.
	 */
	public function column_time_logout( $item ) {
		$time_logout_data = isset( $item->time_logout ) ? strtotime( $item->time_logout ) : false;
		$date_format      = get_option( 'date_format' );
		$time_format      = get_option( 'time_format' );
		$date             = gmdate( $date_format, $time_logout_data );
		$time             = gmdate( $time_format, $time_logout_data );
		if ( '' != $time_logout_data ) {
			if ( is_network_admin() && ualp_multi_site_support_return() ) {
				$adminurl = network_admin_url( 'admin.php?page=ualp_user_details&datefilterlogout=' );
			} else {
				$adminurl = admin_url( 'admin.php?page=ualp_user_details&datefilterlogout=' );
			}
			$return = '<a title="' . $date . '" href="' . $adminurl . $time_logout_data . '">' . $date . '</a> <br/>' .
			$time . '<br/>' .
			'<b>' . human_time_diff( $time_logout_data, current_time( 'timestamp' ) ) . ' ' . esc_html__( 'ago', 'user_activity_log_pro' ) . '</b>';
		} else {
			$return = '';
		}

		return $return;
	}

	/**
	 * Last Seen Time Column.
	 *
	 * @param string $item Item.
	 */
	public function column_time_last_seen( $item ) {

		$time_last_seen = strtotime( $item->time_last_seen );
		$date_format    = get_option( 'date_format' );
		$time_format    = get_option( 'time_format' );
		$date           = gmdate( $date_format, $time_last_seen );
		$time           = gmdate( $time_format, $time_last_seen );
		if ( is_network_admin() && ualp_multi_site_support_return() ) {
			$adminurl = network_admin_url( 'admin.php?page=ualp_user_details&datefilterlastseen=' );
		} else {
			$adminurl = admin_url( 'admin.php?page=ualp_user_details&datefilterlastseen=' );
		}
		$return = '<a title="' . $date . '" href="' . $adminurl . $time_last_seen . '">' . $date . '</a> <br/>' .
					$time . '<br/>' .
				'<b>' . human_time_diff( $time_last_seen, current_time( 'timestamp' ) ) . ' ' . esc_html__( 'ago', 'user_activity_log_pro' ) . '</b>';
				return $return;
	}

	/**
	 * Login Status Column.
	 *
	 * @param string $item Item.
	 */
	public function column_login_status( $item ) {
		$user_id           = $item->user_id;
		$login_status      = 'logout';
		$user_metas        = get_user_meta( $user_id, 'session_tokens', true );
		$total_logins      = 0;
		$session_token     = $item->session_token;
		$enc_session_token = ualp_get_current_token( $session_token );
		if ( is_array( $user_metas ) ) {
			$total_logins = count( $user_metas );
			if ( array_key_exists( $enc_session_token, $user_metas ) ) {
				$login_status = 'login';
			}
		}
		$all_login_status = ucfirst( $login_status );
		if ( is_network_admin() && ualp_multi_site_support_return() ) {
			$adminurl = network_admin_url( 'admin.php?page=ualp_user_details&loginstatus=' );
		} else {
			$adminurl = admin_url( 'admin.php?page=ualp_user_details&loginstatus=' );
		}
		$return = '<a title="' . $all_login_status . '" href="' . $adminurl . $login_status . '">' . $all_login_status . '</a>';
		return $return;
	}

	/**
	 * Action Column.
	 *
	 * @param string $item Item.
	 */
	public function column_action( $item ) {
		$action            = '';
		$user_id           = $item->user_id;
		$login_status      = 'logout';
		$user_metas        = get_user_meta( $user_id, 'session_tokens', true );
		$total_logins      = 0;
		$paged             = 1;
		$session_token     = $item->session_token;
		$enc_session_token = ualp_get_current_token( $session_token );
		if ( is_array( $user_metas ) ) {
			$total_logins = count( $user_metas );
			if ( array_key_exists( $enc_session_token, $user_metas ) ) {
				$login_status = 'login';
			}
		}
		global $externaldb;
		if ( 'login' == $login_status && get_current_user_id() != $user_id ) {

			$action .= '<a title="' . esc_html__( 'Log out user', 'user_activity_log_pro' ) . '"  class ="column-delete ualp-session-expire" data-t_session="' . $session_token . '" data-user-id="' . $user_id . '">' . esc_html__( 'Log out User from this session only', 'user_activity_log_pro' ) . '</a><br/>';

			$action .= '<a title="' . esc_html__( 'Log out user', 'user_activity_log_pro' ) . '"  class ="column-delete ualp-session-expire-all" data-t_session="' . $session_token . '" data-user-id="' . $user_id . '">' . esc_html__( 'Log out User from All Devices', 'user_activity_log_pro' ) . '</a><br/>';

		} elseif ( 'login' == $login_status && get_current_user_id() == $user_id && wp_get_session_token() == $session_token && $total_logins > 1 ) {
			$action .= '<a title="' . esc_html__( 'Log out From all other devices', 'user_activity_log_pro' ) . '"  class ="column-delete ualp-session-expire-except" data-t_session="' . $session_token . '" data-user-id="' . $user_id . '">' . esc_html__( 'Log out From all other devices', 'user_activity_log_pro' ) . '</a><br/>';

		}

		$total_history = $externaldb->get_var( 'select count(*) from ' . UALP_TABLENAME . " where t_session = '" . $session_token . "'" );

		if ( $total_history > 0 ) {
			if ( is_network_admin() && ualp_multi_site_support_return() ) {
				$adminurl = network_admin_url( "admin.php?page=ual_pro&t_session=$session_token" );
			} else {
				$adminurl = admin_url( "admin.php?page=ual_pro&t_session=$session_token" );
			}
			$action .= '<a target="_blank" href= "' . $adminurl . '" title="' . esc_html__( 'View Log History', 'user_activity_log_pro' ) . '"  class ="ualp-green" data-user-id="' . $user_id . '">' . esc_html__( 'View Log History', 'user_activity_log_pro' ) . '</a><br/>';

		}
		$delete_title = esc_html__( 'Delete', 'user_activity_log_pro' );
		if ( ! isset( $_REQUEST['usershow'] ) ) {
			$usershow = '';
		} else {
			$usershow = sanitize_text_field( wp_unslash( $_REQUEST['usershow'] ) );
		}
		if ( ! isset( $_REQUEST['showip'] ) ) {
			$showip = '';
		} else {
			$showip = sanitize_text_field( wp_unslash( $_REQUEST['showip'] ) );
		}
		if ( ! isset( $_REQUEST['showcountry'] ) ) {
			$showcountry = '';
		} else {
			$showcountry = sanitize_text_field( wp_unslash( $_REQUEST['showcountry'] ) );
		}
		if ( ! isset( $_REQUEST['showuser_agent'] ) ) {
			$showuser_agent = '';
		} else {
			$showuser_agent = sanitize_text_field( wp_unslash( $_REQUEST['showuser_agent'] ) );
		}
		if ( ! isset( $_REQUEST['s'] ) ) {
			$s = '';
		} else {
			$s = sanitize_text_field( wp_unslash( $_REQUEST['s'] ) );
		}
		if ( ! isset( $_REQUEST['loginstatus'] ) ) {
			$loginstatus = '';
		} else {
			$loginstatus = sanitize_text_field( wp_unslash( $_REQUEST['loginstatus'] ) );
		}
		if ( ! isset( $_REQUEST['timelogin'] ) ) {
			$timelogin = '';
		} else {
			$timelogin = sanitize_text_field( wp_unslash( $_REQUEST['timelogin'] ) );
		}
		if ( ! isset( $_REQUEST['timelogout'] ) ) {
			$timelogout = '';
		} else {
			$timelogout = sanitize_text_field( wp_unslash( $_REQUEST['timelogout'] ) );
		}
		if ( ! isset( $_REQUEST['user_role'] ) ) {
			$user_role = '';
		} else {
			$user_role = sanitize_text_field( wp_unslash( $_REQUEST['user_role'] ) );
		}
		if ( ! isset( $_REQUEST['showsiteid'] ) ) {
			$showsiteid = '';
		} else {
			$showsiteid = sanitize_text_field( wp_unslash( $_REQUEST['showsiteid'] ) );
		}
		if ( '' != $usershow || '' != $showip || '' != $showcountry || '' != $showuser_agent || '' != $loginstatus || '' != $timelogin || '' != $timelogout || '' != $user_role || '' != $showsiteid ) {
			$query_string = "&usershow=$usershow&showip=$showip&showcountry=$showcountry&showuser_agent=$showuser_agent&s=$s&loginstatus=$loginstatus&timelogin=$timelogin&timelogout=$timelogout&user_role=$user_role&showsiteid=$showsiteid";
		} else {
			$query_string = '';
		}
		if ( is_network_admin() && ualp_multi_site_support_return() ) {
			$adminurl = network_admin_url( "admin.php?page=ualp_user_details&paged=$paged&action=delete&id=$item->uacltid$query_string" );
		} else {
			$adminurl = admin_url( "admin.php?page=ualp_user_details&paged=$paged&action=delete&id=$item->uacltid$query_string" );
		}
		$action .= '<a title="' . $delete_title . '" class="column-delete deleteLog" data-id="' . $item->uacltid . '" href="' . wp_nonce_url( $adminurl, "delete-action$item->uacltid", 'delete-nonce' ) . '"><span class="dashicons dashicons-trash"></span></a>';
		return $action;
	}

	/**
	 * Get Columns.
	 */
	public function get_columns() {
		$columns = array(
			'cb'      => '<input type="checkbox">',
			'user_id' => esc_html__( 'Author', 'user_activity_log_pro' ),
		);
		if ( ualp_allow_ip() ) {
			$columns['ip_address'] = esc_html__( 'IP Address', 'user_activity_log_pro' );
		}
		if ( ualp_allow_country() ) {
			$columns['country'] = esc_html__( 'Country', 'user_activity_log_pro' );
		}
		if ( ualp_allow_user_agent() ) {
			$columns['user_agent'] = esc_html__( 'User Agent', 'user_activity_log_pro' );
		}
		$columns['time_login']     = esc_html__( 'Logged in Time', 'user_activity_log_pro' );
		$columns['time_logout']    = esc_html__( 'Logged out Time', 'user_activity_log_pro' );
		$columns['time_last_seen'] = esc_html__( 'Last seen', 'user_activity_log_pro' );
		$columns['login_status']   = esc_html__( 'Login Status', 'user_activity_log_pro' );
		$columns['action']         = esc_html__( 'Action', 'user_activity_log_pro' );

		return $columns;
	}

	/**
	 * Sortable Columns.
	 */
	public function get_sortable_columns() {
		return array(
			'ip_address'     => array( 'ip_address', false ),
			'country'        => array( 'country', false ),
			'user_agent'     => array( 'user_agent', false ),
			'user_id'        => array( 'user_id', false ),
			'time_login'     => array( 'time_login', false ),
			'time_logout'    => array( 'time_logout', false ),
			'time_last_seen' => array( 'time_last_seen', false ),
		);
	}

	/**
	 * Extra Table Navigation.
	 *
	 * @param string $which Condition.
	 */
	public function extra_tablenav( $which ) {
		global $wpdb, $externaldb;
		$args_kses = ualp_args_kses();
		if ( 'top' !== $which ) {

			return;
		}
		echo '<div class="alignleft actions1">';
		echo '<div class="filter-cover">';
			$users = $externaldb->get_results(
				$externaldb->prepare(
					'SELECT DISTINCT user_name FROM ' . UALP_LOGIN_TABLENAME . '
                WHERE 1 = 1 AND user_name <> %s ORDER BY user_name',
					'""'
				)
			);
		if ( $users ) {
			if ( ! isset( $_REQUEST['usershow'] ) ) {
				$_REQUEST['usershow'] = '';
			}
			$output = array();
			foreach ( $users as $all_user ) {
				if ( isset( $all_user->user_name ) && '' != $all_user->user_name ) {
					$output[] = sprintf( '<option value="%s"%s>%s</option>', $all_user->user_name, selected( sanitize_text_field( wp_unslash( $_REQUEST['usershow'] ) ), $all_user->user_name, false ), $this->ualp_get_action_label( $all_user->user_name ) );
				}
			}
			echo '<select class="chosen-filter" name="usershow" id="ualp-filter-usershow">';
			printf( '<option value="">' . esc_html__( 'All Users', 'user_activity_log_pro' ) . '</option>' );
			echo wp_kses( implode( '', $output ), $args_kses );
			echo '</select>';
		}
			$user_id = $externaldb->get_results(
				'SELECT DISTINCT user_id FROM ' . UALP_LOGIN_TABLENAME . '
                        WHERE 1 = 1
                        ORDER BY user_id
                '
			);
		if ( $user_id ) {
			if ( ! isset( $_REQUEST['user_role'] ) ) {
				$_REQUEST['user_role'] = '';
			}
			$output = array();
			foreach ( $user_id as $alluserroleid ) {
				foreach ( $alluserroleid as $alluserrole ) {
					if ( '' != $alluserrole && 0 != $alluserrole ) {
						$userroles = get_user_by( 'id', $alluserrole );
						if ( isset( $userroles->roles ) ) {
							$user_roles = $userroles->roles;
						} else {
							$user_roles = '';
						}
					} else {
							$user_roles = '';
					}
					if ( '' == $user_roles ) {
						$user_roles = array();
					}
					foreach ( $user_roles as $user_id_role ) {
						$output[] = sprintf( '<option value="%s"%s>%s</option>', $user_id_role, selected( sanitize_text_field( wp_unslash( $_REQUEST['user_role'] ) ), $user_id_role, false ), $user_id_role );
					}
				}
			}

			echo '<select class="chosen-filter" name="user_role" id="ualp-filter-user_role">';
			printf( '<option value="">' . esc_html__( 'All Roles', 'user_activity_log_pro' ) . '</option>' );
			echo wp_kses( implode( '', array_unique( $output ) ), $args_kses );
			echo '</select>';
		}
			$ips = $externaldb->get_results(
				'SELECT DISTINCT ip_address FROM ' . UALP_LOGIN_TABLENAME . '
                    WHERE 1 = 1
                    ORDER BY ip_address
            '
			);
		if ( $ips && ualp_allow_ip() ) {
			if ( ! isset( $_REQUEST['showip'] ) ) {
				$_REQUEST['showip'] = '';
			}
			$output = array();
			foreach ( $ips as $ip ) {
				if ( isset( $ip->ip_address ) && '' != $ip->ip_address ) {
					$output[] = sprintf( '<option value="%s"%s>%s</option>', $ip->ip_address, selected( sanitize_text_field( wp_unslash( $_REQUEST['showip'] ) ), $ip->ip_address, false ), $this->ualp_get_action_label( $ip->ip_address ) );
				}
			}
			echo '<select class="chosen-filter" name="showip" id="ualp-filter-showip">';
			printf( '<option value="">' . esc_html__( 'All IP', 'user_activity_log_pro' ) . '</option>' );
			echo wp_kses( implode( '', $output ), $args_kses );
			echo '</select>';
		}
			$countrys = $externaldb->get_results(
				'SELECT DISTINCT country FROM ' . UALP_LOGIN_TABLENAME . '
                        WHERE 1 = 1
                        ORDER BY country'
			);
		if ( $countrys && ualp_allow_country() ) {
			if ( ! isset( $_REQUEST['showcountry'] ) ) {
				$_REQUEST['showcountry'] = '';
			}
			$output = array();
			foreach ( $countrys as $country ) {
				if ( isset( $country->country ) && '' != $country->country ) {
					$output[] = sprintf( '<option value="%s"%s>%s</option>', $country->country, selected( sanitize_text_field( wp_unslash( $_REQUEST['showcountry'] ) ), $country->country, false ), $this->ualp_get_action_label( $country->country ) );
				}
			}
			echo '<select class="chosen-filter" name="showcountry" id="ualp-filter-showcountry">';
			printf( '<option value="">' . esc_html__( 'All Countries', 'user_activity_log_pro' ) . '</option>' );
			echo wp_kses( implode( '', $output ), $args_kses );
			echo '</select>';
		}
			$user_agents = $externaldb->get_results(
				'SELECT DISTINCT user_agent FROM ' . UALP_LOGIN_TABLENAME . '
                        WHERE 1 = 1
                        ORDER BY user_agent'
			);
		if ( $user_agents && ualp_allow_user_agent() ) {
			if ( ! isset( $_REQUEST['showuser_agent'] ) ) {
				$_REQUEST['showuser_agent'] = '';
			}
			$output = array();
			foreach ( $user_agents as $user_agent ) {
				if ( isset( $user_agent->user_agent ) && '' != $user_agent->user_agent ) {
					$output[] = sprintf( '<option value="%s"%s>%s</option>', $user_agent->user_agent, selected( sanitize_text_field( wp_unslash( $_REQUEST['showuser_agent'] ) ), $user_agent->user_agent, false ), $this->ualp_get_action_label( $user_agent->user_agent ) );
				}
			}
			echo '<select style="max-width:200px" class="chosen-filter" name="showuser_agent" id="ualp-filter-showuser_agent">';
			printf( '<option value="">' . esc_html__( 'All User Agents', 'user_activity_log_pro' ) . '</option>' );
			echo wp_kses( implode( '', $output ), $args_kses );
			echo '</select>';
		}

			$allloginstatus = $externaldb->get_results(
				'SELECT DISTINCT login_status FROM ' . UALP_LOGIN_TABLENAME . '
                        WHERE 1 = 1
                        ORDER BY login_status
                '
			);
		if ( $allloginstatus ) {
			if ( ! isset( $_REQUEST['loginstatus'] ) ) {
				$_REQUEST['loginstatus'] = '';
			}
			$output = array();
			foreach ( $allloginstatus as $loginstatus ) {
				if ( $loginstatus->login_status ) {
					$output[] = sprintf( '<option value="%s"%s>%s</option>', $loginstatus->login_status, selected( sanitize_text_field( wp_unslash( $_REQUEST['loginstatus'] ) ), $loginstatus->login_status, false ), ucfirst( $loginstatus->login_status ) );
				}
			}
			echo '<select class="chosen-filter" name="loginstatus" id="ualp-filter-loginstatus">';
			printf( '<option value="">' . esc_html__( 'All Login Status', 'user_activity_log_pro' ) . '</option>' );
			echo wp_kses( implode( '', $output ), $args_kses );
			echo '</select>';
		}
			$alltimelogin = $externaldb->get_results(
				'SELECT DISTINCT time_login FROM ' . UALP_LOGIN_TABLENAME . '
                        WHERE 1 = 1
                        ORDER BY time_login
                '
			);
		if ( $alltimelogin ) {
			if ( ! isset( $_REQUEST['timelogin'] ) ) {
				$_REQUEST['timelogin'] = '';
			}
				$date_options = array(
					''           => esc_html__( 'All Login Time', 'user_activity_log_pro' ),
					'today'      => esc_html__( 'Today', 'user_activity_log_pro' ),
					'yesterday'  => esc_html__( 'Yesterday', 'user_activity_log_pro' ),
					'week'       => esc_html__( 'Week', 'user_activity_log_pro' ),
					'this-month' => esc_html__( 'This Month', 'user_activity_log_pro' ),
					'month'      => esc_html__( 'Last 1 Month', 'user_activity_log_pro' ),
					'2-month'    => esc_html__( 'Last 2 Month', 'user_activity_log_pro' ),
					'3-month'    => esc_html__( 'Last 3 Month', 'user_activity_log_pro' ),
					'6-month'    => esc_html__( 'Last 6 Month', 'user_activity_log_pro' ),
					'this-year'  => esc_html__( 'This Year', 'user_activity_log_pro' ),
					'last-year'  => esc_html__( 'Last Year', 'user_activity_log_pro' ),
					'custom'     => esc_html__( 'Custom Date Range', 'user_activity_log_pro' ),
				);
				echo '<select name="timelogin" class="chosen-filter" id="ualp-login-filter-date">';
				foreach ( $date_options as $key => $value ) {
					printf( '<option value="%1$s"%2$s>%3$s</option>', esc_html( $key ), selected( sanitize_text_field( wp_unslash( $_REQUEST['timelogin'] ) ), esc_html( $key ), false ), esc_html( $value ) );
				}
				echo '</select>';
		}

			$alltimelogout = $externaldb->get_results(
				'SELECT DISTINCT time_logout FROM ' . UALP_LOGIN_TABLENAME . '
                        WHERE 1 = 1
                        ORDER BY time_logout
                '
			);
		if ( $alltimelogout ) {
			if ( ! isset( $_REQUEST['timelogout'] ) ) {
				$_REQUEST['timelogout'] = '';
			}
				$date_options = array(
					''           => esc_html__( 'All Logout Time', 'user_activity_log_pro' ),
					'today'      => esc_html__( 'Today', 'user_activity_log_pro' ),
					'yesterday'  => esc_html__( 'Yesterday', 'user_activity_log_pro' ),
					'week'       => esc_html__( 'Week', 'user_activity_log_pro' ),
					'this-month' => esc_html__( 'This Month', 'user_activity_log_pro' ),
					'month'      => esc_html__( 'Last 1 Month', 'user_activity_log_pro' ),
					'2-month'    => esc_html__( 'Last 2 Month', 'user_activity_log_pro' ),
					'3-month'    => esc_html__( 'Last 3 Month', 'user_activity_log_pro' ),
					'6-month'    => esc_html__( 'Last 6 Month', 'user_activity_log_pro' ),
					'this-year'  => esc_html__( 'This Year', 'user_activity_log_pro' ),
					'last-year'  => esc_html__( 'Last Year', 'user_activity_log_pro' ),
					'custom'     => esc_html__( 'Custom Date Range', 'user_activity_log_pro' ),
				);
				echo '<select name="timelogout" class="chosen-filter" id="ualp-logout-filter-date">';
				foreach ( $date_options as $key => $value ) {
					printf( '<option value="%1$s"%2$s>%3$s</option>', esc_html( $key ), selected( sanitize_text_field( wp_unslash( $_REQUEST['timelogout'] ) ), esc_html( $key ), false ), esc_html( $value ) );
				}
				echo '</select>';
		}
			$site_id = $externaldb->get_results(
				'SELECT DISTINCT site_id FROM ' . UALP_LOGIN_TABLENAME . '
                        WHERE 1 = 1
                        ORDER BY site_id'
			);

		if ( ualp_multi_site_support_return() ) {
			if ( is_network_admin() && ualp_multi_site_support_return() ) {
				if ( $site_id ) {
					if ( ! isset( $_REQUEST['showsiteid'] ) ) {
						$_REQUEST['showsiteid'] = '';
					}
					$output = array();
					foreach ( $site_id as $allsiteid ) {
						if ( isset( $allsiteid->site_id ) && 0 != $allsiteid->site_id ) {
							$getsitename = get_blog_details( $allsiteid->site_id );
							$output[]    = sprintf( '<option value="%s"%s>%s</option>', $allsiteid->site_id, selected( sanitize_text_field( wp_unslash( $_REQUEST['showsiteid'] ) ), $allsiteid->site_id, false ), $this->ualp_get_action_label( $getsitename->blogname ) );
						}
					}
					echo '<select class="chosen-filter" name="showsiteid" id="ualp-filter-showsiteid">';
					printf( '<option value="">' . esc_html__( 'All Site', 'user_activity_log_pro' ) . '</option>' );
					echo wp_kses( implode( '', $output ), $args_kses );
					echo '</select>';
				}
			}
		}
		echo '</div>';
			// Parse all query vars into an array.
			$query_vars = array();

		if ( isset( $_SERVER['QUERY_STRING'] ) ) {
			parse_str( urldecode( sanitize_text_field( wp_unslash( $_SERVER['QUERY_STRING'] ) ) ), $query_vars );
		}

			// Ignore certain query vars and query vars that are empty.
		foreach ( $query_vars as $query_var => $value ) {
			if ( '' === $value || 'page' === $query_var || 'paged' === $query_var ) {
				unset( $query_vars[ $query_var ] );
			}
		}
		?>
		<div class="filter-btn-cover">
			<?php
			submit_button( __( 'Filter', 'user_activity_log_pro' ), 'primary', false, false, array( 'uacltid' => 'login-query-submit' ) );
			if ( ! empty( $query_vars ) ) {
				if ( is_network_admin() && ualp_multi_site_support_return() ) {
					$adminurl = network_admin_url( 'admin.php?page=ualp_user_details' );
				} else {
					$adminurl = admin_url( 'admin.php?page=ualp_user_details' );
				}
				?>
				<a class="button ualp-button-green" href="<?php echo esc_url( $adminurl ); ?>">
					<?php esc_html_e( 'Reset Filter', 'user_activity_log_pro' ); ?>
				</a>
				<?php
			}
			?>
		</div>
		<?php
			$loginstart_date = ( isset( $_REQUEST['login_start_date'] ) && '' != $_REQUEST['login_start_date'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['login_start_date'] ) ) : '';
			$loginend_date   = ( isset( $_REQUEST['login_end_date'] ) && '' != $_REQUEST['login_end_date'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['login_end_date'] ) ) : '';
				echo '<div class="custom-login-date pull-left">'
						. '<p>'
							. esc_html__( 'Login start date', 'user_activity_log_pro' ) . ' : '
							. '<input type="text" name="login_start_date" value="' . esc_attr( $loginstart_date ) . '" class="datepicker login-start-date"> '
							. esc_html__( 'Login end date', 'user_activity_log_pro' ) . ' : '
							. '<input type="text" name="login_end_date" value="' . esc_attr( $loginend_date ) . '" class="datepicker login-end-date">'
						. '</p>'
						. '<p class="login_custom_date_msg"></p>'
					. '</div>';
		$logoutstart_date = ( isset( $_REQUEST['logout_start_date'] ) && '' != $_REQUEST['logout_start_date'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['logout_start_date'] ) ) : '';
		$logoutend_date   = ( isset( $_REQUEST['logout_end_date'] ) && '' != $_REQUEST['logout_end_date'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['logout_end_date'] ) ) : '';
			echo '<div class="custom-logout-date pull-left">'
					. '<p>'
						. esc_html__( 'Logout start date', 'user_activity_log_pro' ) . ' : '
						. '<input type="text" name="logout_start_date" value="' . esc_attr( $logoutstart_date ) . '" class="datepicker logout-start-date"> '
						. esc_html__( 'Logout end date', 'user_activity_log_pro' ) . ' : '
						. '<input type="text" name="logout_end_date" value="' . esc_attr( $logoutend_date ) . '" class="datepicker logout-end-date">'
					. '</p>'
					. '<p class="logout_custom_date_msg"></p>'
					. '</div>';
		echo '</div>';
	}

	/**
	 * Display Table Navigation.
	 *
	 * @param string $which Condition.
	 */
	public function display_tablenav( $which ) {
		global $wpdb, $externaldb;
		$transition_where = ' 1 = 1';
		if ( ualp_multi_site_support_return() ) {
			$transition_where .= " AND site_id = '" . get_current_blog_id() . "'";
		}
		$item_list = $externaldb->get_var( 'SELECT count(uacltid) FROM ' . UALP_LOGIN_TABLENAME . ' WHERE' . $transition_where );
		?>
		<div class="tablenav <?php echo esc_attr( $which ); ?>">
			<?php
			if ( $item_list ) {
				if ( 'top' == $which ) {
					?>
					<div class = "wp-filter">
						<div class = "filter-items">
							<?php
							$this->extra_tablenav( $which );
							?>
							<div class="top-cover">
								<div class="alignleft bulkactions">
									<?php
									$ualp_delete_log_pwd       = get_option( 'ualp_delete_log_pwd' );
									$ualp_log_password_protect = get_option( 'ualpLogPasswordProtect', true );
									if ( 1 == $ualp_log_password_protect && ( ! $ualp_delete_log_pwd || '' == $ualp_delete_log_pwd ) ) {
										$class = 'setBulkDeletePassword';
									} elseif ( 0 == $ualp_log_password_protect ) {
										$class = 'logPasswordProtect';
									} else {
										$class = 'deleteBulkLog';
									}
									?>
									<label class="screen-reader-text" for="bulk-action-selector-top">
										<?php esc_html_e( 'Select bulk action', 'user_activity_log_pro' ); ?>
									</label>
									<select class="<?php echo esc_attr( $class ); ?>" id="bulk-action-selector-top" name="bulk_action_selector">
										<option value="0"><?php esc_html_e( 'Bulk Actions', 'user_activity_log_pro' ); ?></option>
										<option value="delete"><?php esc_html_e( 'Delete Permanently', 'user_activity_log_pro' ); ?></option>
									</select>
									<input type="submit" value="<?php esc_html_e( 'Apply', 'user_activity_log_pro' ); ?>" name="bulk_action" class="button action" id="doaction">
									<?php
									$items_array = $this->items;
									if ( is_array( $items_array ) && count( $items_array ) > 0 ) {
										if ( ! isset( $_REQUEST['usershow'] ) ) {
											$_REQUEST['usershow'] = '';
										}
										if ( ! isset( $_REQUEST['showip'] ) ) {
											$_REQUEST['showip'] = '';
										}
										if ( ! isset( $_REQUEST['showcountry'] ) ) {
											$_REQUEST['showcountry'] = '';
										}
										if ( ! isset( $_REQUEST['showuser_agent'] ) ) {
											$_REQUEST['showuser_agent'] = '';
										}
										if ( ! isset( $_REQUEST['s'] ) ) {
											$_REQUEST['s'] = '';
										}
										if ( ! isset( $_REQUEST['loginstatus'] ) ) {
											$_REQUEST['loginstatus'] = '';
										}
										if ( ! isset( $_REQUEST['timelogin'] ) ) {
											$_REQUEST['timelogin'] = '';
										}
										if ( ! isset( $_REQUEST['timelogout'] ) ) {
											$_REQUEST['timelogout'] = '';
										}
										if ( ! isset( $_REQUEST['user_role'] ) ) {
											$_REQUEST['user_role'] = '';
										}
										if ( ! isset( $_REQUEST['showsiteid'] ) ) {
											$_REQUEST['showsiteid'] = '';
										}
										if ( ! isset( $_REQUEST['login_start_date'] ) ) {
											$_REQUEST['login_start_date'] = '';
										}
										if ( ! isset( $_REQUEST['login_end_date'] ) ) {
											$_REQUEST['login_end_date'] = '';
										}
										if ( ! isset( $_REQUEST['logout_start_date'] ) ) {
											$_REQUEST['logout_start_date'] = '';
										}
										if ( ! isset( $_REQUEST['logout_end_date'] ) ) {
											$_REQUEST['logout_end_date'] = '';
										}

										if ( is_network_admin() && ualp_multi_site_support_return() ) {
											$adminurl      = network_admin_url( 'admin.php?page=ualp_user_details&export=user_login&logformat=csv&username=' . sanitize_text_field( wp_unslash( $_REQUEST['usershow'] ) ) . '&ip=' . sanitize_text_field( wp_unslash( $_REQUEST['showip'] ) ) . '&country=' . sanitize_text_field( wp_unslash( $_REQUEST['showcountry'] ) ) . '&user_agent=' . sanitize_text_field( wp_unslash( $_REQUEST['showuser_agent'] ) ) . '&txtsearch=' . sanitize_text_field( wp_unslash( $_REQUEST['s'] ) ) . '&loginstatus=' . sanitize_text_field( wp_unslash( $_REQUEST['loginstatus'] ) ) . '&timelogin=' . sanitize_text_field( wp_unslash( $_REQUEST['timelogin'] ) ) . '&timelogout=' . sanitize_text_field( wp_unslash( $_REQUEST['timelogout'] ) ) . '&user_role=' . sanitize_text_field( wp_unslash( $_REQUEST['user_role'] ) ) . '&showsiteid=' . sanitize_text_field( wp_unslash( $_REQUEST['showsiteid'] ) ) . '&login_start_date=' . sanitize_text_field( wp_unslash( $_REQUEST['login_start_date'] ) ) . '&login_end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['login_end_date'] ) ) . '&logout_start_date=' . sanitize_text_field( wp_unslash( $_REQUEST['logout_start_date'] ) ) . '&logout_end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['logout_end_date'] ) ) );
											$json_adminurl = network_admin_url( 'admin.php?page=ualp_user_details&export=user_login&logformat=json&username=' . sanitize_text_field( wp_unslash( $_REQUEST['usershow'] ) ) . '&ip=' . sanitize_text_field( wp_unslash( $_REQUEST['showip'] ) ) . '&country=' . sanitize_text_field( wp_unslash( $_REQUEST['showcountry'] ) ) . '&user_agent=' . sanitize_text_field( wp_unslash( $_REQUEST['showuser_agent'] ) ) . '&txtsearch=' . sanitize_text_field( wp_unslash( $_REQUEST['s'] ) ) . '&loginstatus=' . sanitize_text_field( wp_unslash( $_REQUEST['loginstatus'] ) ) . '&timelogin=' . sanitize_text_field( wp_unslash( $_REQUEST['timelogin'] ) ) . '&timelogout=' . sanitize_text_field( wp_unslash( $_REQUEST['timelogout'] ) ) . '&user_role=' . sanitize_text_field( wp_unslash( $_REQUEST['user_role'] ) ) . '&showsiteid=' . sanitize_text_field( wp_unslash( $_REQUEST['showsiteid'] ) ) . '&login_start_date=' . sanitize_text_field( wp_unslash( $_REQUEST['login_start_date'] ) ) . '&login_end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['login_end_date'] ) ) . '&logout_start_date=' . sanitize_text_field( wp_unslash( $_REQUEST['logout_start_date'] ) ) . '&logout_end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['logout_end_date'] ) ) );
										} else {
											$adminurl      = admin_url( 'admin.php?page=ualp_user_details&export=user_login&logformat=csv&username=' . sanitize_text_field( wp_unslash( $_REQUEST['usershow'] ) ) . '&ip=' . sanitize_text_field( wp_unslash( $_REQUEST['showip'] ) ) . '&country=' . sanitize_text_field( wp_unslash( $_REQUEST['showcountry'] ) ) . '&user_agent=' . sanitize_text_field( wp_unslash( $_REQUEST['showuser_agent'] ) ) . '&txtsearch=' . sanitize_text_field( wp_unslash( $_REQUEST['s'] ) ) . '&loginstatus=' . sanitize_text_field( wp_unslash( $_REQUEST['loginstatus'] ) ) . '&timelogin=' . sanitize_text_field( wp_unslash( $_REQUEST['timelogin'] ) ) . '&timelogout=' . sanitize_text_field( wp_unslash( $_REQUEST['timelogout'] ) ) . '&user_role=' . sanitize_text_field( wp_unslash( $_REQUEST['user_role'] ) ) . '&showsiteid=' . sanitize_text_field( wp_unslash( $_REQUEST['showsiteid'] ) ) . '&login_start_date=' . sanitize_text_field( wp_unslash( $_REQUEST['login_start_date'] ) ) . '&login_end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['login_end_date'] ) ) . '&login_end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['login_end_date'] ) ) . '&logout_start_date=' . sanitize_text_field( wp_unslash( $_REQUEST['logout_start_date'] ) ) . '&logout_end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['logout_end_date'] ) ) );
											$json_adminurl = admin_url( 'admin.php?page=ualp_user_details&export=user_login&logformat=json&username=' . sanitize_text_field( wp_unslash( $_REQUEST['usershow'] ) ) . '&ip=' . sanitize_text_field( wp_unslash( $_REQUEST['showip'] ) ) . '&country=' . sanitize_text_field( wp_unslash( $_REQUEST['showcountry'] ) ) . '&user_agent=' . sanitize_text_field( wp_unslash( $_REQUEST['showuser_agent'] ) ) . '&txtsearch=' . sanitize_text_field( wp_unslash( $_REQUEST['s'] ) ) . '&loginstatus=' . sanitize_text_field( wp_unslash( $_REQUEST['loginstatus'] ) ) . '&timelogin=' . sanitize_text_field( wp_unslash( $_REQUEST['timelogin'] ) ) . '&timelogout=' . sanitize_text_field( wp_unslash( $_REQUEST['timelogout'] ) ) . '&user_role=' . sanitize_text_field( wp_unslash( $_REQUEST['user_role'] ) ) . '&showsiteid=' . sanitize_text_field( wp_unslash( $_REQUEST['showsiteid'] ) ) . '&login_start_date=' . sanitize_text_field( wp_unslash( $_REQUEST['login_start_date'] ) ) . '&login_end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['login_end_date'] ) ) . '&login_end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['login_end_date'] ) ) . '&logout_start_date=' . sanitize_text_field( wp_unslash( $_REQUEST['logout_start_date'] ) ) . '&logout_end_date=' . sanitize_text_field( wp_unslash( $_REQUEST['logout_end_date'] ) ) );
										}
										?>
										<a href="<?php echo wp_nonce_url( $adminurl, 'export-action', 'export-nonce' ); ?>" class="button-primary action">
											<?php esc_html_e( 'Export Data (CSV)', 'user_activity_log_pro' ); ?>
										</a>
										<a href="<?php echo wp_nonce_url( $json_adminurl, 'export-action', 'export-nonce' ); ?>" class="button-primary action">
											<?php esc_html_e( 'Export Data (JSON)', 'user_activity_log_pro' ); ?>
										</a>
										<?php
									}
									?>
								</div>
							</div>
							<?php
							$this->search_box( 'Search', 'search' );
							?>
						</div>
					</div>
					<div class="terminate-session-wrapp">
					<?php
					if ( $item_list ) {
						if ( ualp_multi_site_support_return() ) {
							$super_admin = is_super_admin( get_current_user_id() );
							if ( '1' == $super_admin ) {
								?>
								<a id="terminate-all-sessions" name= "terminate-all-sessions" class="button-primary action terminate-all-sessions">
								<?php esc_html_e( 'Terminate All Sessions', 'user_activity_log_pro' ); ?>
								</a>
								<?php
							}
						} else {
							$current_user = wp_get_current_user();
							if ( isset( $current_user->roles ) ) {
								$user_all_role = $current_user->roles;
								foreach ( $user_all_role as $user_role ) {
									if ( 'administrator' == $user_role ) {
										?>
											<a id="terminate-all-sessions" name= "terminate-all-sessions" class="button-primary action terminate-all-sessions">
											<?php esc_html_e( 'Terminate All Sessions', 'user_activity_log_pro' ); ?>
												</a>
											<?php
									}
								}
							}
						}
					}
					?>
						</div>
					<?php
				}
				$this->pagination( $which );
			}
			?>
		</div>
		<?php
	}

	/**
	 * Bulk Actions.
	 */
	public function process_bulk_action() {
		global $wpdb;
		if ( isset( $_REQUEST['id'] ) && is_array( $_REQUEST['id'] ) ) {
			$ids = isset( $_REQUEST['id'] ) ? array_map( 'sanitize_text_field', wp_unslash( $_REQUEST['id'] ) ) : array();
		} else {
			$ids = isset( $_REQUEST['id'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['id'] ) ) : '';
		}
		if ( is_array( $ids ) ) {
			$ids = implode( ',', $ids );
		}

		if ( ! empty( $ids ) ) {
			if ( is_multisite() ) {
				$wpdb->query( $wpdb->prepare( "DELETE FROM {$wpdb->base_prefix}ualp_user_activity_login WHERE uacltid IN(%1s)", $ids ) );
			} else {
				$wpdb->query( $wpdb->prepare( "DELETE FROM {$wpdb->prefix}ualp_user_activity_login WHERE uacltid IN(%1s)", $ids ) );
			}
		}
	}
	/**
	 * Prepare Items.
	 */
	public function prepare_items() {
		global $wpdb, $externaldb;
		$request_url            = isset( $_SERVER['REQUEST_URI'] ) ? esc_url_raw( wp_unslash( $_SERVER['REQUEST_URI'] ) ) : '';
		$_SERVER['REQUEST_URI'] = remove_query_arg( '_wp_http_referer', $request_url );
		$items_per_page         = $this->get_items_per_page( 'ualp_user_logged_per_page' );
		$columns                = $this->get_columns();
		$hidden                 = array();
		$sortable               = $this->get_sortable_columns();
		$this->_column_headers  = $this->get_column_info();
		$this->process_bulk_action();
		$where = ' WHERE 1=1';
		if ( ! isset( $_REQUEST['order'] ) || ! in_array( $_REQUEST['order'], array( 'desc', 'asc' ) ) ) {
			$_REQUEST['order'] = 'desc';
		}
		if ( ! isset( $_REQUEST['orderby'] ) || ! in_array( $_REQUEST['orderby'], array( 'user_agent', 'user_id', 'user_email', 'time_login', 'time_logout', 'ip_address', 'country', 'time_last_seen', 'login_status' ) ) ) {
			$_REQUEST['orderby'] = 'time_login';
		}
		if ( isset( $_REQUEST['datefilterlastseen'] ) && '' != $_REQUEST['datefilterlastseen'] ) {
			$datefilterlastseen = sanitize_text_field( wp_unslash( $_REQUEST['datefilterlastseen'] ) );
			$datefilterlastseen = gmdate( 'Y-m-d', $datefilterlastseen );
			$where             .= ' AND time_last_seen LIKE "%%' . $datefilterlastseen . '%%"';
		}
		if ( isset( $_REQUEST['datefilterlogout'] ) && '' != $_REQUEST['datefilterlogout'] ) {
			$datefilterlogout = sanitize_text_field( wp_unslash( $_REQUEST['datefilterlogout'] ) );
			$datefilterlogout = gmdate( 'Y-m-d', $datefilterlogout );
			$where           .= ' AND time_logout LIKE "%%' . $datefilterlogout . '%%"';
		}
		if ( isset( $_REQUEST['datefilterlogin'] ) && '' != $_REQUEST['datefilterlogin'] ) {
			$datefilterlogin = sanitize_text_field( wp_unslash( $_REQUEST['datefilterlogin'] ) );
			$datefilterlogin = gmdate( 'Y-m-d', $datefilterlogin );
			$where          .= ' AND time_login LIKE "%%' . $datefilterlogin . '%%"';
		}

		if ( isset( $_REQUEST['loginstatus'] ) && '' != $_REQUEST['loginstatus'] ) {
			$loginstatus = sanitize_text_field( wp_unslash( $_REQUEST['loginstatus'] ) );
			$where      .= ' AND login_status LIKE "%%' . $loginstatus . '%%"';
		}
		if ( isset( $_REQUEST['ip_address'] ) && '' != $_REQUEST['ip_address'] ) {
			$ip_address = sanitize_text_field( wp_unslash( $_REQUEST['ip_address'] ) );
			$where     .= ' AND ip_address LIKE "%%' . $ip_address . '%%"';
		}
		if ( isset( $_REQUEST['user_id'] ) && '' != $_REQUEST['user_id'] ) {
			$user_id = sanitize_text_field( wp_unslash( $_REQUEST['user_id'] ) );
			$where  .= ' AND user_id LIKE "%%' . $user_id . '%%"';
		}
		if ( isset( $_REQUEST['user_role'] ) && '' != $_REQUEST['user_role'] ) {
			$user_role = sanitize_text_field( wp_unslash( $_REQUEST['user_role'] ) );
			$where    .= ' AND user_role LIKE "%%' . $user_role . '%%"';
		}
		if ( isset( $_REQUEST['usershow'] ) && '' !== $_REQUEST['usershow'] ) {
			$where .= $externaldb->prepare( ' AND `user_name` = %s', sanitize_text_field( wp_unslash( $_REQUEST['usershow'] ) ) );
		}
		if ( isset( $_REQUEST['showip'] ) && '' !== $_REQUEST['showip'] ) {
			$where .= $externaldb->prepare( ' AND `ip_address` = \'%s\'', sanitize_text_field( wp_unslash( $_REQUEST['showip'] ) ) );
		}
		if ( isset( $_REQUEST['showcountry'] ) && '' !== $_REQUEST['showcountry'] ) {
			$where .= $externaldb->prepare( ' AND `country` = \'%s\'', sanitize_text_field( wp_unslash( $_REQUEST['showcountry'] ) ) );
		}
		if ( isset( $_REQUEST['showuser_agent'] ) && '' !== $_REQUEST['showuser_agent'] ) {
			$where .= $externaldb->prepare( ' AND `user_agent` = \'%s\'', sanitize_text_field( wp_unslash( $_REQUEST['showuser_agent'] ) ) );
		}
		if ( isset( $_REQUEST['s'] ) && '' != $_REQUEST['s'] ) {
			$where .= ' AND (user_name LIKE \'%%' . $externaldb->esc_like( sanitize_text_field( wp_unslash( $_REQUEST['s'] ) ) ) . '%%\')';
		}
		if ( isset( $_REQUEST['timelogin'] ) && in_array( $_REQUEST['timelogin'], array( 'today', 'yesterday', 'week', 'this-month', 'month', '2-month', '3-month', '6-month', 'this-year', 'last-year', 'custom' ) ) ) {
			$get_login_time = isset( $_REQUEST['timelogin'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['timelogin'] ) ) : '';
			$current_time   = current_time( 'timestamp' );
			$start_time     = mktime( 0, 0, 0, gmdate( 'm', $current_time ), gmdate( 'd', $current_time ), gmdate( 'Y', $current_time ) );
			$end_time       = mktime( 23, 59, 59, gmdate( 'm', $current_time ), gmdate( 'd', $current_time ), gmdate( 'Y', $current_time ) );
			if ( 'today' == $get_login_time ) {
				$start_time = $current_time;
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time );

			} elseif ( 'yesterday' === $get_login_time ) {
				$start_time = strtotime( 'yesterday', $start_time );
				$end_time   = $current_time;

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time );

			} elseif ( 'week' === $get_login_time ) {
				$start_time = strtotime( '-1 week', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time );

			} elseif ( 'this-month' === $get_login_time ) {
				$start_time = gmdate( 'Y-m-01' );
				$start_time = strtotime( $start_time );

				$end_time = gmdate( 'Y-m-31' );
				$end_time = strtotime( $end_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time );

			} elseif ( 'month' === $get_login_time ) {
				$start_time = strtotime( '-1 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time );

			} elseif ( '2-month' === $get_login_time ) {
				$start_time = strtotime( '-2 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time );

			} elseif ( '3-month' === $get_login_time ) {
				$start_time = strtotime( '-3 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time );

			} elseif ( '6-month' === $get_login_time ) {
				$start_time = strtotime( '-6 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time );

			} elseif ( 'this-year' === $get_login_time ) {
				$start_time = gmdate( 'Y-01-01' );
				$start_time = strtotime( $start_time );

				$end_time = gmdate( 'Y-12-31' );
				$end_time = strtotime( $end_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time );
			} elseif ( 'last-year' === $get_login_time ) {

				$start_time = gmdate( 'Y-01-01' );
				$start_time = strtotime( $start_time );
				$start_time = strtotime( '-1 year', $start_time );

				$end_time = gmdate( 'Y-12-31' );
				$end_time = strtotime( $end_time );
				$end_time = strtotime( '-1 year', $end_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time );
			} elseif ( 'custom' === $get_login_time ) {
				$custom_start_date = isset( $_REQUEST['login_start_date'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['login_start_date'] ) ) : '';
				$custom_end_date   = isset( $_REQUEST['login_end_date'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['login_end_date'] ) ) : '';
				if ( isset( $custom_start_date ) && '' != $custom_start_date ) {
					$start_time = strtotime( $custom_start_date . ' 23:59:59' );
					if ( gmdate( 'Y-m-d H:i:s', $start_time ) > gmdate( 'Y-m-d H:i:s' ) ) {
						$start_time = strtotime( $custom_start_date . ' 23:59:59' );
					} else {
						$start_time = strtotime( '-1 day', $start_time );
					}
					$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
					$where     .= $externaldb->prepare( ' AND time_login >= "%s"', $start_time );
				}
				if ( isset( $custom_end_date ) && '' != $custom_end_date ) {
					$end_time = strtotime( $custom_end_date . ' 23:59:59' );
					$end_time = strtotime( '+1 day', $end_time );
					$end_time = gmdate( 'Y-m-d H:i:s', $end_time );
					$where   .= $externaldb->prepare( ' AND time_login < "%s"', $end_time );
				}
			}
		}
		if ( isset( $_REQUEST['timelogout'] ) && in_array( $_REQUEST['timelogout'], array( 'today', 'yesterday', 'week', 'this-month', 'month', '2-month', '3-month', '6-month', 'this-year', 'last-year', 'custom' ) ) ) {
			$get_logout_time = isset( $_REQUEST['timelogout'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['timelogout'] ) ) : '';
			$current_time    = current_time( 'timestamp' );
			$start_time      = mktime( 0, 0, 0, gmdate( 'm', $current_time ), gmdate( 'd', $current_time ), gmdate( 'Y', $current_time ) );
			$end_time        = mktime( 23, 59, 59, gmdate( 'm', $current_time ), gmdate( 'd', $current_time ), gmdate( 'Y', $current_time ) );
			if ( 'today' == $get_logout_time ) {
				$start_time = $current_time;
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time );

			} elseif ( 'yesterday' === $get_logout_time ) {
				$start_time = strtotime( 'yesterday', $start_time );
				$end_time   = $current_time;

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time );

			} elseif ( 'week' === $get_logout_time ) {
				$start_time = strtotime( '-1 week', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time );

			} elseif ( 'this-month' === $get_logout_time ) {
				$start_time = gmdate( 'Y-m-01' );
				$start_time = strtotime( $start_time );

				$end_time = gmdate( 'Y-m-31' );
				$end_time = strtotime( $end_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time );

			} elseif ( 'month' === $get_logout_time ) {
				$start_time = strtotime( '-1 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time );

			} elseif ( '2-month' === $get_logout_time ) {
				$start_time = strtotime( '-2 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time );

			} elseif ( '3-month' === $get_logout_time ) {
				$start_time = strtotime( '-3 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time );

			} elseif ( '6-month' === $get_logout_time ) {
				$start_time = strtotime( '-6 month', $start_time );
				$end_time   = strtotime( '+1 day', $current_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time );

			} elseif ( 'this-year' === $get_logout_time ) {
				$start_time = gmdate( 'Y-01-01' );
				$start_time = strtotime( $start_time );

				$end_time = gmdate( 'Y-12-31' );
				$end_time = strtotime( $end_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time );
			} elseif ( 'last-year' === $get_logout_time ) {

				$start_time = gmdate( 'Y-01-01' );
				$start_time = strtotime( $start_time );
				$start_time = strtotime( '-1 year', $start_time );

				$end_time = gmdate( 'Y-12-31' );
				$end_time = strtotime( $end_time );
				$end_time = strtotime( '-1 year', $end_time );

				$start_time = gmdate( 'Y-m-d', $start_time );
				$end_time   = gmdate( 'Y-m-d', $end_time );
				$where     .= $externaldb->prepare( ' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time );
			} elseif ( 'custom' === $get_logout_time ) {
				$custom_start_date = isset( $_REQUEST['logout_start_date'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['logout_start_date'] ) ) : '';
				$custom_end_date   = isset( $_REQUEST['logout_end_date'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['logout_end_date'] ) ) : '';
				if ( isset( $custom_start_date ) && '' != $custom_start_date ) {
					$start_time = strtotime( $custom_start_date . ' 23:59:59' );
					if ( gmdate( 'Y-m-d H:i:s', $start_time ) > gmdate( 'Y-m-d H:i:s' ) ) {
						$start_time = strtotime( $custom_start_date . ' 23:59:59' );
					} else {
						$start_time = strtotime( '-1 day', $start_time );
					}
					$start_time = gmdate( 'Y-m-d H:i:s', $start_time );
					$where     .= $externaldb->prepare( ' AND time_logout >= "%s"', $start_time );
				}
				if ( isset( $custom_end_date ) && '' != $custom_end_date ) {
					$end_time = strtotime( $custom_end_date . ' 23:59:59' );
					$end_time = strtotime( '+1 day', $end_time );
					$end_time = gmdate( 'Y-m-d H:i:s', $end_time );
					$where   .= $externaldb->prepare( ' AND time_logout < "%s"', $end_time );
				}
			}
		}

		if ( ualp_multi_site_support_return() ) {
			if ( is_network_admin() ) {
				if ( isset( $_REQUEST['showsiteid'] ) && '' != $_REQUEST['showsiteid'] ) {
					$where .= " AND site_id = '" . sanitize_text_field( wp_unslash( $_REQUEST['showsiteid'] ) ) . "'";
				}
			} else {
				$where .= " AND site_id = '" . get_current_blog_id() . "'";
			}
		}
		$offset = ( $this->get_pagenum() - 1 ) * $items_per_page;

		$total_items = $externaldb->get_var(
			'SELECT COUNT(`uacltid`) FROM ' . UALP_LOGIN_TABLENAME . $where
		);
		$this->items = $externaldb->get_results(
			$externaldb->prepare(
				'SELECT * FROM ' . UALP_LOGIN_TABLENAME . $where . ' order by ' . sanitize_text_field( wp_unslash( $_REQUEST['orderby'] ) ) . ' ' . sanitize_text_field( wp_unslash( $_REQUEST['order'] ) ) . ' LIMIT %d, %d',
				$offset,
				$items_per_page
			)
		);
		$this->set_pagination_args(
			array(
				'total_items' => $total_items,
				'per_page'    => $items_per_page,
				'total_pages' => ceil( $total_items / $items_per_page ),
			)
		);
	}

	/**
	 * No Items.
	 */
	public function no_items() {
		esc_html_e( 'No Logged In User Found.', 'user_activity_log_pro' );
	}

	/**
	 * Search Box.
	 *
	 * @param string $text Text.
	 * @param string $input_id Input ID.
	 */
	public function search_box( $text, $input_id ) {
		$search_data = isset( $_REQUEST['s'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['s'] ) ) : '';
		$input_id    = $input_id . '-search-input';
		?>
		<p class="search-box">
			<label class="screen-reader-text" for="<?php echo esc_attr( $input_id ); ?>"><?php echo esc_html( $text ); ?>:</label>
			<input type="search" id="<?php echo esc_attr( $input_id ); ?>" name="s" placeholder="<?php esc_html_e( 'User Name', 'user_activity_log_pro' ); ?>" value="<?php echo esc_attr( $search_data ); ?>" />
			<?php submit_button( $text, 'button', false, false, array( 'uacltid' => 'search-submit' ) ); ?>
		</p>
		<?php
	}
}

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @author     Solwin Infotech <info@solwininfotech.com>
 */
class Ualp_Email_Notification_List_Table extends WP_List_Table {

	/**
	 * Class Cunstructor.
	 */
	public function __construct() {
		global $status, $page;
		parent::__construct(
			array(
				'singular' => 'person',
				'plural'   => 'persons',
				'screen'   => isset( $args['screen'] ) ? $args['screen'] : null,
			)
		);
		add_screen_option(
			'per_page',
			array(
				'default' => 20,
				'label'   => esc_html__( 'Number of email per page', 'user_activity_log_pro' ) . ' : ',
				'option'  => 'ualp_user_email_per_page',
			)
		);
			add_filter( 'set-screen-option', array( &$this, 'ualp_email_set_screen_option' ), 10, 3 );
			set_screen_options();
	}

	/**
	 * Set Screem Options.
	 *
	 * @param string $status Status.
	 * @param string $option Option.
	 * @param string $value Value.
	 */
	public function ualp_email_set_screen_option( $status, $option, $value ) {
		if ( 'ualp_user_email_per_page' === $option ) {
			return $value;
		}
	}

	/**
	 * Column Default.
	 *
	 * @param string $item Item.
	 * @param string $column_name Column Name.
	 */
	public function column_default( $item, $column_name ) {
		return $item[ $column_name ];
	}

	/**
	 * User name Column.
	 *
	 * @param string $item Item.
	 */
	public function column_user_name( $item ) {
		return $item['user_name'];
	}

	/**
	 * Email Address Column.
	 *
	 * @param string $item Item.
	 */
	public function column_email_address( $item ) {
		return $item['email_address'];
	}

	/**
	 * Email Template Column.
	 *
	 * @param string $item Item.
	 */
	public function column_email_template( $item ) {
		if ( '0' == $item['email_template'] ) {
			return __( 'Default Template', 'user_activity_log_pro' );
		}
		if ( '1' == $item['email_template'] ) {
			return __( 'Event Specific Template', 'user_activity_log_pro' );
		}

	}

	/**
	 * Email Title Column.
	 *
	 * @param string $item Item.
	 */
	public function column_email_title( $item ) {
		$actions = array(
			'edit'   => sprintf( '<a href="?page=ualp_add_email_notification&enotification=%s">%s</a>', $item['uacteid'], __( 'Edit', 'user_activity_log_pro' ) ),
			'delete' => sprintf( '<a class="ualp_delete_email" href="?page=ualp_email_setting&action=delete&id=%s">%s</a>', $item['uacteid'], __( 'Delete', 'user_activity_log_pro' ) ),
		);

		return sprintf(
			'%s %s',
			$item['email_title'],
			$this->row_actions( $actions )
		);
	}

	/**
	 * Add checkbox for column.
	 *
	 * @param string $item Item.
	 */
	public function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="id[]" value="%s" />',
			$item['uacteid']
		);
	}

	/**
	 * Get Columns.
	 */
	public function get_columns() {
		$columns = array(
			'cb'             => '<input type="checkbox" />', // Render a checkbox instead of text.
			'email_title'    => __( 'Title', 'user_activity_log_pro' ),
			'email_address'  => __( 'To Email ID', 'user_activity_log_pro' ),
			'email_template' => __( 'Email Template', 'user_activity_log_pro' ),
			'user_name'      => __( 'Author', 'user_activity_log_pro' ),
		);
		return $columns;
	}

	/**
	 * Get Sortable Columns.
	 */
	public function get_sortable_columns() {
		$sortable_columns = array(
			'email_title' => array( 'email_title', true ),
			'user_name'   => array( 'user_name', true ),
		);
		return $sortable_columns;
	}

	/**
	 * Get Bulk Actions.
	 */
	public function get_bulk_actions() {
		$actions = array(
			'delete' => 'Delete',
		);
		return $actions;
	}

	/**
	 * [OPTIONAL] This method processes bulk actions
	 * it can be outside of class
	 * it can not use wp_redirect coz there is output already
	 * in this example we are processing delete action
	 * message about successful deletion will be shown on page in next part
	 */
	public function process_bulk_action() {
		global $wpdb, $externaldb;
		$table_name = UALP_EMAIL_TABLENAME; // do not forget about tables prefix.

		if ( 'delete' === $this->current_action() ) {
			if ( isset( $_REQUEST['id'] ) && is_array( $_REQUEST['id'] ) ) {
				$ids = isset( $_REQUEST['id'] ) ? array_map( 'sanitize_text_field', wp_unslash( $_REQUEST['id'] ) ) : array();
			} else {
				$ids = isset( $_REQUEST['id'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['id'] ) ) : '';
			}
			if ( is_array( $ids ) ) {
				$ids = implode( ',', $ids );
			}

			if ( ! empty( $ids ) ) {
				$externaldb->query( "DELETE FROM $table_name WHERE uacteid IN($ids)" );
			}
		}
	}

	/**
	 * [REQUIRED] This is the most important method
	 *
	 * It will get rows from database and prepare them to be showed in table
	 */
	public function prepare_items() {
		global $wpdb, $externaldb;
		$table_name             = UALP_EMAIL_TABLENAME; // do not forget about tables prefix.
		$request_url            = isset( $_SERVER['REQUEST_URI'] ) ? esc_url_raw( wp_unslash( $_SERVER['REQUEST_URI'] ) ) : '';
		$_SERVER['REQUEST_URI'] = remove_query_arg( '_wp_http_referer', $request_url );
		$per_page               = $this->get_items_per_page( 'ualp_user_email_per_page' );

		$columns  = $this->get_columns();
		$hidden   = array();
		$sortable = $this->get_sortable_columns();

		// here we configure table headers, defined in our methods.
		$this->_column_headers = array( $columns, $hidden, $sortable );

		// [OPTIONAL] process bulk action if any.
		$this->process_bulk_action();

		// will be used in pagination settings.
		$total_items = $externaldb->get_var( "SELECT COUNT(uacteid) FROM $table_name" );

		// prepare query params, as usual current page, order by and order direction.
		$paged   = isset( $_REQUEST['paged'] ) ? ( $per_page * max( 0, intval( $_REQUEST['paged'] ) - 1 ) ) : 0;
		$orderby = ( isset( $_REQUEST['orderby'] ) && in_array( $_REQUEST['orderby'], array_keys( $this->get_sortable_columns() ) ) ) ? sanitize_text_field( wp_unslash( $_REQUEST['orderby'] ) ) : 'user_id';
		$order   = ( isset( $_REQUEST['order'] ) && in_array( $_REQUEST['order'], array( 'asc', 'desc' ) ) ) ? sanitize_text_field( wp_unslash( $_REQUEST['order'] ) ) : 'asc';

		// [REQUIRED] define $items array
		// notice that last argument is ARRAY_A, so we will retrieve array.
		$this->items = $externaldb->get_results( $externaldb->prepare( "SELECT * FROM $table_name ORDER BY $orderby $order LIMIT %d OFFSET %d", $per_page, $paged ), ARRAY_A );

		// [REQUIRED] configure pagination
		$this->set_pagination_args(
			array(
				'total_items' => $total_items, // total items defined above.
				'per_page'    => $per_page, // per page constant defined at top of method.
				'total_pages' => ceil( $total_items / $per_page ), // calculate pages count.
			)
		);
	}

	/**
	 * No Items.
	 */
	public function no_items() {
		esc_html_e( 'No Email Notification Found.', 'user_activity_log_pro' );
	}
}
/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @author     Solwin Infotech <info@solwininfotech.com>
 */
class Ualp_Sms_Notification_List_Table extends WP_List_Table {

	/**
	 * Class Cunstructor.
	 */
	public function __construct() {
		global $status, $page;
		parent::__construct(
			array(
				'singular' => 'person',
				'plural'   => 'persons',
				'screen'   => isset( $args['screen'] ) ? $args['screen'] : null,
			)
		);
		add_screen_option(
			'per_page',
			array(
				'default' => 20,
				'label'   => esc_html__( 'Number of sms per page', 'user_activity_log_pro' ) . ' : ',
				'option'  => 'ualp_user_sms_per_page',
			)
		);
		add_filter( 'set-screen-option', array( &$this, 'ualp_sms_set_screen_option' ), 10, 3 );
		set_screen_options();
	}

	/**
	 * Set Screen Options.
	 *
	 * @param string $status Status.
	 * @param string $option Option.
	 * @param string $value Value.
	 */
	public function ualp_sms_set_screen_option( $status, $option, $value ) {
		if ( 'ualp_user_email_per_page' === $option ) {
			return $value;
		}
	}

	/**
	 * Default Column.
	 *
	 * @param string $item Item.
	 * @param string $column_name Column Name.
	 */
	public function column_default( $item, $column_name ) {
		return $item[ $column_name ];
	}

	/**
	 * User name Column.
	 *
	 * @param string $item Item.
	 */
	public function column_user_name( $item ) {
		return $item['user_name'];
	}

	/**
	 * SMS Address Column.
	 *
	 * @param string $item Item.
	 */
	public function column_sms_address( $item ) {
		return $item['sms_address'];
	}

	/**
	 * SMS Template Column.
	 *
	 * @param string $item Item.
	 */
	public function column_sms_template( $item ) {
		if ( '0' == $item['sms_template'] ) {
			return __( 'Default Template', 'user_activity_log_pro' );
		}
		if ( '1' == $item['sms_template'] ) {
			return __( 'Event Specific Template', 'user_activity_log_pro' );
		}
	}

	/**
	 * SMS Title Column.
	 *
	 * @param string $item Item.
	 */
	public function column_sms_title( $item ) {
		$actions = array(
			'edit'   => sprintf( '<a href="?page=ualp_add_sms_notification&snotification=%s">%s</a>', $item['uacteid'], __( 'Edit', 'user_activity_log_pro' ) ),
			'delete' => sprintf( '<a class="ualp_delete_sms" href="?page=ualp_sms_setting&action=delete&id=%s">%s</a>', $item['uacteid'], __( 'Delete', 'user_activity_log_pro' ) ),
		);
		return sprintf( '%s %s', $item['sms_title'], $this->row_actions( $actions ) );
	}

	/**
	 * Add checkbox for column.
	 *
	 * @param string $item Item.
	 */
	public function column_cb( $item ) {
		return sprintf( '<input type="checkbox" name="id[]" value="%s" />', $item['uacteid'] );
	}

	/**
	 * Get Columns.
	 */
	public function get_columns() {
		$columns = array(
			'cb'           => '<input type="checkbox" />', // Render a checkbox instead of text.
			'sms_title'    => __( 'Title', 'user_activity_log_pro' ),
			'sms_address'  => __( 'To Phone Number', 'user_activity_log_pro' ),
			'sms_template' => __( 'SMS Template', 'user_activity_log_pro' ),
			'user_name'    => __( 'Author', 'user_activity_log_pro' ),
		);
		return $columns;
	}

	/**
	 * Get Sortable Columns.
	 */
	public function get_sortable_columns() {
		$sortable_columns = array(
			'sms_title' => array( 'sms_title', true ),
			'user_name' => array( 'user_name', true ),
		);
		return $sortable_columns;
	}
	/**
	 * Get Bulk Actions.
	 */
	public function get_bulk_actions() {
		$actions = array( 'delete' => 'Delete' );
		return $actions;
	}
	/**
	 * Bulk Actions.
	 */
	public function process_bulk_action() {
		global $wpdb, $externaldb;
		$table_name = UALP_SMS_TABLENAME; // do not forget about tables prefix.
		if ( 'delete' === $this->current_action() ) {
			if ( isset( $_REQUEST['id'] ) && is_array( $_REQUEST['id'] ) ) {
				$ids = isset( $_REQUEST['id'] ) ? array_map( 'sanitize_text_field', wp_unslash( $_REQUEST['id'] ) ) : array();
			} else {
				$ids = isset( $_REQUEST['id'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['id'] ) ) : '';
			}
			if ( is_array( $ids ) ) {
				$ids = implode( ',', $ids );
			}
			if ( ! empty( $ids ) ) {
				$externaldb->query( "DELETE FROM $table_name WHERE uacteid IN($ids)" );
			}
		}
	}
	/**
	 * [REQUIRED] This is the most important method.
	 *
	 * It will get rows from database and prepare them to be showed in table.
	 */
	public function prepare_items() {
		global $wpdb, $externaldb;
		$table_name             = UALP_SMS_TABLENAME; // do not forget about tables prefix.
		$request_url            = isset( $_SERVER['REQUEST_URI'] ) ? esc_url_raw( wp_unslash( $_SERVER['REQUEST_URI'] ) ) : '';
		$_SERVER['REQUEST_URI'] = remove_query_arg( '_wp_http_referer', $request_url );
		$per_page               = $this->get_items_per_page( 'ualp_user_sms_per_page' );
		$columns                = $this->get_columns();
		$hidden                 = array();
		$sortable               = $this->get_sortable_columns();
		// here we configure table headers, defined in our methods.
		$this->_column_headers = array( $columns, $hidden, $sortable );
		// [OPTIONAL] process bulk action if any.
		$this->process_bulk_action();
		// will be used in pagination settings.
		$total_items = $externaldb->get_var( "SELECT COUNT(uacteid) FROM $table_name" );
		// prepare query params, as usual current page, order by and order direction.
		$paged   = isset( $_REQUEST['paged'] ) ? ( $per_page * max( 0, intval( $_REQUEST['paged'] ) - 1 ) ) : 0;
		$orderby = ( isset( $_REQUEST['orderby'] ) && in_array( $_REQUEST['orderby'], array_keys( $this->get_sortable_columns() ) ) ) ? sanitize_text_field( wp_unslash( $_REQUEST['orderby'] ) ) : 'user_id';
		$order   = ( isset( $_REQUEST['order'] ) && in_array( $_REQUEST['order'], array( 'asc', 'desc' ) ) ) ? sanitize_text_field( wp_unslash( $_REQUEST['order'] ) ) : 'asc';

		// [REQUIRED] define $items array.
		// notice that last argument is ARRAY_A, so we will retrieve array.
		$this->items = $externaldb->get_results( $externaldb->prepare( "SELECT * FROM $table_name ORDER BY $orderby $order LIMIT %d OFFSET %d", $per_page, $paged ), ARRAY_A );

		// [REQUIRED] configure pagination.
		$this->set_pagination_args(
			array(
				'total_items' => $total_items, // total items defined above.
				'per_page'    => $per_page, // per page constant defined at top of method.
				'total_pages' => ceil( $total_items / $per_page ), // calculate pages count.
			)
		);
	}

	/**
	 * No Items.
	 */
	public function no_items() {
		esc_html_e( 'No SMS Notification Found.', 'user_activity_log_pro' );
	}
}
